!***********************************************************************
!
!                     CRPCOF_DPM.F  
!
!     Declares, initializes, and then sets, for each day, the parameters for any of 
!     the MAXLANDS-nlands land-uses/covers present in the modeled area 

  
!     version: 1.1 (vaccaro/bauer)


      integer function cropcof_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer cropcofdecl, cropcofinit, cropcofrun, retval

      integer cov_type(MAXHRU), nhru, nlands, ncoef
      integer irrst1(MAXLANDS), irren1(MAXLANDS), irrst2(MAXLANDS)
      integer irren2(MAXLANDS), irrscd(MAXLANDS), iroot, fallow

      real    coefs(MAXLANDS,MAXCOEFS),sumcp(MAXLANDS)
      real    maxint(MAXLANDS), fcmax(MAXLANDS), rdmax(MAXLANDS)

      save nhru, cov_type, nlands, ncoef
      save maxint, fcmax,  rdmax,  coefs,  sumcp
      save irrst1, irren1, irrst2, irren2, irrscd, iroot, fallow
  
      retval = 0

      if(arg.eq.'declare') then
        retval = cropcofdecl(coefs)
      
      else if(arg.eq.'initialize') then

        retval = cropcofinit(maxint,fcmax,rdmax,irrst1,irren1,irrst2,
     +            irren2,irrscd,iroot,fallow,coefs,sumcp,cov_type,
     +                                    ncoef,nhru,nlands)

      else if(arg.eq.'run') then
        retval = cropcofrun(maxint,fcmax,rdmax,irrst1,irren1,irrst2,
     +  irren2,irrscd,fallow,coefs,sumcp,cov_type,nhru,nlands,ncoef)

      end if

!******Debug level print
      call dpint4('End of crpcof_dpm, retval = ', retval, 1, 2)

      cropcof_dpm = retval

      return
      end

!***********************************************************************
!     CROPCOFDECL: Declares  parameters for crop (cover-type) landuses
!              

!     cropcofdecl - set up parameters


      integer function cropcofdecl(coefs)

      include 'fmodules.inc'

      real coefs(MAXLANDS,MAXCOEFS)

      cropcofdecl = 1

!.. New variable for this modules and new parameter

      if(declvar('cropcof', 'coefs', 'nlands,ncoef', MAXLANDS*MAXCOEFS,
     +   'real',
     +   'Daily crop coefficients for 6 parameters of the crop-type'//
     +   'Coefs for: root depth, foliar cover, cp, interctp, irrig',
     +   'varies',coefs).ne.0) return

!.. LAND-USE/COVER PARAMETERS FOR MODIFIED or NON-DEFAULT MODULE VALUES

      if(declparam('cropcof', 'fcmax', 'nlands', 'real',
     +   '0.0', '0.0', '1.0',
     +   'Maximum foliar cover of associated land use',
     +   'Maximum foliar cover of associated land use'//
     +   'Default values in land-use routines, this overides those'//
     +   'In decimal fraction, cover density for PET calcs',
     +   'decimal').ne.0) return

      if(declparam('cropcof', 'maxint', 'nlands', 'real',
     +   '0.0', '0.0', '0.3',
     +   'Maximum interception capacity of associated land use',
     +   'Maximum interception capacity of associated land use'//
     +   'Default values in land-use routines, this overides those',
     +   'inches').ne.0) return

      if(declparam('cropcof', 'rdmax', 'nlands', 'real',
     +   '0.0', '0.0', '60.',
     +   'Maximum root depth of associated land use',
     +   'Maximum root depth of associated land use'//
     +   'Default values in land-use routines, this overides those',
     +   'inches').ne.0) return

      if(declparam('cropcof', 'irrst1', 'nlands', 'integer',
     +   '0', '0', '1231',
     +   'Start date for first irrigation scheduling period',
     +   'Start date for first irrigation scheduling period =0 no irr'//
     +   'Default is no irrigation, dates coded as compressed values:'//
     +   'IE, june 9th is 0609, if irrst1=0 then no irr this landuse',
     +   'monthday').ne.0) return

      if(declparam('cropcof', 'irren1', 'nlands', 'integer',
     +   '0', '0', '1231',
     +   'End date for first irrigation scheduling period',
     +   'End date for first irrigation scheduling period'//
     +   'If only one period irren2=end date, set irren1 < irren2'//
     +   'Default is no irrigation, dates coded as compressed values:'//
     +   'IE, june 9th is 0609',
     +   'monthday').ne.0) return

      if(declparam('cropcof', 'irrst2', 'nlands', 'integer',
     +   '0', '0', '1231',
     +   'Start date for second irrigation scheduling period',
     +   'Start date for second irrigation scheduling period'//
     +   'If only one period, add one day to irren1'//
     +   'Default is no irrigation, dates coded as compressed values:'//
     +   'IE, june 9th is 0609',
     +   'monthday').ne.0) return

      if(declparam('cropcof', 'irren2', 'nlands', 'integer',
     +   '0', '0', '1231',
     +   'End date for second irrigation scheduling period',
     +   'End date for second irrigation scheduling period'//
     +   'If only one period irren2=end date, set irren1 < irren2'//
     +   'Default is no irrigation, dates coded as compressed values:'//
     +   'IE, june 9th is 0609',
     +   'monthday').ne.0) return

      if(declparam('cropcof', 'irrscd', 'nlands', 'integer',
     +   '0', '0', '1',
     +   'Irrigation scheduling type: =0 constant, =1 ~ growth stage',
     +   'Irrigation scheduling type: =0 constant, =1 ~ growth stage'//
     +   'IRRSCD=0 FOR CONSTANT DAILY IRRIGATION RATE'//
     +   'IRRSCD=1 FOR irrigation RATE PROPORTIONAL TO GROWTH STAGE',
     +   'none').ne.0) return

      if(declparam('cropcof', 'sumcp', 'nlands', 'real',
     +   '0.0', '0.0', '26.',
     +   'Crop curve integrated over the input irrigation season',
     +   'Crop curve integrated over the input irrigation season'//
     +   'Sum of the crop coefficient curve for the irrigation season',
     +   'none').ne.0) return

!..Root distribution parameter

      if(declparam('cropcof', 'iroot', 'one', 'integer',
     +   '0', '0', '1',
     +  'Distribution of root mass in root zone: linear or exponential',
     + 'Distribution of root mass in root zone: linear or exponential'//
     +   'iroot=0=linear, iroot>0=exponential: expon gives more rech'//
     +   'because plant moisture extraction ~ to root mass distribtion',
     +   'none').ne.0) return

!.counter to determine if need to swap dryland wheat from active to fallow

      if(declparam('cropcof', 'fallow', 'one', 'integer',
     +   '0', '0', '1',
     +   'Winter wheat (2yr cycle) landcover swapping, type 5 to 6',
     +   'Winter wheat (2yr cycle) landcover swapping, type 5 to 6'//
     +  'If any cells/hrus have landcover of 5 or 6 then set fallow>0',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return


      cropcofdecl = 0

      return
      end

!**********************************************************************
!     cropcofinit - get input crop-coef parameters and then initialize 
!                


      integer function cropcofinit(maxint,fcmax,rdmax,irrst1,irren1,
     +                        irrst2,irren2,irrscd,iroot,fallow,coefs,
     +                        sumcp,cov_type,ncoef,nhru,nlands)


      include 'fmodules.inc'

      
      integer nhru, nlands, ncoef, cov_type(MAXHRU)
      integer i, j, irdy, irmo

      integer irrst1(MAXLANDS),  irren1(MAXLANDS), irrst2(MAXLANDS)
      integer irren2(MAXLANDS),  irrscd(MAXLANDS), iroot, fallow
      real    maxint(MAXLANDS),  fcmax(MAXLANDS),  rdmax(MAXLANDS)
      real    coefs(MAXLANDS,MAXCOEFS),            sumcp(MAXLANDS)

!..julian start day for each month=jdym

      integer jdym(12)
      DATA JDYM/1,32,60,91,121,152,182,213,254,274,305,335/

      CHARACTER*110 BUFFER

      cropcofinit = 1

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

!..GET THE PARAMETERS FOR THE 
!..MODIFIED LAND-USE/COVER PARAMETERS FOR NON-DEFAULT VALUES

!..get interception, foliar cover, and maximum root depth later
!. (after scheduling since bring in these values as 0's for calls to crop routines)              

      if(getparam('cropcof', 'irrst1', MAXLANDS, 'integer', irrst1)
     +   .ne.0) return

      if(getparam('cropcof', 'irren1', MAXLANDS, 'integer', irren1)
     +   .ne.0) return

      if(getparam('cropcof', 'irrst2', MAXLANDS, 'integer', irrst2)
     +   .ne.0) return

      if(getparam('cropcof', 'irren2', MAXLANDS, 'integer', irren2)
     +   .ne.0) return

      if(getparam('cropcof', 'irrscd', MAXLANDS, 'integer', irrscd)
     +   .ne.0) return

!..GET root distribution parameters

      if(getparam('cropcof', 'iroot',     1,     'integer',  iroot)
     +  .ne.0) return

!..landuse/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.....CONVERT MONTH-DAY TO JULIAN DAY

      DO 10  I=1,nlands

      IF(IRRST1(I).LT.1) GO TO 10
      IRMO=IRRST1(I)/100
      IRDY=MOD(IRRST1(I),100)
      IRRST1(I)=JDYM(IRMO)-1+IRDY
      IRMO=IRRST2(I)/100
      IRDY=MOD(IRRST2(I),100)
      IRRST2(I)=JDYM(IRMO)-1+IRDY
      IRMO=IRREN1(I)/100
      IRDY=MOD(IRREN1(I),100)
      IRREN1(I)=JDYM(IRMO)-1+IRDY
      IRMO=IRREN2(I)/100
      IRDY=MOD(IRREN2(I),100)
      IRREN2(I)=JDYM(IRMO)-1+IRDY
    
10    CONTINUE


!.....INTEGRATE THE CROP GROWTH CURVES OVER THE IRRIGATION SEASON SO THAT,
!.....IF IRRSCD=1, IRRIGATION CAN BE APPORTIONED ACCORDING TO GROWTH CURVE.

      CALL SCHEDULE(IRRST1,IRREN1,IRRST2,IRREN2,IRRSCD,SUMCP,nlands)

!.. now get CROP INFORMATION PARAMETERS

      if(getparam('cropcof', 'maxint', MAXLANDS, 'real',   maxint)
     + .ne.0) return

      if(getparam('cropcof', 'fcmax',  MAXLANDS, 'real',    fcmax)
     +  .ne.0) return

      if(getparam('cropcof', 'rdmax',  MAXLANDS, 'real',    rdmax)
     +  .ne.0) return

!.....GROWING CYCLE THEN LANDUSE=5 MUST BE SWAPPED FOR LANDUSE=6 EACH YEAR

      fallow = 0
      do 20 i=1,nhru
20    IF(cov_type(I).EQ.5.OR.cov_type(I).EQ.6) FALLOW=FALLOW+1

!..zero variable:  coefs    = 0.0

      do 30 I=1,nlands
      do 30 J=1,ncoef
30    coefs(i,j) = 0.0

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)      
      WRITE(BUFFER,1001) IROOT
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)      
      WRITE(BUFFER,1002) NLANDS
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)      
      WRITE(BUFFER,1003) 
      CALL OPSTR(BUFFER)

      DO 40  I=1,nlands
      WRITE(BUFFER,1004) I, RDMAX(I),FCMAX(I), MAXINT(I),IRRST1(I),
     .                     IRREN1(I),IRRST2(I),IRREN2(I),IRRSCD(I)
40    CALL OPSTR(BUFFER)

!..Formats for echoing input data

1000  FORMAT()
1001  FORMAT(  '  PARAMETER IROOT= ',I1,' : ROOT DENSITY AND WATER DEPLE
     .TION DISTRIBUTION; 0= UNIFORM; 1= EXPONENTIAL')
1002  FORMAT(  '  DIMENSION NLANDS =',I2,' : =NUMBER OF MODIFIED LANDUSE
     .S AS FOLLOWS:')
1003  FORMAT(' LANDUSE  RDMAX   FCMAX   MAXINT IRRST1 IRREN1 IRRST2 IRRE
     .N2 IRRSCD')
1004  FORMAT (2X,I4,6X,F3.0,4X,F4.2,4X,F4.2,5I7)

      cropcofinit = 0

      return
      end


!***********************************************************************
! 
!     cropcofrun - FIND daily crop-parameters
!
!.....MODULE TO GET FOR CURRENT DAY: CROP-PET COEFFICIENT (CP),
!.....MAXIMUM ROOT DEPTH (RDMX), CURRENT ROOT DEPTH (RD), FOLAIR COVER (FC),
!.... INTERCEPTION CAPACITY (MXNT), AND FRACTION OF ANNUAL APPLICATION
!        values for each day stored in: coefs(30,6)


      integer function cropcofrun(maxint,fcmax,rdmax,irrst1,irren1, 
     +   irrst2,irren2,irrscd,fallow,coefs,sumcp,cov_type,
     +  nhru,nlands,ncoef)

      include 'fmodules.inc'

      integer nhru, nlands, ncoef
      integer cov_type(MAXHRU), fallow

      integer irrst1(MAXLANDS),  irren1(MAXLANDS), irrst2(MAXLANDS)
      integer irren2(MAXLANDS),  irrscd(MAXLANDS)

      real    maxint(MAXLANDS),  fcmax(MAXLANDS),  rdmax(MAXLANDS)
      real    coefs(MAXLANDS,MAXCOEFS), sumcp(MAXLANDS)

!..temps
      
      real mxnt,apmult,rd,cp,fc,rdmx,fcmx,xinter,cpalf
      integer i, jday, month, kntdays, nowtime(6)

      cropcofrun = 1

      call dattim('now', nowtime)
      jday    = julian('now', 'calendar')
      month   = nowtime(2)
      kntdays = getstep()

!..FIRST SEE if need to swap the 2 dryland wheat landuses due to 2-yr growing cycle

      if(fallow.gt.0 .and. kntdays.gt.30 .and. month.eq.12) then

      do 50 i=1,nhru
      if(cov_type(i).eq.5) cov_type(i)=6
50    if(cov_type(i).eq.6) cov_type(i)=5

      end if

!.....REFERENCE CROP FOR JENSEN-HAISE (J-H) PET METHOD IS ALFALFA. PUBLISHED
!.....CROP COEFFICIENTS USED IN THE AGRICULTURAL LANDUSE SUBROUTINES ARE
!.....FROM THE BLANEY-CRIDDEL (B-C) METHOD (ALSO WRIGHT). THEREFORE CROP COEFFICIENT
!.....(CP) FOR J-H PET IS (B-C CP)/(B-C ALFALFA CP). SOME KCs from FAO FOR GRASS BASE
!.....AND THESE VALUES ARE SIMILIAR TO ALF FOR JEN-HAISE (IF ANYTHING SLIGHTLY LARGER THAN
!.....SMALLER). FAO VALUES USED BASED ON PENMAN-MONTIETH. 

!.....FIRST EVALUATE ALFALFA CP (CPALF) FOR CURRENT DAY.

      call alftoday(jday,cpalf)

!.....GET PARAMETERS FOR EACH LAND-USE.

      DO 40 I=1,nlands

      APMULT=0.0
      RD    =0.0
      CP    =0.0
      FC    =0.0
      MXNT  =0.0
      RDMX  =0.0

!..IF SURFACE-WATER CELL/HRU/MRU SKIP REST

      IF(I.EQ.10) GO TO 20

      RDMX  =RDMAX(I)
      FCMX  =FCMAX(I)
      XINTER=MAXINT(I)

      GO TO (1,2,3,4,5,6,7,8,9,20,11,12,13,
     .       14,15,20,17,18,19,16,21,22,23,24,25,26,27,28,29,30,31) I

1     CALL FOREST (RDMX,FCMX,XINTER,RD,FC,MXNT,CP)
      GO TO 20

2     CALL GRASS(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      GO TO 20

3     CALL SAGE  (RDMX,FCMX,XINTER,RD,FC,MXNT,CP)
      GO TO 20

!.........WINTER WHEAT HARVESTED THIS SUMMER AND PLANTED THIS FALL
4     CALL WWALYR(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

!......WINTER WHEAT HARVESTED THIS SUMMER AND FALLOW NEXT FALL'S PLANTNG
5     CALL WWSPRG(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

!.........WINTER WHEAT FALLOW THIS SPRING AND PLANTED THIS FALL
6     CALL WWAUTM(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

7     CALL ORCHRD(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

8     CALL ALFALF(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

9     CALL ROW  (JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20
11    CALL CORN (JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20
12    CALL POTATO(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

13    CALL SAND(RDMX,RD,FC,MXNT,CP)
      GO TO 20

14    CALL LENTILS(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

15    CALL SPRGWT(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

17    CALL SMALVEG(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

18    CALL COTTON(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

19    CALL MINT(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

16    CALL GRAPECAL(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

21    CALL GRAPEWAOR(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

22    CALL HOPS(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

23    CALL OLIVE(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

24    CALL CITRUS(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

25    CALL SOY(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

26    CALL APPLES(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

27    CALL SORGHUM(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

28    CALL PASTURE(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

29    CALL BEAN(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

30    CALL PEA(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF
      GO TO 20

31    CALL ASPARAGUS(JDAY,RDMX,FCMX,XINTER,RD,FC,MXNT,CP,APMULT,
     .            IRRST1(I),IRREN1(I),IRRST2(I),IRREN2(I),
     .            IRRSCD(I),SUMCP(I))
      CP=CP/CPALF

20    COEFS(I,1)=RD
      COEFS(I,2)=FC
      COEFS(I,3)=MXNT
      COEFS(I,4)=CP
      COEFS(I,5)=APMULT
      COEFS(I,6)=RDMX

40    CONTINUE
      
221   format(2x,2i4,6f6.2)

      cropcofrun = 0

      RETURN
      END


      SUBROUTINE SCHEDULE(IRRST1,IRREN1,IRRST2,IRREN2,IRRSCD,SUMCP,
     +                                                       nlands)

      integer irrst1(nlands),irren1(nlands),irrst2(nlands)
      integer irren2(nlands),irrscd(nlands), nlands

      real    sumcp(nlands),cp,rdmx,fcmx,mxi,rd,fc,mxnt,apmult
      integer jday, L

      real dum

      do 1 L=1,nlands
1     sumcp(L)  = 0.0

      dum=0.0

!
!.....SUBROUTINE TO INTEGRATE THE CROP COEFFICIENT CURVES OVER THE
!.....SPECIFIED IRRIGATION SEASON.
!
      DO 100 JDAY=1,366

      L=2
      IF(IRRSCD(L).LT.1) GO TO 4
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 4
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 4
      CALL GRASS(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
4     L=4
      IF(IRRSCD(L).LT.1) GO TO 5
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 5
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 5
      CALL WWALYR(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
5     L=5
      IF(IRRSCD(L).LT.1) GO TO 6
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 6
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 6
      CALL WWSPRG(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
6     L=6
      IF(IRRSCD(L).LT.1) GO TO 7
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 7
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 7
      CALL WWAUTM(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
7     L=7
      IF(IRRSCD(L).LT.1) GO TO 8
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 8
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 8
      CALL ORCHRD(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
8     L=8
      IF(IRRSCD(L).LT.1) GO TO 9
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 9
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 9
      CALL ALFALF(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
9     L=9
      IF(IRRSCD(L).LT.1) GO TO 11
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 11
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 11
      CALL ROW(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
11    L=11
      IF(IRRSCD(L).LT.1) GO TO 12
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 12
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 12
      CALL CORN(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
12    L=12
      IF(IRRSCD(L).LT.1) GO TO 14
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 14
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 14
      CALL POTATO(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
14    L=14
      IF(IRRSCD(L).LT.1) GO TO 15
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 15
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 15
      CALL LENTILS(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
15    L=15
      IF(IRRSCD(L).LT.1) GO TO 17
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 17
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 17
      CALL SPRGWT(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
17    L=17
      IF(IRRSCD(L).LT.1) GO TO 18
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 18
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 18
      CALL SMALVEG(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
18    L=18
      IF(IRRSCD(L).LT.1) GO TO 19
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 19
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 19
      CALL COTTON(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
19    L=19
      IF(IRRSCD(L).LT.1) GO TO 20
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 20
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 20
      CALL MINT(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
20    L=20
      IF(IRRSCD(L).LT.1) GO TO 21
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 21
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 21
      CALL GRAPECAL(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
21    L=21
      IF(IRRSCD(L).LT.1) GO TO 22
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 22
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 22
      CALL GRAPEWAOR(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
22    L=22
      IF(IRRSCD(L).LT.1) GO TO 23
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 23
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 23
      CALL HOPS(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
23    L=23
      IF(IRRSCD(L).LT.1) GO TO 24
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 24
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 24
      CALL OLIVE(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP
24    L=24
      IF(IRRSCD(L).LT.1) GO TO 25
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 25
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 25
      CALL CITRUS(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

25    L=25
      IF(IRRSCD(L).LT.1) GO TO 26
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 26
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 26
      CALL SOY(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

26    L=26
      IF(IRRSCD(L).LT.1) GO TO 27
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 27
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 27
      CALL APPLES(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

27    L=27
      IF(IRRSCD(L).LT.1) GO TO 28
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 28
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 28
      CALL SORGHUM(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

28    L=28
      IF(IRRSCD(L).LT.1) GO TO 29
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 29
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 29
      CALL PASTURE(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

29    L=29
      IF(IRRSCD(L).LT.1) GO TO 30
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 30
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 30
      CALL BEAN(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

30    L=30
      IF(IRRSCD(L).LT.1) GO TO 31
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 31
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 31
      CALL PEA(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

31    L=31
      IF(IRRSCD(L).LT.1) GO TO 100
      IF(JDAY.LT.IRRST1(L).OR. JDAY.GT.IRREN2(L)) GO TO 100
      IF(JDAY.LT.IRRST2(L).AND.JDAY.GT.IRREN1(L)) GO TO 100
      CALL ASPARAGUS(JDAY,dum,dum,dum,dum,dum,dum,cp,dum,
     .           IRRST1(L),IRREN1(L),IRRST2(L),IRREN2(L),0,-1.0)
      SUMCP(L)=SUMCP(L)+CP

100   CONTINUE

      RETURN
      END


!..FORESTS

      SUBROUTINE FOREST(RDMX,FCMX,MXI,RD,FC,MXNT,CP)

!.....LANDUSE #1-DOUGLAS FIR CONIFER FOREST BASED IN PART ON WORK OF
!.... GILES, BLACK, AND SPITTLEHOUSE, 1984, FOR SUMMER.
!.....THE PARAMETERS SET IN THIS SUBROUTINE ARE BASED ON USING PRIESTLY-TAYLOR
!.....PET FORMULATION. CRPMX=ALFA-COEFFICIENT TO PRIESTLY-TAYLOR PET.

      REAL MXI,MXNT,RDMX,FCMX,RD,FC,CP,CRPMX

      CRPMX=0.73
      IF(RDMX.LT.0.00001) RDMX=36.0
      IF(FCMX.LT.0.00001) FCMX= 1.0
      IF(MXI. LT.0.00001) MXI = 0.13
      RD=RDMX
      FC=FCMX
      MXNT=MXI
      CP=CRPMX
      RETURN
      END

!..GRASS

      SUBROUTINE GRASS(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #2-GRASS.
!.....THE PARAMETERS SET IN THIS SUBROUTINE ARE BASED ON USING
!.....PRIESTLY-TAYLOR GRASS REFERENCE PET FORMULATION.
!.....CRPMX=ALFA-COEFFICIENT TO PRIESTLY-TAYLOR PET.

      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,CRPMX,SUMCP
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD, JDAY


!!      CRPMX=1.26
      CRPMX=0.73
      IF(RDMX.LT.0.00001) RDMX=24.0
      IF(FCMX.LT.0.00001) FCMX= 1.0
      IF(MXI. LT.0.00001) MXI = 0.06
      RD  = RDMX
      FC  = FCMX
      MXNT= MXI
      CP  = CRPMX
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END
!
!..SAGEBRUSH
!
      SUBROUTINE SAGE (RDMX,FCMX,MXI,RD,FC,MXNT,CP)

!.....LANDUSE #3-SAGEBRUSH AND ASSOCIATED SCRUB

      REAL MXI,MXNT,RDMX,FCMX,RD,FC,CP,CRPMX

!.....THE PARAMETERS SET IN THIS SUBROUTINE ARE BASED ON USING PRIESTLY-TAYLOR
!.....PET FORMULATION. CRPMX=ALFA-COEFFICIENT TO PRIESTLY-TAYLOR PET,
!.....ASSUME THAT IT IS THE SAME AS FOR GRASS = 1.26

      CRPMX=1.26
!.....ROOT DEPTH FROM BATELLE RECHARGE REPORT.
      IF(RDMX.LT.0.00001)RDMX=55.22
!.....FCMAX=.35, MXI=.06 FROM PERS. COMM. GEORGE LEAVSLY, AND AFTER
!.....ZINKE, RESPECTIVELY.
      IF(FCMX.LT.0.00001)FCMX=0.35
      IF(MXI.LT.0.00001) MXI =0.06
      RD  =RDMX
      FC  =FCMX
      MXNT=MXI
      CP  =CRPMX
      RETURN
      END

!..WINTER WHEAT, NO FALLOW: HARVESTED SUMMER AND PLANTED THAT FALL

      SUBROUTINE WWALYR (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #4-WINTER WHEAT, HARVESTED AND PLANTED EACH YEAR

      REAL CRP(13),CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDAY, JDATE(13)
      DATA CRP/1.15,1.15,1.15,1.12,1.0,0.98,0.,0.,.34,.45,.85,1.15,1.15/
      DATA JDATE/1, 87,  99,  117, 137,146, 186,248,256,261,273,305,366/
      CRPMX=1.15

      IF(RDMX.LT.0.00001) RDMX=48.0
      IF(FCMX.LT.0.00001) FCMX= 1.0
!.....MXI=0.16 FROM LINSLEY, ETC.
      IF(MXI.LT.0.00001)  MXI = 0.16

!......INTERPOLATE BLANNEY-CRIDDLE CROP COEFFICIENTS TO JDAY
      DO 100 JJ=2,13
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN

!...APPROX 70 DAYS FROM 45 DEGREE MEAN TEMP DAY IN SPRING (DAY=87)
!...TO FULLY GROWN WHEAT. ASSUME 33% GROWN BEFORE WINTER DORMANCY.
!.. HARVESTED DAY# 186.
      FACT=.33
      IF(JDAY.GT.87 .AND.JDAY.LT.158)  FACT=0.67*(JDAY-87)/70.0+0.33
      IF(JDAY.GT.157.AND.JDAY.LT.187)  FACT=1.0

!.....NON GROWING PERIOD DURING MIDDLE SUMMER.
      IF( JDAY.GT.186.AND.JDAY.LT.251) FACT=0.0

!...APPORX 55 DAYS TO 45 DEG. MEAN TEMP DAY IN FALL (DAY=305)
!...FROM PLANTING (DAY=250). ASSUME WHEAT GROWS TO 33% OF FULL
!...SIZE BY DAY=305
      IF(JDAY.GT.250.AND.JDAY.LT.306) FACT=.33*(JDAY-250)/55.0
      IF(JDAY.GT.305) FACT=0.33

      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..WINTER WHEAT HARVESTED THIS SUMMER AND FALLOW NEXT FALL'S PLANTNG

      SUBROUTINE WWSPRG(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #5-WINTER WHEAT, GROWN ON TWO YEAR CYCLE. THIS SUBROUTINE
!.....FOR SECOND CALENDER YEAR OF CYCLE(HARVEST,FALLOW)

      REAL CRP(8), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(8), JDAY

      DATA JDATE/1,  87,  99,  117,137,146,186,366/
      DATA CRP/1.15,1.15,1.15,1.12,1.0,0.98,0.,0.0/

      CRPMX=1.15
      IF(RDMX.LT.0.00001) RDMX =48.0
      IF(FCMX.LT.0.00001) FCMX = 1.0
!.....MXI=0.16 FROM LINSLEY, ETC.
      IF(MXI.LT.0.00001)  MXI  = 0.16

!......INTERPOLATE BLANNEY-CRIDDLE CROP COEFFICIENTS TO JDAY
      DO 100 JJ=2,8
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))

      IF(SUMCP.LT.0.0) RETURN

!...APPROX 70 DAYS FROM 45 DEGREE MEAN TEMP DAY IN SPRING (DAY=87)
!...TO FULLY GROWN WHEAT. ASSUME 33% GROWN BEFORE FIRST OF YEAR.
      FACT=.33
      IF(JDAY.GT.87.AND.JDAY.LT.158) FACT=0.67*(JDAY-87)/70.0+0.33
      IF(JDAY.GT.157.AND.JDAY.LT.187) FACT=1.0
!.....FALLOW FOR REST OF YEAR
      IF(JDAY.GT.186) FACT=0.0

      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1.OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..WINTER WHEAT FALLOW THIS SPRING AND PLANTED THIS FALL

      SUBROUTINE WWAUTM(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #6-WINTER WHEAT, GROWN ON TWO YEAR CYCLE. THIS SUBROUTINE
!.....FOR FIRST CALANDER YEAR OF CYCLE(FALLOW,PLANTED)

      REAL CRP(7), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(7), JDAY

      DATA CRP/0., 0.,.34,.45,.85, 1.15, 1.15/
      DATA JDATE/1,248,256,261,273 ,305,  366/

      CRPMX=1.15
      IF(RDMX.LT.0.00001)   RDMX=48.0
      IF(FCMX.LT.0.00001)   FCMX= 1.0
!.....MXI=0.16 FROM LINSLEY, ETC.
      IF(MXI.LT.0.00001)     MXI= 0.16

!......INTERPOLATE CROP COEFFICIENTS TO JDAY
      DO 100 JJ=2,7
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN

!...APPORX 55 DAYS TO 45 DEG. MEAN TEMP DAY IN FALL (DAY=305)
!...FROM PLANTING (DAY=250). ASSUME WHEAT GROWS TO 33% OF FULL
!...SIZE BY DAY=305
      FACT=0.0
      IF(JDAY.GT.250.AND.JDAY.LT.306) FACT=.33*(JDAY-250)/55.0
      IF(JDAY.GT.305) FACT=.33

      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END
!
!..ORCHARDS AND DECIDOUS TREES--  LOW LATITUDES -- LEAFED OUT MOST YEAR
!
      SUBROUTINE ORCHRD (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #7-ORCHARD-DECIDUOUS TREES, LOW LATITUDES 
!..         OR MID-LATITUDES RIPARIAN TYPE W/ THICK UNDERSTORY

      REAL  MXI,MXNT
      REAL CRP(11),CRPMX 
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(11), JDAY
      DATA CRP/.61,.66,.98,1.10,1.13,1.12,1.09,1.00,.90,.65,.60/
      DATA JDATE/1, 25,105,140, 161, 186, 212, 253, 288,344,366/

      CRPMX=1.13
      IF(RDMX.LT.0.00001) RDMX =60.0
      IF(FCMX.LT.0.00001) FCMX = 0.65
!.....ASSUME SAME AS DECIDUOUS FOREST =.05 (+.05 FOR GRASS GROUND COVER)
!.....AFTER ZINKE.
      IF(MXI.LT.0.00001)  MXI =0.1
      DO 100 JJ=2,11
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
         J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END


!..ALFALFA, HAY CROPS


      SUBROUTINE ALFALF (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #8-ALFALFA (START AT LAST -4C SPRING, END -4C FALL/killing FROST)

      REAL CRP(9)
      REAL MXI,MXNT,RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPMX,FACT

      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY

      DATA CRP/0.0,0.0,0.40,.4,1.05, 1.05, 0.92, 0.0, 0.0/
      DATA JDATE/1,59, 60,  70, 100, 273,  304,  305, 366/

!.....THIS SUBROUTINE COMPUTES CROP COEFFICIENTS, CP, ROOT DEPTH: RD,
!.....FOLIAR COVER: FC, AND "POTENTIAL" INTERCEPTION: MXNT, FOR JDAY (calendar)
      
      CRPMX=1.05

      IF (fcmx.LT.0.00001) fcmx = 1.0

!.....ALFALFA INTERCEPTION FROM LINSLEY,KOHLER,PAULUS,1975
      IF (mxi.LT.0.00001)  mxi = 0.11

      IF (rdmx.LT.0.00001) rdmx = 60.0

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
       J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))

      IF(SUMCP.LT.0.0) RETURN

      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT

      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END

      SUBROUTINE ALFTODAY (JDAY,CP)

!.....LANDUSE #8-ALFALFA WITH FULL YEAR GROWING SEASON AS BASE REFERENCE
!..   WITH KC VALUES AS HIGHER REPORTED TO GET BASE
!..         FIND ALFALFA CROP COEF FOR TODAY (JDAY)

      REAL CRP(16),CP

      INTEGER J, JJ, JDATE(16), JDAY

      DATA CRP/.6,.66,.75,1.0,1.04,1.10,1.125,1.13,1.13,1.1,1.05,.95,
     +.85,.7,.625,.60/
      DATA JDATE/1,25,51,110,120,140,156,166,176,206,240,273,303,339,
     +352,366/

!.....THIS SUBROUTINE COMPUTES CROP COEFFICIENTS, CP, ROOT DEPTH, RD,
!.....FOLIAR COVER, FC, AND "POTENTIAL" INTERCEPTION, MXNT, FOR JDAY


      DO 100 JJ=2,16
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
       J=JJ
      GO TO 110
 100  CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      RETURN
      END


!..ROW CROPS 

      SUBROUTINE ROW (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
!
!.....LANDUSE#9-ROW CROPS, UNDIFFERENTIATED, 244 DAYS, CAN USE FOR 2 CROPS IN SEASON
!..                                                    OR CROPS SUCH AS ASPARAGUS
!..                                                 CROP WATER USE AVOUT 28" MID-LATS
!
      REAL MXI,MXNT, CRP(12),CRPMX,APMULT
      REAL RDMX,FCMX,RD,FC,CP,SUMCP, FACT

      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(12), JDAY

      DATA CRP/0.0,0.0,.35,.39,.53,.66,.91,1.0,.79,.37,0.0,0.0/
      DATA JDATE/1,59,  75,105,135,166,196,227,258,288,304,366/
!.....COMPOSITE CROP CURVE MADE BY AVERAGING BEANS, PEAS, AND ALFALFA
      CRPMX=1.0
      IF(RDMX.LT.0.00001)RDMX=30.
      IF(FCMX.LT.0.00001)FCMX=0.8
!.....MXI=0.1 INTERPOLATED FROM LINSLEY, ETC
      IF(MXI.LT.0.00001)MXI=0.1
      DO 100 JJ=2,12
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
        J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=FACT*RDMX
      FC=FACT*FCMX
      MXNT=MXI*FACT
      IF(JDAY.LT.227.OR.JDAY.GT.303) GO TO 120
      RD=RDMX
      FC=FCMX
      MXNT=MXI
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1.OR. JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END


!..CORN

      SUBROUTINE CORN(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #11-CORN

      REAL MXI,MXNT
      REAL CRP(13), CRPMX
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(13), JDAY
      DATA CRP/0., 0.,.51, .68,.9, 1.,1.04,1.08,1.08,1.0,.80, 0.,0./
      DATA JDATE/1,126,155,178,188,199,210,219, 230, 243, 253,265,366/

      CRPMX=1.08
      IF(RDMX.LT.0.0001) RDMX=48.0
      IF(FCMX.LT.0.0001) FCMX= 1.0
!.....INTERCEPTION "INTERPOLATED" FROM LINSLEY,ETC
      IF(MXI.LT.0.0001)  MXI = 0.03

      DO 100 JJ=2,13
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
        J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=FACT*RDMX
      FC=FACT*FCMX
      MXNT=MXI*FACT
      IF(JDAY.LT.215.OR.JDAY.GT.264) GO TO 120
      RD=RDMX
      FC=FCMX
      MXNT=MXI
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..POTATO

      SUBROUTINE POTATO(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #12-POTATOES APRIL 20-SEPT 15

      REAL MXI,MXNT
      REAL CRP(13), CRPMX
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDAY, JDATE(13)
      DATA CRP/0,   0,.6, .67, 0.8,0.99,1.13,1.18,1.18,1.16,0.90,0,  0/
      DATA JDATE/1,110,143,152,170,180 ,189, 197, 204, 222, 257,258,366/
!      DATA JDATE/1,164,197,206,224,234,243,251,258,271,294,295,366/

      CRPMX=1.18
      IF(RDMX.LT.0.0001)  RDMX = 48.0
      IF(FCMX.LT.0.0001)  FCMX =  1.0
      IF(MXI.LT.0.0001)   MXI  =  0.15
      DO 100 JJ=2,13 
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
        J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=FACT*RDMX
      FC=FACT*FCMX
      MXNT=MXI*FACT
      IF(JDAY.LT.197.OR.JDAY.GT.251) GO TO 120
      RD=RDMX
      FC=FCMX
      MXNT=MXI
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!
!..SAND, VERY PERMEABLE SOIL WITHOUT LAND-COVER
!
      SUBROUTINE SAND(RDMX,RD,FC,MXNT,CP)

!.....LANDUSE #13-SAND DUNES, BARE GROUND

      REAL MXNT,RDMX,RD,FC,CP


!.....RD AND RDMX ARE SET TO 1.0 FEET, WHICH IS ABOUT THE MAXIMUM DEPTH
!.....OF SIGNIFICANT BARE-SOIL SOIL EVAPORATION.
!.....THE PARAMETERS SET IN THIS SUBROUTINE ARE BASED ON USING PRIESTLY-TAYLOR
!.....PET FORMULATION. CRPMX=ALFA-COEFFICIENT TO PRIESTLY-TAYLOR PET,
!.....WHICH IS 0.9 WHEN THE SOIL SURFACE IS WET (JENSEN, AND OTHERS, 1990)
      CP    =0.9             !..= CRPMX
      RD    =12.0
      RDMX  =RD
      FC    =0.0
      MXNT  =0.0
      RETURN
      END

!..LENTILS

      SUBROUTINE LENTILS(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #14- LENTILS
!..   PLANT DATE VARIES FROM MAY TO JUNE, USE MAY 1

      REAL CRP(10), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(10), JDAY
      DATA CRP/0.0,0.0,0.50,0.81,1.11,1.12,1.11,0.96,0.0,0.0/
      DATA JDATE/1,121,125, 152, 176, 186, 191, 225, 228,366/

      CRPMX=1.12
      IF(RDMX.LT.0.0001) RDMX = 42.0
      IF(FCMX.LT.0.0001) FCMX =  1.0
!.....MXI=0.16 FROM LINSLEY, ETC.
      IF(MXI.LT.0.0001)  MXI  =  0.16

!.....AS MODIFIED BY WELUM ON 1-30-86 TO SIMULATE

      DO 100 JJ=2,10
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(JDAY.LT.186.OR.JDAY.GT.227) GO TO 120
      RD=RDMX
      FC=FCMX
      MXNT=MXI
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..SPRING WHEAT

      SUBROUTINE SPRGWT(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #15-SPRING WHEAT

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/0.0,0.0,0.28,1.25,1.31,1.25,1.10,0.0,0.0/
      DATA JDATE/0,90,91,160,172,185,195,244,366/

      CRPMX=1.31
      IF(RDMX.LT.0.0001) RDMX=42.0
      IF(FCMX.LT.0.0001) FCMX= 1.0
!.....MXI=0.16 FROM LINSLEY, ETC.
      IF(MXI.LT.0.0001)  MXI = 0.16

!......INTERPOLATE BLANNEY-CRIDDLE CROP COEFFICIENTS TO JDAY

!.....AS MODIFIED BY WELUM ON 1-30-86 TO SIMULATE
!......SPRING WHEAT, NO FALLOW HERE

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(JDAY.LT.172.OR.JDAY.GT.195) GO TO 120
      RD  =RDMX
      FC  =FCMX
      MXNT=MXI
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END


!..SMALL VEGTABLES (BROCCOLI-CAULFLOWER-CABBAGE CALIFORNIA ENVIRONMENT

      SUBROUTINE SMALVEG(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #17-SMALL VEGTABLES-CALIF. 135 DAY GROWING SEASON, PLANTED SEPT 1

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP  /1.05,1.05,0.95,0.0,0.0, 0.7, 0.7, 1.05, 1.05/
      DATA JDATE/ 1,   4,  19,  20, 243, 244, 279,  329, 366/

      CRPMX=1.05
      IF(RDMX.LT.0.0001) RDMX= 19.0
      IF(FCMX.LT.0.0001) FCMX=  0.8
      IF(MXI.LT.0.0001)  MXI =  0.1

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..COTTON-TEXAS

      SUBROUTINE COTTON(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #18-COTTON-TEXAS, PLANT APRIL 1, 180-DAY GROW, 220-225 FOR AZ/CA
!..    Texas AM & FAO info.Note  150-day grow also used for texas so 180 gives more et

      REAL CRP(10), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(10), JDAY
      DATA CRP/ 0.0,0.0,.25,.35,.45, 1.1, 1.1, .6, 0.0,0.0/
      DATA JDATE/1, 90,  91,121, 151,171, 226,  271,272,366/

      CRPMX=1.1
      IF(RDMX.LT.0.0001) RDMX=60.0
      IF(FCMX.LT.0.0001) FCMX= 1.0
      IF(MXI.LT.0.0001)  MXI = 0.1

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,10
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..MINT-NORTHERN MID-LATITUDES 

      SUBROUTINE MINT(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #19-MINT, MAY 7 106 DAYS ABOUT AUG 20 END

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0, 0.6,0.70, 1.18,1.20,1.20,0.0,0.0/
      DATA JDATE/1,  126, 127,150,  157, 212, 232, 233,366/

      CRPMX=1.20
      IF(RDMX.LT.0.0001) RDMX=31.0
      IF(FCMX.LT.0.0001) FCMX= 1.0
      IF(MXI.LT.0.0001)  MXI = 0.13

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..GRAPES CALIFORNIA

      SUBROUTINE GRAPECAL(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #20-GRAPES CALIFORNIA, MARCH 1-SEPT 21 206 DAYS

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0, 0.3,0.3, 0.7,0.7, 0.45,0.0, 0.0/
      DATA JDATE/1,  59, 60,  80, 130, 264, 265, 267,  366/

      CRPMX=0.7
      IF(RDMX.LT.0.0001) RDMX=66.0
      IF(FCMX.LT.0.0001) FCMX= 0.7
      IF(MXI.LT.0.0001)  MXI = 0.08

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..GRAPES WASHINGTON-OREGON

      SUBROUTINE GRAPEWAOR(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #21-GRAPES WA-OREGON, APRIL 1-OCT 25 (1st soilevp to drop leaf)

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0,0.30, 0.3, 0.92, 0.92, 0.45, 0.0,  0.0/
      DATA JDATE/1,  90, 91,  121,  175,  240,  298,  299,  366/

      CRPMX=0.92
      IF(RDMX.LT.0.0001) RDMX=66.0
      IF(FCMX.LT.0.0001) FCMX= 0.7
      IF(MXI.LT.0.0001)  MXI = 0.08

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!
!..HOPS WASHINGTON-IDAHO-OREGON
!
      SUBROUTINE HOPS(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #22-HOPS WA-ID-OR, APRIL 1-SEPT 1

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0, 0.3,0.35, 1.07, 1.07, 0.85,0.0, 0.0/
      DATA JDATE/1,  90, 91,  116, 156,   236, 249, 250,  366/

      CRPMX=1.07
      IF(RDMX.LT.0.0001) RDMX=48.0
      IF(FCMX.LT.0.0001) FCMX= 0.75
      IF(MXI.LT.0.0001)  MXI = 0.10

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END


!..OLIVES

      SUBROUTINE OLIVE(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #23 OLIVES-CALIFORNIA, MARCH 1 INITIAL GROWTH DEC 3 HARVEST/DORMANT
!..   ASSUMES 60 PERCENT COVERAGE BY CANOPY (FAO), LOSE LEAVES SO START BARE

      REAL CRP(9), CRPMX, LEAF(9)
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0, 0.65,0.65, .45, .45, 0.65,0.0, 0.0/
      DATA JDATE/1,  59,   60,  99,  188, 247, 337, 338, 366/
      DATA LEAF/0.0,0.0,  0.0, 1.0, 1.0, 1.0, 1.0,0.0, 0.0/

      CRPMX=0.65
      IF(RDMX.LT.0.0001) RDMX=67.0
      IF(FCMX.LT.0.0001) FCMX= 0.60
      IF(MXI.LT.0.0001)  MXI = 0.15

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      CRPT=LEAF(J)
      CRPY=LEAF(J-1)
      FACT=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..CITRUS

      SUBROUTINE CITRUS(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #24 CITRUS, JANUARY 1- DEC 31 GROWTH
!..   ASSUMES 50 PERCENT COVERAGE BY CANOPY AND AVERAGES VALUES FOR W/ GROUND COVER AND W/0
!..                                       THE RESULTING AVERAGES ARE LIKE: W/  GRND COV 70% CANOPY
!..                                                                  LIKE: W/0 GRND COV 70% CANOPY

      REAL CRP(5), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(5), JDAY
      DATA CRP/  0.0, .75,  .7,   .7,   .72/
      DATA JDATE/1,   60,   150,  270,  366/

      CRPMX=0.75
      IF(RDMX.LT.0.0001) RDMX=35.0
      IF(FCMX.LT.0.0001) FCMX= 0.55
      IF(MXI.LT.0.0001)  MXI = 0.15

!......INTERPOLATE FAO CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,5
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      RD=RDMX
      FC=FCMX
      MXNT=MXI
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..SOYBEANS MID-LATITUDES 

      SUBROUTINE SOY(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)
                       

!.....LANDUSE #25-SOY, MAY 7--140 DAYS ABOUT SEPT 24 (267) END

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/  0.0,0.0, 0.3,0.3, 1.0, 1.0, 0.5, 0.0, 0.0/
      DATA JDATE/1,  126, 127,147, 182, 242, 267, 268, 366/

      CRPMX=1.0
      IF(RDMX.LT.0.0001) RDMX=51.0
      IF(FCMX.LT.0.0001) FCMX= 1.0
      IF(MXI.LT.0.0001)  MXI = 0.14

!......INTERPOLATE FAO/COLO/SE CROP COEFFICIENTS TO JDAY

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..APPLES--  AGRIMET/FAO INFO 

      SUBROUTINE APPLES (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #26-APPLE TREES W/ GROUND COVER

      REAL  MXI,MXNT
      REAL CRP(17),CRPMX 
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(17), JDAY
      DATA CRP/0.0,0.0,.2,.25,.34,.48,.66,.83,.92,.98, 1.1, 1.1,.72,.38,
     +        .20,0.0,0.0/
      DATA JDATE/1,59, 60, 70, 80, 97,114,132,150,170, 180,280, 290,310,
     +        329,330,366/

      CRPMX=1.1
      IF(RDMX.LT.0.00001) RDMX = 64.0
      IF(FCMX.LT.0.00001) FCMX =  0.65
!.....ASSUME SAME AS DECIDUOUS FOREST =.05 (+.05 FOR GRASS GROUND COVER)
!.....AFTER ZINKE.
      IF(MXI.LT.0.00001)  MXI =0.1

      DO 100 JJ=2,17
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
         J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END


!..SORGHUM--  U NEBRAS/TEXAS AM/FAO INFO 

      SUBROUTINE SORGHUM (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #27-SORGHUM, W/ 140 DAY GROWING SEASON, VARIES BY REGION (SHORTER)
!..                        ASSUMES PLANTING ON MAY 20

      REAL  MXI,MXNT
      REAL CRP(15),CRPMX 
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(15), JDAY
      DATA CRP/0.0,0.0,.4,.4, .55,.60,.80, .95,1.1,1.1, 1., .9,.85,.0,
     +        0.0/
      DATA JDATE/1,139,140,148,160,170,177,195,200,205,211,237,255,280,
     +        366/

      CRPMX=1.1
      IF(RDMX.LT.0.00001) RDMX = 54.0
      IF(FCMX.LT.0.00001) FCMX =  0.75
      IF(MXI.LT.0.00001)  MXI =0.1

      DO 100 JJ=2,15
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
         J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END

!
!..PASTURE GRASS
!

      SUBROUTINE PASTURE (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #28-PASTURE, ASSUMES START MARCH 1 END OCT 31: MID-LATITUDES
!..   KC  INFO:  FAO

      REAL CRP(10)
      REAL MXI,MXNT,RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPMX,FACT

      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(10), JDAY

      DATA CRP/ 0.0,0.0,0.25,.63,0.80, 0.80,0.60, 0.4, 0.0, 0.0/
      DATA JDATE/1 ,59, 60,  70, 110,  283,  288, 304,305, 366/

!.....THIS SUBROUTINE COMPUTES CROP COEFFICIENTS, CP, ROOT DEPTH: RD,
!.....FOLIAR COVER: FC, AND "POTENTIAL" INTERCEPTION: MXNT, FOR JDAY (calendar)
      
      CRPMX=0.80

      IF (fcmx.LT.0.00001) fcmx = 1.0

!.....USE REDUCED ALFALFA INTERCEPTION (> GRASS) FROM LINSLEY,KOHLER,PAULUS,1975
      IF (mxi.LT.0.00001)  mxi = 0.08

      IF (rdmx.LT.0.00001) rdmx = 24.0

      DO 100 JJ=2,10
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
       J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))

      IF(SUMCP.LT.0.0) RETURN

      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT

      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END

!..BEANS

      SUBROUTINE BEAN(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #29- BEANS  FAO,AGRIMET, ARS, CA WAT
!..   PLANT DATE VARIES FROM MAY TO JUNE, USE MAY 15
!..USE 45 DAYS FOR INITIAL THROUGH CROP DEVELOPMENT (AVE OF FRESH/DRY BEANS)
!..USE 100 DAYS FOR GROWTH SLIGHT LONGER THAN FRESH SLIGHT SHORTER THAN DRY

      REAL CRP(11), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(11), JDAY
      DATA CRP/0.0,0.0,0.20,0.31,0.65, 1.1,0.98,0.85,0.62,0.0,0.0/
      DATA JDATE/1,134,135, 145, 150,  180, 215,225, 235,236,366/

      CRPMX=1.1
      IF(RDMX.LT.0.0001) RDMX = 37.0
      IF(FCMX.LT.0.0001) FCMX =  0.95
      IF(MXI.LT.0.0001)  MXI  =  0.1

      DO 100 JJ=2,11
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!..PEAS

      SUBROUTINE PEA(JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #30- PEAS  FAO
!..   PLANT DATE VARIES FROM MARCH TO MAY, USE APRIL 15
!..USE 100 DAYS FOR GROWTH 

      REAL CRP(9), CRPMX
      REAL MXI,MXNT
      REAL RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPT,CRPY,FACT
      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(9), JDAY
      DATA CRP/0.0,0.0,0.5,0.5,1.12,1.12, 0.30,0.0,0.0/
      DATA JDATE/1,104,105, 130, 155, 190, 205,206,366/

      CRPMX=1.12
      IF(RDMX.LT.0.0001) RDMX = 34.0
      IF(FCMX.LT.0.0001) FCMX =  0.9
      IF(MXI.LT.0.0001)  MXI  =  0.07

      DO 100 JJ=2,9
      IF(JDAY.GT.JDATE(JJ))  GO TO 100
        J=JJ
      GO TO 110
100   CONTINUE
  110 CRPT=CRP(J)
      CRPY=CRP(J-1)
      CP=CRPY+(JDAY-JDATE(J-1))*(CRPT-CRPY)/(JDATE(J)-JDATE(J-1))
      IF(SUMCP.LT.0.0) RETURN
      FACT=CP/CRPMX
      RD=RDMX*FACT
      FC=FCMX*FACT
      MXNT=MXI*FACT
120   IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)
      RETURN
      END

!
!..ASPARAGUS GRASS
!

      SUBROUTINE ASPARAGUS (JDAY,RDMX,FCMX,MXI,RD,FC,MXNT,CP,APMULT,
     +                  IRSRT1,IREND1,IRSRT2,IREND2,IRSCD,SUMCP)

!.....LANDUSE #31-ASPARAGUS, ASSUMES START MARCH 1 END OCT 31: MID-LATITUDES
!..   EQUIV-MEDIT. WITH A 245 DAY GROWING SEASON
!..   ASSUMES FULLY DEVELOPED PER. CROP, NOT NEWLY PLANTED
!..   KC  INFO:  UCD, BCMINAG, FAO using * 0.83 for adjust al

!..LARGE ROOT DEPTH BUT MOST EXTRACTION IN UPPER PART, USE EXPON. ROOT DEPTH
!..EXTRACTION OF WATER (PARAMETER:IROOT > 0)

!..DEFAULT ROOT DEPTH IS 72 INCHES 
!..     LITERATURE GIVES WATER REQUIR RANGE: 30CM-300CM,THESE KCs MID-LAT GIVE 45CM

      REAL CRP(11)
      REAL MXI,MXNT,RDMX,FCMX,RD,FC,CP,APMULT,SUMCP,CRPMX,FACT

      INTEGER IRSRT1,IREND1,IRSRT2,IREND2,IRSCD
      INTEGER J, JJ, JDATE(11), JDAY

      DATA CRP/ 0.0,0.0,0.15,0.20,0.25, 0.72, 0.72,0.3, 0.15, 0.0, 0.0/
      DATA JDATE/1 ,59,  60,  90,  120, 140,  210, 240, 304,  305, 366/

!.....THIS SUBROUTINE COMPUTES CROP COEFFICIENTS, CP, ROOT DEPTH: RD,
!.....FOLIAR COVER: FC, AND "POTENTIAL" INTERCEPTION: MXNT, FOR JDAY (calendar)
      
      CRPMX=0.72

      IF (fcmx.LT.0.00001) fcmx = 0.9

!.....USE REDUCED ALFALFA INTERCEPTION (> GRASS) FROM LINSLEY,KOHLER,PAULUS,1975
      IF (mxi.LT.0.00001)  mxi = 0.08

      IF (rdmx.LT.0.00001) rdmx = 72.0

      DO 100 JJ=2,11
      IF(JDAY.GT.JDATE(JJ)) GO TO 100
       J=JJ
      GO TO 110
  100 CONTINUE
  110 CP=CRP(J-1)+(JDAY-JDATE(J-1))*(CRP(J)-CRP(J-1))/
     .(JDATE(J)-JDATE(J-1))

      IF(SUMCP.LT.0.0) RETURN

      FACT=CP/CRPMX
      RD=RDMX
      FC=FCMX*FACT
      MXNT=MXI*FACT

      IF(IRSRT1.EQ.0) RETURN
      IF(JDAY.LT.IRSRT1. OR.JDAY.GT.IREND2) RETURN
      IF(JDAY.LT.IRSRT2.AND.JDAY.GT.IREND1) RETURN
      IF(IRSCD.EQ.1) APMULT=CP/SUMCP
      IF(IRSCD.EQ.0) APMULT=1.0/(IREND1-IRSRT1+IREND2-IRSRT2+2)

      RETURN
      END
