!***********************************************************************
!
!                      BASIN_PARMS_DPM.F
!
!              Main basin-parameter declare routine
!
!   Establish the basin parameters for the model and writes to file to see
!   the input parameters


!     version: 1.0 (vaccaro/bauer)


      integer function basin_parms_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer basdecl, basinit, retval

      integer nhru, nsoils, nmonths

      integer hru_soil(MAXHRU), cov_type(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real hru_elev(MAXHRU),   hru_area(MAXHRU), hru_slope(MAXHRU)
      real hru_aspect(MAXHRU), hru_ylat(MAXHRU), hru_xlong(MAXHRU)
      real hru_appld(MAXHRU),  wght(MAXHRU), hru_mon_ppt(MAXHRU,MAXMO)


      save nhru, nsoils, nmonths, wght
      save hru_elev,  hru_area,  hru_slope, hru_aspect
      save hru_xlong, hru_ylat,  hru_appld, hru_irr_methd
      save hru_soil,  cov_type,  hru_mon_ppt
      
      retval = 0

      if(arg.eq.'declare') then
        retval = basdecl(wght)
      
      else if(arg.eq.'initialize') then
        retval = basinit(wght, hru_elev,hru_area, hru_slope,
     +    hru_aspect,hru_xlong, hru_ylat,hru_soil,cov_type,hru_appld, 
     +               hru_irr_methd,hru_mon_ppt, nhru, nsoils, nmonths)

      end if

!******Debug level print
      call dpint4('End of basin, retval = ', retval, 1, 2)

      basin_parms_dpm = retval

      return
      end


!***********************************************************************
!     basdecl: Declares basin and HRU physical parameters 
!              

!     basdecl - set up parameters


      integer function basdecl(wght)

      include 'fmodules.inc'

      real  wght(MAXHRU)

      basdecl = 1


!..HRU/CELL/MRU DIMENSIONED (nhru)
      

      if(declvar('basin', 'wght', 'nhru', MAXHRU, 'real',  
     +   'HRU area as fraction of total area',
     +   'fraction',wght).ne.0) return

      if(declparam('basin', 'hru_elev', 'nhru', 'real',
     +   '0.', '-300.', '15000',
     +   'Mean elevation for each HRU',
     +   'Mean elevation for each HRU',
     +   'feet').ne.0) return
     
      if(declparam('basin', 'hru_area', 'nhru', 'real',
     +   '1.0', '0.001', '1e+09',
     +   'HRU area',
     +   'HRU area',
     +   'square miles').ne.0) return

      if(declparam('basin', 'hru_slope', 'nhru', 'real',
     +   '0.', '0.', '90.',
     +   'HRU slope in degrees from horizontal',
     +   'HRU slope in degrees from horizontal',
     +   'degrees (1-90)')
     +   .ne.0) return

      if(declparam('basin', 'hru_aspect', 'nhru', 'real',
     +   '0.', '0.', '360.',
     +   'HRU aspect in degrees from north: 0-360',
     +   'HRU aspect in degrees from north: 0-360',
     +   'degrees').ne.0) return

      if(declparam('basin', 'hru_ylat', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU latitude of centroid, lat or state plane',
     +   'latitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_xlong', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU longitude of centroid, long or state plane',
     +   'longitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_soil', 'nhru', 'integer',
     +   '1', '1', '200',
     +   'HRU soil type',
     +   'HRU soil type',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_appld', 'nhru', 'real',
     +   '0.', '0.', '72.',
     +   'Average application rate of irrigation water for hru',
     +   'Average application rate of irrigation water for hru',
     +   'inches').ne.0) return

      if(declparam('basin', 'hru_irr_methd', 'nhru', 'integer',
     +   '0', '0', '1',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_mon_ppt', 'nhru,nmonths', 'real',
     +   '0.', '0.', '50.',
     +   'Mean monthly precipitation for each hru/mru',
     +   'Mean monthly precipitation for each hru/mru',
     +   'inches').ne.0) return

      basdecl = 0

      return
      end


!**********************************************************************
!     basinit - get input parameters and then initialize 
!               write-out basic input information
            

      integer function basinit(wght, hru_elev,hru_area, hru_slope,
     +  hru_aspect,hru_xlong, hru_ylat,hru_soil,cov_type,hru_appld, 
     +             hru_irr_methd,hru_mon_ppt,nhru, nsoils, nmonths) 

      include 'fmodules.inc'

      integer nhru, nsoils, nmonths
      integer i, ns, ncnt, nscnt(200)

      character*90 buffer

      real basin_area

      integer hru_soil(MAXHRU), cov_type(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real hru_elev(MAXHRU),   hru_area(MAXHRU), hru_slope(MAXHRU)
      real hru_aspect(MAXHRU), hru_ylat(MAXHRU), hru_xlong(MAXHRU)
      real hru_appld(MAXHRU), wght(MAXHRU), hru_mon_ppt(MAXHRU,MAXMO)

      basinit = 1

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nsoils = getdim('nsoils')
      if(nsoils.eq.-1) return

      nmonths = getdim('nmonths')
      if(nmonths.eq.-1) return

!..GET THE PARAMETERS FOR THE MODEL, most OTHER PARAMETERS ARE MODULE DEPENDENT

!..SINGLE DIMENSIONS, SCALARS

!..HRU/CELL/MRU DIMENSIONED (MAXHRU)
      
      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

      if(getparam('basin', 'hru_elev',   MAXHRU, 'real',    hru_elev)
     +   .ne.0) return
     
      if(getparam('basin', 'hru_area',   MAXHRU, 'real',    hru_area)
     +   .ne.0) return

      if(getparam('basin', 'hru_slope',  MAXHRU, 'real',   hru_slope)
     +   .ne.0) return

      if(getparam('basin', 'hru_aspect', MAXHRU, 'real',   hru_aspect)
     +  .ne.0) return

      if(getparam('basin', 'hru_soil',   MAXHRU, 'integer',  hru_soil)
     +   .ne.0) return

      if(getparam('basin', 'hru_appld',  MAXHRU, 'real',    hru_appld)
     +   .ne.0) return
 
      if(getparam('basin','hru_irr_methd',MAXHRU,'integer',
     +   hru_irr_methd)   .ne.0) return

!.. mean monthly precipitation

      if(getparam('basin', 'hru_mon_ppt',   MAXHRU*MAXMO, 'real',
     +  hru_mon_ppt) .ne.0) return

!..HRU X,Y'S

      if (getparam ('basin', 'hru_xlong', MAXHRU, 'real',    hru_xlong)
     +    .ne.0) return

      if (getparam ('basin', 'hru_ylat',  MAXHRU, 'real',    hru_ylat)
     +    .ne.0) return


!..Calculate the basin area based on the CELL/MRU/HRU AREAS

      basin_area = 0.
      do 100 i=1,nhru
        hru_area(i)=hru_area(i) 
        basin_area = basin_area + hru_area(i)
  100 continue

      WRITE(BUFFER,1001)  nhru
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)  
      CALL OPSTR(BUFFER)

      WRITE(BUFFER,1002) basin_area
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)  
      CALL OPSTR(BUFFER)

      WRITE(BUFFER,1003)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1004)
      CALL OPSTR(BUFFER)

      DO 50 I=1,nhru

      WRITE(BUFFER,1005)I,hru_xlong(I),hru_ylat(I),hru_area(I),
     .   hru_soil(I),cov_type(I),hru_elev(I),hru_slope(I),
     .   hru_aspect(I),hru_APPLD(I), hru_irr_methd(i)

!      WRITE(BUFFER,1000)  
      CALL OPSTR(BUFFER)

!..CALCULATE AREA WEIGHT FOR LATER USE

50    WGHT(i)=hru_area(I)/basin_area

!.... WRITE OUT THE SOIL INDEX NUMBERS USED AND THE NUMBER OF CELLS

      WRITE(BUFFER,1000)  

      DO 60 I=1,nsoils
60    NSCNT(I)=0
      DO 61 I=1,nhru
      NS=hru_soil(I)
61    NSCNT(NS)=NSCNT(NS)+1
      WRITE(BUFFER,1006)
      CALL OPSTR(BUFFER)      
      WRITE(BUFFER,1007)
      CALL OPSTR(BUFFER)      

      NCNT=0
      DO 62 I=1,nsoils
       NCNT=NCNT+NSCNT(I)
       WRITE(BUFFER,1008) I,NSCNT(I)
62     CALL OPSTR(BUFFER)

      WRITE(BUFFER,1009)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1010) NCNT,nhru
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)  
      CALL OPSTR(BUFFER)

1000  FORMAT(' ')
1001  FORMAT(2X,'THE NUMBER OF CELLS IN MODEL    (nhru)     =',I5)
1002  FORMAT('  TOTAL BASIN AREA AS SUM OF CELL AREAS=',F6.2)
1003  FORMAT('  ** THE FOLLOWING ARE ATTRIBUTES FOR EACH CELL: **')
1004  FORMAT('  CELL#         X          Y       AREA  NSOIL LND  ELEV  
     +SLOPE  ASPCT IRRATE IRR METDH')
1005  FORMAT(2X,I4,2X,2F12.4,1x,F9.2,I4,I5,F7.0,F6.1,F6.0,F6.0,I5)
1006  FORMAT(2X,'THE FOLLOWING TABULATES THE NUMBER OF CELLS FOR EACH SO
     +IL TYPE')
1007   FORMAT('  SOIL NUMBER      # OF BLOCKS')
1008  FORMAT(7X,I4,14X,I5)
1009  FORMAT('   ____________      _________')
1010  FORMAT('                     SUM=',I5,'   SHOULD EQUAL nhru=',I4)

      basinit = 0

      return
      end


