!***********************************************************************

!                     GRID_MET_DPM.F  

!   Declares, initializes, and then interpolates, for each day, the:
!    daily precipitation, maximum and minimum temperature, solar radiation, 
!    and thrufall from observing sites to NHRUs
  
!     version: 1.0 (vaccaro/bauer)


      integer function grid_met_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer griddecl, gridinit, gridrun, retval

      integer nhru, nrain, ntemp, nthru, nsol, nmonths
      integer cov_type(MAXHRU), covthru(MAXTHRU)

      real   ratemn(MAXMO), ratemx(MAXMO)

      real hru_ylat(MAXHRU),  hru_xlong(MAXHRU)
      real hru_ppt(MAXHRU), hru_elev(MAXHRU), hru_solrad(MAXHRU)
      real tmaxf(MAXHRU), tminf(MAXHRU),  tmxyst(MAXHRU), tavf(MAXHRU)
      real hru_mon_ppt(MAXHRU,MAXMO)
      real tsta_x(MAXTEMP),  tsta_y(MAXTEMP), tsta_elev(MAXTEMP)
      real tnjulav(MAXTEMP), txjulav(MAXTEMP) 
      real elfac(MAXHRU,MAXTEMP)
      real psta_x(MAXRAIN),  psta_y(MAXRAIN)
      real psta_mon_ppt(MAXRAIN,MAXMO)
      real solsta_x(MAXSOL), solsta_y(MAXSOL)
      real thrusta_x(MAXTHRU), thrusta_y(MAXTHRU)
      real distp(MAXHRU,MAXRAIN),  distt(MAXHRU,MAXTEMP)
      real distr(MAXHRU,MAXSOL), disttf(MAXHRU,MAXTHRU)
      real tffrc(MAXHRU), hru_tmnjuly(MAXHRU), hru_tmxjuly(MAXHRU) 


      save  nrain, ntemp, nthru, nsol, nmonths, nhru
      save  tffrc, tmxyst,tavf
      save  ratemn, ratemx, hru_ylat, hru_xlong, cov_type
      save  tsta_x,  tsta_y, tsta_elev, tnjulav, txjulav, elfac
      save  psta_x,  psta_y, psta_mon_ppt, solsta_x, solsta_y
      save  thrusta_x, thrusta_y, covthru
      save  tmaxf, tminf, hru_tmxjuly, hru_tmnjuly
      save  distp, distt, distr, disttf
      save  hru_mon_ppt, hru_ppt, hru_elev, hru_solrad

      retval = 0

      if(arg.eq.'declare') then
        retval = griddecl(hru_ppt,hru_solrad, tmaxf, tminf, tavf,tffrc,
     +                    hru_tmxjuly, hru_tmnjuly,tmxyst)

      
      else if(arg.eq.'initialize') then
        retval = gridinit(nhru,nrain,ntemp,nthru,nsol,nmonths,
     +    cov_type,covthru, ratemn, ratemx,hru_ylat,hru_xlong,
     +  hru_elev,hru_mon_ppt,tsta_x,tsta_y,tsta_elev, tnjulav,
     +   txjulav,psta_x,psta_y,psta_mon_ppt,solsta_x,solsta_y,
     +   thrusta_x,thrusta_y,tffrc,distp,distt,distr,disttf,elfac,
     +                             hru_tmnjuly,hru_tmxjuly,tmxyst)


      else if(arg.eq.'run') then
        retval = gridrun(nhru,nrain,ntemp,nthru,nsol,nmonths,
     +                    ratemn,ratemx,elfac,psta_mon_ppt,
     +                 hru_mon_ppt,distp, distt,distr,disttf,
     +       hru_ppt,hru_solrad,tmaxf,tminf,tffrc,tmxyst,tavf)
 
      end if

!******Debug level print
      call dpint4('End of grid_met, retval = ', retval, 1, 2)

      grid_met_dpm = retval

      return
      end

!***********************************************************************
!     GRIDDECL: Declares  parameters for griding meteorological data
!              
!***********************************************************************

!     griddecl - declare hru/cell values of weather info and set up parameters


      integer function griddecl(hru_ppt, hru_solrad, tmaxf, tminf,tavf,
     +                           tffrc, hru_tmxjuly, hru_tmnjuly,tmxyst)

      include 'fmodules.inc'

      real hru_ppt(MAXHRU), hru_solrad(MAXHRU), tffrc(MAXHRU)
      real tmaxf(MAXHRU),   tminf(MAXHRU),      tavf(MAXHRU)
      real tmxyst(MAXHRU)
      real hru_tmnjuly(MAXHRU), hru_tmxjuly(MAXHRU) 

      griddecl = 1

!...Variables that are interpolated for this module

      if(declvar('grid', 'hru_solrad', 'nhru', MAXHRU, 'real',
     +   'Daily incoming solar rad for each of the cells-hrus-mrus',
     +   'cal/cm2/dy',hru_solrad).ne.0) return

      if(declvar('grid', 'hru_ppt', 'nhru', MAXHRU, 'real',
     +   'Daily precipitation for each of the cells/hrus/mrus',
     +   'inches',hru_ppt).ne.0) return

      if(declvar('grid', 'tmaxf', 'nhru', MAXHRU, 'real',
     +   'Daily maximum temperature for each of the cells/hrus/mrus',
     +   'degrees',tmaxf).ne.0) return

      if(declvar('grid', 'tminf', 'nhru', MAXHRU, 'real',
     +   'Daily minimum temperature for each of the cells/hrus/mrus',
     +   'degrees',tminf).ne.0) return

      if(declvar('grid', 'tavf',  'nhru', MAXHRU, 'real',
     +   'Daily average temperature for each of the cells/hrus/mrus',
     +   'degrees',tavf).ne.0) return

      if(declvar('grid', 'tmxyst', 'nhru', MAXHRU, 'real',
     +   'Yesterdays daily maximum temperature for each hru/mru',
     +   'degrees',tmxyst).ne.0) return

      if (declvar('grid', 'tffrc', 'nhru', MAXHRU, 'real',
     +   'Thrufall for a hru interpolated from thrufall site'//
     +  'Set = -1 identifying that hru does not have a thrufall site'//
     +   ' with same landuse to interpolate from',
     +   'fraction', tffrc).ne.0) return

      if(declvar('grid', 'hru_tmxjuly', 'nhru', MAXHRU, 'real',
     +   'MRU  mean maximum July temperature used for PET calculations',
     +   'degrees',hru_tmxjuly ).ne.0) return

      if(declvar('grid', 'hru_tmnjuly', 'nhru', MAXHRU, 'real',
     +   'MRU  mean minimum July temperature used for PET calculations',
     +   'degrees', hru_tmnjuly).ne.0) return


!..MODEL CALCULATED DISTANCE-WEIGHTING INTERPOLATION PARAMETERS

!.....DISTANCE BETWEEN STATIONS AND HRU, IN FEET IF LAT-LON WERE
!.....USED TO LOCATE CELLS (KZONE>0), OTHERWISE IN USER UNITS.


      if (declparam ('grid', 'distp', 'nhru,nrain', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Inverse of square of distance between hru and precip site',
     +   'Inverse of square of distance between hru and precip site',
     +   'none').ne.0) return

      if (declparam ('grid', 'distt', 'nhru,ntemp', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Inverse of distance between hru and temperature site',
     +   'Inverse of distance between hru and temperature site',
     +   'none').ne.0) return

      if (declparam ('grid', 'distr', 'nhru,nsol', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Inverse of distance between hru and solar radiation site',
     +   'Inverse of distance between hru and solar radiation site',
     +   'none').ne.0) return

      if (declparam ('grid', 'disttf', 'nhru,nthru', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Inverse of distance between hru and thrufall collection site',
     +   'Inverse of distance between hru and thrufall collection site',
     +   'none').ne.0) return

      if(declparam('grid', 'elfac', 'nhru,ntemp', 'real',
     +   '0.0', '0.0', '10.0',
     +   'Elevation difference mru to each ntemp temp. sites',
     +   'Elevation/1000. for lapse: temperature-gages to '//
     +   'each hru-- accounts for differences in elevation'//
     +   'although /1000., meters or feet as elev are OK',
     +   'feet/feet')
     +   .ne.0) return

      if(declparam('weather', 'ratemn', 'nmonths', 'real',
     +   '2.0', '0.0', '4.',
     +   'Minimum monthly temperature lapse rate: for each month',
     +   'Minimum monthly temperature lapse rate: for each month',
     +   'degrees/1000 ft').ne.0) return

      if(declparam('weather', 'ratemx', 'nmonths', 'real',
     +   '2.0', '0.0', '5.',
     +   'Maximum monthly temperature lapse rate: for each month',
     +   'Maximum monthly temperature lapse rate: for each month',
     +   'degrees/1000 ft').ne.0) return

      if (declparam ('weather', 'tsta_x', 'ntemp', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each temper. station-state plane or decimal degrees',
     +   'X for each temper. station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tsta_y', 'ntemp', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each temper. station-state plane or decimal degrees',
     +   'Y for each temper. station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tsta_elev', 'ntemp', 'real',
     +   '0.', '-300.', '15000.',
     +   'Temperature station elevation',
     +   'Elevation of each temperature '//
     +   'measurement station',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tnjulav', 'ntemp', 'real',
     +   '40.', '33.', '80.',
     +   'AVERAGE July minimum temperature for each temp. station',
     +   'AVERAGE July minimum temperature for each temp. station',
     +   'degrees').ne.0) return

      if (declparam ('weather', 'txjulav', 'ntemp', 'real',
     +   '70.', '40.', '110.',
     +   'AVERAGE July maximum temperature for each temp. station',
     +   'AVERAGE July maximum temperature for each temp. station',
     +   'degrees').ne.0) return

      if (declparam ('weather', 'psta_x', 'nrain', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each precip station (state plane or decimal degrees)',
     +   'X for each precip station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'psta_y', 'nrain', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each precip station (state plane or decimal degrees)',
     +   'Y for each precip station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'psta_mon_ppt',
     +   'nrain,nmonths', 'real',
     +   '0.', '0.', '60.',
     +   'Average monthly precip at each station',
     +   'Average monthly precip at each station',
     +   'inches').ne.0) return

      if (declparam ('weather', 'thrusta_x', 'nthru', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each thrufall station (state plane or decimal degrees)',
     +   'X for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'thrusta_y', 'nthru', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'covthru', 'nthru', 'integer',
     +   '1', '1', '31',
     +   'Land cover for each thrufall station',
     +   'Land cover for each thrufall station',
     +   'none').ne.0) return

      if (declparam ('weather', 'solsta_x', 'nsol', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each solar rad station-state plane or decimal degrees',
     +   'X for each solar rad station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'solsta_y', 'nsol', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

!..PARAMETERS FROM OTHER MODULES

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_mon_ppt', 'nhru,nmonths', 'real',
     +   '0.', '0.', '50.',
     +   'Mean monthly precipitation for each hru/mru',
     +   'Mean monthly precipitation for each hru/mru',
     +   'inches').ne.0) return

      if(declparam('basin', 'hru_ylat', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU latitude of centroid, lat or state plane',
     +   'latitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_xlong', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU longitude of centroid, long or state plane',
     +   'longitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_elev', 'nhru', 'real',
     +   '0.', '-300.', '15000',
     +   'Mean elevation for each HRU',
     +   'Mean elevation for each HRU',
     +   'feet').ne.0) return
     
      griddecl = 0

      return
      end


!**********************************************************************
!**********************************************************************
!     gridinit - set initial interpolation values for each nhru
!               


      integer function gridinit(nhru,nrain,ntemp,nthru,nsol,nmonths,
     +           cov_type,covthru, ratemn, ratemx,hru_ylat,hru_xlong,
     +hru_elev,hru_mon_ppt,tsta_x,tsta_y, tsta_elev, tnjulav,
     + txjulav,psta_x,psta_y,psta_mon_ppt,solsta_x,solsta_y,thrusta_x,
     + thrusta_y,tffrc,distp,distt,distr,disttf,elfac,hru_tmnjuly,
     + hru_tmxjuly, tmxyst)

      include 'fmodules.inc'

      
      integer nhru, nrain, ntemp, nthru, nsol, nmonths
      integer i, j, iws
      integer cov_type(MAXHRU), covthru(MAXTHRU)

      real  wt, pwtnavj, pwtxavj, dis
      real  ratemn(MAXMO), ratemx(MAXMO)

      real hru_ylat(MAXHRU),  hru_xlong(MAXHRU)
      real hru_elev(MAXHRU),  tmxyst(MAXHRU)
      real hru_mon_ppt(MAXHRU,MAXMO) 
      real tsta_x(MAXTEMP),   tsta_y(MAXTEMP), tsta_elev(MAXTEMP)
      real tnjulav(MAXTEMP),  txjulav(MAXTEMP) 
      real psta_x(MAXRAIN),   psta_y(MAXRAIN)
      real psta_mon_ppt(MAXRAIN,MAXMO)
      real solsta_x(MAXSOL), solsta_y(MAXSOL)
      real thrusta_x(MAXTHRU), thrusta_y(MAXTHRU), tffrc(MAXHRU)
      real distp(MAXHRU,MAXRAIN),  distt(MAXHRU,MAXTEMP)
      real distr(MAXHRU,MAXSOL), disttf(MAXHRU,MAXTHRU)
      real elfac(MAXHRU,MAXTEMP)
      real hru_tmnjuly(MAXHRU), hru_tmxjuly(MAXHRU) 

      gridinit = 1

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nrain = getdim('nrain')
      if(nrain.eq.-1) return

      ntemp = getdim('ntemp')
      if(ntemp.eq.-1) return

      nsol = getdim('nsol')
      if(nsol.eq.-1) return

      nthru = getdim('nthru')
      if(nthru.eq.-1) return

      nmonths = getdim('nmonths')
      if(nmonths.eq.-1) return

!..GET THE PARAMETERS

!..MONTHLY MINIMUM AND MAXIMUM LAPSE RATES FOR STUDY AREA
!.....ZERO LAPSE RATES ARE CODED IF CONSIDERED UNIMPORTANT.

      if(getparam('weather', 'ratemn',  MAXMO, 'real',
     +   ratemn).ne.0) return

      if(getparam('weather', 'ratemx',  MAXMO, 'real',
     +   ratemx).ne.0) return

!..HRU information

!.. X,Y'S

      if (getparam ('basin', 'hru_xlong', MAXHRU, 'real', hru_xlong)
     +   .ne.0) return

      if (getparam ('basin', 'hru_ylat',  MAXHRU, 'real', hru_ylat)
     +   .ne.0) return

!..landuse/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.. mean monthly precipitation

      if(getparam('basin', 'hru_mon_ppt',   MAXHRU*MAXMO, 'real',
     +  hru_mon_ppt) .ne.0) return

!.. mean elevation

      if(getparam('basin', 'hru_elev',   MAXHRU, 'real',    hru_elev)
     +   .ne.0) return
     

!.. TEMPERATURE STATION INFO

!.....GET THE X,Y,ALTITUDE,AND AVG-JUL MIN-MAX OF TEMP STATIONS

      if (getparam ('weather', 'tsta_x',   MAXTEMP,  'real', tsta_x)
     +   .ne.0) return

      if (getparam ('weather', 'tsta_y',   MAXTEMP,  'real', tsta_y)
     +   .ne.0) return

      if (getparam ('weather', 'tsta_elev', MAXTEMP, 'real', tsta_elev)
     +   .ne.0) return

      if (getparam ('weather', 'tnjulav',   MAXTEMP, 'real', tnjulav)
     +   .ne.0) return

      if (getparam ('weather', 'txjulav',   MAXTEMP, 'real', txjulav) 
     +   .ne.0) return

!..PRECIP STATION INFO

!.....GET THE X,Y LOCATIONS(LON-LAT DECIMAL. DEG. OR X-Y FEET) AND MEAN monthly 
!.....PRECIP FOR PRECIP STATIONS.

      if (getparam ('weather', 'psta_x',    MAXRAIN,  'real', psta_x)
     +   .ne.0) return

      if (getparam ('weather', 'psta_y',    MAXRAIN,  'real', psta_y)
     +   .ne.0) return

      if (getparam ('weather', 'psta_mon_ppt', MAXRAIN*MAXMO, 'real',
     +   psta_mon_ppt) .ne.0) return

!..THRUFALL STATION INFO

!.....GET THE X,Y LOCATIONS(LON-LAT DECIMAL DEG. OR X-Y FEET) AND LANDUSE
!.....FOR THROUGHFALL STATIONS.

      if (getparam ('weather', 'thrusta_x', MAXTHRU, 'real', thrusta_x)
     +   .ne.0) return

      if (getparam ('weather', 'thrusta_y', MAXTHRU, 'real', thrusta_y)
     +   .ne.0) return

      if (getparam ('weather', 'covthru',  MAXTHRU,  'integer', covthru)
     +   .ne.0) return

!..SOLAR RADIATION STATION INFO

! ....GET THE X,Y OF SOLAR RADIATION DATA SITES 

      if (getparam ('weather', 'solsta_x', MAXSOL,   'real', solsta_x)
     +   .ne.0) return

      if (getparam ('weather', 'solsta_y', MAXSOL,   'real', solsta_y)
     +   .ne.0) return


!.....DISTANCE BETWEEN STATIONS AND HRU, IN FEET IF LAT-LON WERE
!.....USED TO LOCATE CELLS (KZONE>0), OTHERWISE IN USER UNITS.



!.....FIRST ZERO ALL ARRAYS and INITILAIZE TEMPMAXYESTERDAY=32 degrees f

      DO 5  I=1,NHRU

      tmxyst(i)=0.0

      DO 5  J=1,Nrain
5     distp(I,J)=0.0

      DO 6  I=1,NHRU
      DO 6  J=1,Ntemp
6     distt(I,J)=0.0

      if(nsol.gt.0) then
       DO 7  I=1,NHRU
       DO 7  J=1,Nsol
7      distr(I,J)=0.0
      end if

      DO 9  I=1,NHRU

      TFFRC(I)= -1.0

       if(nthru.gt.0) then
        DO 8  J=1,Nthru
8       disttf(I,J)=0.0
       endif
9     continue


! ...NOW CALCULATE DISTANCES BETWEEN EACH type of meteorological SITE AND ALL HRUs

!..PRECIPITATION sites

      DO 18  i=1,NHRU
! ...LOOP THROUGH precipitation STATIONS FOR EACH HRU
      DO 18 IWS=1,Nrain
      DIS=SQRT((hru_xlong(i) - psta_x(iws))**2 +
     +          (hru_Ylat(i) - psta_y(iws))**2)
      DISTp(i,iws)=1. / DIS**2
18    CONTINUE

!..TEMPERATURE sites

      DO 19  i=1,NHRU
! ...LOOP THROUGH temperature STATIONS FOR EACH HRU
      DO 19 IWS=1,Ntemp

!..elevation differences for lapse rates, if higher hru will be negative
!..lapse rates input as absolute values

      elfac(i,iws)=(tsta_elev(iws)-hru_elev(i))/1000.
      DIS=SQRT((hru_xlong(i) - tsta_x(iws))**2 +
     +          (hru_Ylat(i) - tsta_y(iws))**2)
      DISTT(i,iws)=1. / DIS
19    CONTINUE


! NOW calculate ave july temps for mrus/hrus for Jensen-Haise PET calculations

      DO 21 I=1,NHRU
      WT=0.0
      PWTnavj=0.0
      PWTxavj=0.0
      DO 20 IWS=1,NTEMP

      pwtnavj=pwtnavj + (tnjulav(Iws)+elfac(i,Iws)*ratemn(7))
     +                                *distt(i,iws)
      pwtxavj=pwtxavj + (txjulav(Iws)+elfac(i,Iws)*ratemx(7))
     +                                *distt(i,Iws)
20    wt=wt+distt(i,iws)

      hru_tmxjuly(i)=pwtxavj/wt
      hru_tmnjuly(i)=pwtnavj/wt

21    continue




!..SOLAR radiation sites

      if(nsol.gt.0) then
       DO 22  i=1,Nhru
! ...LOOP THROUGH solar radiation STATIONS FOR EACH HRU
       DO 22 IWS=1,Nsol
       DIS=SQRT((hru_xlong(i) - solsta_x(iws))**2 +
     +          (hru_Ylat(i)  - solsta_y(iws))**2)
       DISTr(i,iws)=1. / DIS
22    CONTINUE
      end if


!.....FOR EACH NHRU FIND THRUFALL STATIONS WITH SAME LANDUSE AS NHRU FOR
!.....INTERPOLATION OF THROUGHFALL DATA TO NHRU (FROM WHICH INTERCEPTION LOSS
!.....IS CALCULATED). IF NO THROUGHFALL STATIONS ARE APPLICABLE FOR A NHRU,
!.....(BECAUSE OF either LANDUSE OR there are NO THROUGHFALL STATIONS)
!.....THEN TFFRC(I) IS SET TO -1 AS A FLAG TO LATER CALCULATE IT IN  MODULE INTRCP_DPM
!.....IE, INSTEAD, COMPUTE INTERCEPTION LOSS.


! ...NOW DO ALL NHRUS
      if(nthru.gt.0) then
        DO 25  i=1,NHRU
! ...LOOP THROUGH thrufall STATIONS FOR EACH NHRU
        DO 24 IWS=1,Nthru
!..there may be more than one thrufall station but only one station may be applicable
!  for some hru due to landuse not being same, thus set dist=-999 to later check in 
!  gridrun

        disttf(i,iws)=-999.
        IF(covthru(IWS).NE.cov_type(i)) GO TO 24
        DIS=SQRT((hru_xlong(i) - thrusta_x(iws))**2 +
     +           (hru_Ylat(i)  - thrusta_y(iws))**2)
        DISTtf(i,iws)=1. / DIS
        tffrc(i)=0.0
24      continue
25     CONTINUE
      endif

      gridinit = 0

      return
      end

!***********************************************************************
! 
!     gridrun - Calculates the meteorolgical values for the NHRUs (MHRUs)
!

      integer function gridrun(nhru,nrain,ntemp,nthru,nsol,nmonths,
     +                            ratemn,ratemx,elfac,psta_mon_ppt,
     +                       hru_mon_ppt,distp, distt,distr,disttf,
     +               hru_ppt,hru_solrad,tmaxf,tminf,tffrc,tmxyst,tavf)


      include 'fmodules.inc'

!..INITIALIZED parameters FROM gridINIT

      integer nhru, nrain, ntemp, nthru, nsol, nmonths
      integer i, nsite

      integer nowtime(6), starttime(6), endtime(6)
      integer iyr, imo, idaymo, mostrt, dayend, endyr
      integer jday, endjday

      real ratemn(MAXMO), ratemx(MAXMO)
      real elfac(MAXHRU,MAXTEMP)

      real psta_mon_ppt(MAXRAIN,MAXMO)
      real hru_mon_ppt(MAXHRU,MAXMO)
      real obs_tmax(MAXTEMP),   obs_tmin(MAXTEMP)
      real obs_precip(MAXRAIN), obs_solrad(MAXSOL),obs_thru(MAXTHRU)

      real distp(MAXHRU,MAXRAIN),  distt(MAXHRU,MAXTEMP)
      real distr(MAXHRU,MAXSOL),  disttf(MAXHRU,MAXTHRU)

      real hru_ppt(MAXHRU), hru_solrad(MAXHRU)
      real tmaxf(MAXHRU), tminf(MAXHRU), tavf(MAXHRU)
      real tffrc(MAXHRU), tmxyst(MAXHRU)

      real r1, r2, pw, wtmn, wtmx, d, fact, pwtn, pwtx, rtn, rtx
      real altdif, tmndif, tmxdif, wt

      gridrun = 1

      call dattim('start', starttime)
      call dattim('now',   nowtime)
      call dattim('end',   endtime)

      iyr    = nowtime(1)
      imo    = nowtime(2)
      idaymo = nowtime(3)
      mostrt = starttime(2)
      dayend = endtime(3)
      endyr  = endtime(1)

      jday   = julian('now', 'calendar')
      endjday = julian('end', 'calendar')
 
      if(getvar('obs',  'tmax',   MAXTEMP,   'real',  obs_tmax)
     +   .ne.0) return

      if(getvar('obs',  'tmin',   MAXTEMP,   'real',  obs_tmin)
     +   .ne.0) return
    
      if(getvar('obs',  'precip', MAXRAIN,   'real',  obs_precip)
     +   .ne.0) return

      if(getvar('obs',  'solrad', MAXSOL,   'real',  obs_solrad)
     +   .ne.0) return

      if(getvar('obs',  'thrufall', MAXTHRU,  'real',  obs_thru)
     +   .ne.0) return

!..save yesterday's tmax for snow computations

      do 1 i=1,nhru
1     tmxyst(i)=tmaxf(i)

!...PRECIP USES 1/DISTANCE**2 (DISTP)  AS WEIGHT FOR EACH WEATHER STATION.
! ....DISTP FROM EACH NHRU TO EACH WEATHER STATION WAS
!.....COMPUTED IN the initialization part of module
!.....obs_precip=PRECIP AT WEATHER STATION.
!.....hru_ppt = PRECIP AT NHRU.
!....."OROGRAPHIC CORRECTION MAY ALSO BE MADE ACCORDING TO LONG-TERM MONTHLY PRECIP
!.....AT WEATHER STATIONS AND AT NHRUS.


!.....INTERPOLATE NATURAL PRECIP, IF OBSERVED PRECIP IS MISSING (NEGATIVE VALUE SKIP THAT STATION)

      DO 20  i=1,NHRU
      WT=0.0
      PW=0.0
      DO 15  nsite=1,NRAIN

      IF(obs_precip(nsite) .LT. -0.0000005) GO TO 12   !....SKIP IF NO OBSERVED DATA FOR THIS DAY & SITE       

      FACT=1.0
      D=DISTP(i,nsite)
      R1=hru_mon_ppt(i,imo)
      R2=psta_mon_ppt(nsite,imo)
      IF (R1.LT.0.000001.OR.R2.LT.0.000001)  GO TO 10
      FACT=R1/R2
10    PW=PW+obs_precip(nsite)*D*FACT
      WT=WT+D

12    CONTINUE

15    CONTINUE

      hru_ppt(i)=PW/WT

20    CONTINUE


!...TEMPERATURE USES 1/(DISTANCE TO STATION) AS WEIGHT FOR EACH STATION.
!.....DISTANCES FROM EACH CELL TO EACH STATION(DISTT) WAS COMPUTED in initalization
!.....obs_tmin, obs_tmax = MIN, MAX TEMPS. AT WEATHER STATIONS.
!.....TMINF, TMAXF       = MIN, MAX TEMPS AT NHRUS.
!.....LAPSE RATES(ratemn, ratemx) ADJUSTMENTS ARE ALSO MADE.

!....IF OBSERVED TEMPERATURE IS MISSING (NEGATIVE VALUE <= -99.0 SKIP THAT STATION)

      rtn=ratemn(imo)
      rtx=ratemx(imo)

      DO 30  i=1,NHRU
      WTMN=0.0
      WTMX=0.0
      PWTN=0.0
      PWTX=0.0
      DO 25  nsite=1,ntemp
      D=DISTT(i,nsite)
      TMNDIF=0
      TMXDIF=0
      ALTDIF=elfac(i,nsite)
      IF(RTN.GT.0.0) TMNDIF=ALTDIF*RTN
      IF(RTX.GT.0.0) TMXDIF=ALTDIF*RTX
       
      IF(obs_tmin(nsite) .LE. -99.0) GO TO 22   !..SKIP TMIN FOR THIS SITE IF MISSING TODAY

      PWTN=PWTN+(obs_tmin(nsite)+TMNDIF)*D
      WTMN =WTMN+D

22    CONTINUE

      IF(obs_tmax(nsite) .LE. -99.0) GO TO 25   !..SKIP TMAX FOR THIS SITE IF MISSING TODAY

      PWTX=PWTX+(obs_tmax(nsite)+TMXDIF)*D
      WTMX=WTMX+D

25    CONTINUE

      TMINf(i)=PWTN/WTMN
      TMAXf(i)=PWTX/WTMX
      tavf(i) = (TMINf(i) + TMAXf(i))*0.5

30    CONTINUE


!.. DAILY VALUES OF INCOMING SOLAR RADIATION 
!.. USES 1/(DISTANCE TO STATION) AS WEIGHT FOR EACH STATION.
!.....obs_solrad = SOLAR RADIATION AT WEATHER STATIONS.
!.....hru_solrad = SOLAR RADIATION AT NHRUS.

      DO 40  i=1,NHRU
      WT=0.0
      PW=0.0
      hru_solrad(i)=0.0
      if(nsol.gt.0) then
        DO 35  nsite=1,Nsol
        D=DISTr(i,nsite)
         PW=PW+obs_solrad(nsite)*D
         WT=WT+D
35       CONTINUE
         hru_solrad(i)=PW/WT
      ENDIF
40    CONTINUE

!.. INTERPOLATE DAILY VALUES OF THROUGHFALL (AS FRACTION
!.....OF PRECIP) AT DATA COLLECTION STATIONS TO NHRUS,
!.....FROM WHICH INTERCEPTION LOSS WILL BE CALCULATED.
!.....USES 1/(DISTANCE TO STATION) AS WEIGHT FOR EACH STATION.
!.....DISTANCES FROM EACH CELL TO EACH STATION WITH SAME LANDUSE (DISTTF)
!.....WAS COMPUTED IN the initialization part of this module
!.....obs_thru = THROUGHFALL (AS FRACTION OF PRECIP) AT DATA COLLECTION STATIONS.
!.....  THESE FRACTIONS ARE
!.......INTERPOLATED TO THE BLOCKS AND LATER MULTIPLIED BY PRECIPITATION
!.......AT THE BLOCK TO GET THROUGHFALL AMOUNTS. THIS PREVENTS THE POSSIBILITY
!.......OF THROUGHFALL EXCEEDING PRECIPITATION
!.....TFFRC = THROUGHFALL (AS FRACTION OF PRECIP) AT NHRUS.
!.....FOR NHRUS HAVING NO THROUGHFALL DATA STATIONS FROM WHICH TO INTERPOLATE,
!.....TFFRC WAS SET = -1.0 IN initialization, AND INTERCEPTION WILL, INSTEAD,
!.....BE LATER COMPUTED BY SUBROUTINE INTRCP in the process module.
!.......SUBROUTINE INTRCP BASED ON  MAXIMUM DAILY MOISTURE CAPACITY
!.......ON FOLIAGE, DAILY PRECIP, AND DAILY PET.


      DO 55  i=1,NHRU
      IF(TFFRC(i).LT.0.0) GO TO 55
      WT=0.0
      PW=0.0
      DO 50  nsite=1,Nthru
      D=DISTTF(i,nsite)
      IF (D.lt.-99.) GO TO 50
      PW=PW+obs_thru(nsite)*D
      WT=WT+D
50    CONTINUE
      TFFRC(i)=PW/WT
55    CONTINUE

      gridrun = 0

      RETURN
      END


