!***********************************************************************
!
!                     INTERCEPT_DPM.F  
!
!.....MODULE to calculate interception
!......COMPUTE intercepted PART OF PRECIPITATION (hru_intercpt) AT GRIDS 
!......COMPUTE thrufall PART OF PRECIPITATION (hru_thrufall) AT GRIDS 
!......COMPUTE evaporated PART OF INTERCEPTION (hru_evapinter) AT GRIDS 
!.......REDUCE POTENTIAL ET (hru_potet) BY AMOUNT OF INTERCEPTED
!..            save this reduced pet in var: hru_adjustpet
!.......MOISTURE ON FOLIAGE (hru_intercept+hru_canopystor).
!.......THE AMOUNT REDUCED WILL DEPEND ON VALUES OF pet AND total canopy water.
!.......hru_canopystor IS ANY INTERCEPTED MOISTURE THAT HAS NOT YET BEEN
!.......EVAPORATED AS OF YESTERDAY, MXNT IS MAXIMUM AMOUNT OF INTERCEPTION
!.......FOR THIS hru/mru/cell (cov_type) FOR THIS DAY OF GROWING SEASON,
!.......mxntr IS MAXIMUM AMOUNT OF mxnt THAT IS POSSIBLE FOR TODAY, hru_ppt IS
!.......IS THE PRECIPITATION FOR THIS mru/hru,  hru_intercpt=REDUCED BY INTERCEPTION,
!.......AND PTN IS THE AMOUNT OF PET REQUIRED TO EVAPORATE THE
!.......INTERCEPTED MOISTURE. IT IS ALWAYS GE 0.0 AND IS ALGEBRAICALLY
!.......SUBTRACTED FROM PET AT EACH BLOCK. IF NO PRECIP, JUST EVAPORATE.


!     version: 1.0 (vaccaro/bauer)


      integer function intercept_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer interceptdecl, interceptinit, interceptrun, retval

      integer nhru, nlands, ncoef, cov_type(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real hru_thrufall(MAXHRU),   hru_intercpt(MAXHRU)
      real hru_canopystor(MAXHRU), hru_evapinter(MAXHRU)
      real hru_chnginter(MAXHRU),  hru_adjustpet(MAXHRU)
      real hru_appld(MAXHRU),      hru_irrigation(MAXHRU)

      save nhru, nlands, ncoef, cov_type
      save hru_thrufall,  hru_intercpt,  hru_canopystor
      save hru_chnginter, hru_adjustpet, hru_evapinter
      save  hru_appld, hru_irr_methd, hru_irrigation

      retval = 0

      if(arg.eq.'declare') then
        retval = interceptdecl(hru_thrufall,hru_intercpt,hru_adjustpet,
     +       hru_canopystor,hru_evapinter,hru_chnginter,hru_irrigation)
      
      else if(arg.eq.'initialize') then
        retval = interceptinit(nhru, nlands, ncoef, cov_type,
     +                     hru_appld, hru_irr_methd, hru_canopystor)

      else if(arg.eq.'run') then
        retval = interceptrun(nlands, nhru, ncoef, cov_type,
     +                   hru_thrufall,  hru_intercpt,  hru_canopystor,
     +                   hru_evapinter, hru_adjustpet, hru_chnginter,
     +                   hru_appld, hru_irr_methd, hru_irrigation)
      

      end if

!******Debug level print
      call dpint4('End of intercept_dpm, retval = ', retval, 1, 2)

      intercept_dpm = retval

      return
      end

!***********************************************************************
!     interceptdecl: Declares 
!   


!     interceptdecl - set up parameters


      integer function interceptdecl(hru_thrufall, hru_intercpt,
     + hru_adjustpet,hru_canopystor, hru_evapinter,hru_chnginter,
     +                                            hru_irrigation)

      include 'fmodules.inc'

      real hru_thrufall(MAXHRU),   hru_intercpt(MAXHRU)
      real hru_canopystor(MAXHRU), hru_evapinter(MAXHRU)
      real hru_chnginter(MAXHRU),  hru_adjustpet(MAXHRU)
      real hru_irrigation(MAXHRU)      

      interceptdecl = 1

!..new variables for this module

      if(declvar('intrcp', 'hru_thrufall', 'nhru', MAXHRU, 'real',
     +   'MRU  thrufall for day, based on thrufall data or calculated',
     +   'inches',hru_thrufall).ne.0) return

      if(declvar('intrcp', 'hru_intercpt', 'nhru', MAXHRU, 'real',
     +   'MRU  interception for day:  thrufall data or calculated',
     +   'inches',hru_intercpt).ne.0) return

      if(declvar('intrcp', 'hru_canopystor', 'nhru', MAXHRU, 'real',
     +   'Amount of water stored in foliar cover/canopy for day',
     +   'inches',hru_canopystor).ne.0) return

      if(declvar('intrcp', 'hru_evapinter', 'nhru', MAXHRU, 'real',
     +   'Amount of intercepted water evaporated from the canopy day',
     +   'inches',hru_evapinter).ne.0) return

      if(declvar('intrcp', 'hru_chnginter', 'nhru', MAXHRU, 'real',
     +   'Change in intercepted water from yesterday day',
     +   'inches',hru_chnginter).ne.0) return

      if(declvar('intrcp', 'hru_adjustpet', 'nhru', MAXHRU, 'real',
     +   'Potential evapotranspiration for hru adjusted as used'//
     +   ' due to reductions by water budget componenet use',
     +   'inches',hru_adjustpet).ne.0) return

      if(declvar('intrcp', 'hru_irrigation', 'nhru', MAXHRU, 'real',
     +   'Amount of irrigation for a hru based in hru_appld'//
     +   ' and irr method (hru_irr-methd:=0, abv canopy=intercept',
     +   'inches',hru_irrigation).ne.0) return

!..declare paremeters

      if(declparam('basin', 'hru_appld', 'nhru', 'real',
     +   '0.', '0.', '72.',
     +   'Average application rate of irrigation water for hru',
     +   'Average application rate of irrigation water for hru',
     +   'inches').ne.0) return

      if(declparam('basin', 'hru_irr_methd', 'nhru', 'integer',
     +   '0', '0', '1',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return

      interceptdecl = 0

      return
      end


!**********************************************************************
!     interceptinit - get input  parameters, calculate,  and then initialize 
!               

      integer function interceptinit(nhru, nlands, ncoef, cov_type,
     +                    hru_appld, hru_irr_methd,  hru_canopystor)

      include 'fmodules.inc'
      
      integer nhru, nlands, ncoef, cov_type(MAXHRU), i
      integer hru_irr_methd(MAXHRU)

      real hru_canopystor(MAXHRU),  hru_appld(MAXHRU)

      interceptinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

!..landuse/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.. irrigation application rate and method

      if(getparam('basin', 'hru_appld',   MAXHRU, 'real',  hru_appld)
     +   .ne.0) return

      if(getparam('basin', 'hru_irr_methd', MAXHRU, 'integer', 
     +    hru_irr_methd) .ne.0) return

       do 100 i=1,nhru
100    hru_canopystor(i) = 0.0

      interceptinit = 0

      RETURN
      END

!***********************************************************************
! 
!     interceptrun - 
!
!.....EVAPORATION OF INTERCEPION (evapinter): USE THROUGHFALL DATA FOR THIS CELL
!.....OR CALCULATE. IF THROUGHFALL DATA IS READ IN, evapinter=ppt-thrufall,
!.....AND REDUCE pet BY evapinter/1.26 BECAUSE 1.26*pet-evapinter=1.26*"LEFTOVER pet"
!.....IF LEFTOVER pet IS NEGATVE.IT WILL BE SET TO 0.0.
!.....(I.E. FOR DOUGLAS FIR FOREST IN WESTERN WASHINGTON
!.... INTERCEPTION GREATLY EXCEEDS RADIATION-METHOD PET IN WINTER),
!.....IF evapinter IS COMPUTED: 1) intercept=AMOUNT OF PRECIP THAT IS INTRCEPTED, ALL OF
!.....WHICH MAY OR MAY NOT BE EVAPORATED, SOME STORED TILL NEXT DAY (canopystor);
!.....2)SAVE NEW canopystor.
!.....IF thrufall IS READ IN intercpt=evapinter, canopystor=0 : ASSUME no irrigation


      integer function interceptrun(nlands, nhru, ncoef, cov_type,
     +               hru_thrufall,  hru_intercpt,  hru_canopystor, 
     +               hru_evapinter, hru_adjustpet, hru_chnginter,
     +                   hru_appld, hru_irr_methd, hru_irrigation)

      include 'fmodules.inc'

      integer nlands, nhru, ncoef, cov_type(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real hru_appld(MAXHRU),      hru_irrigation(MAXHRU)     

      real coefs(MAXLANDS,MAXCOEFS)
      real hru_ppt(MAXHRU), hru_potet(MAXHRU), tffrc(MAXHRU)

      real hru_thrufall(MAXHRU),   hru_intercpt(MAXHRU) 
      real hru_canopystor(MAXHRU), hru_evapinter(MAXHRU)
      real hru_adjustpet(MAXHRU),  hru_chnginter(MAXHRU)

!..temp variables

      integer i, landcover
      real remnew, ptn, mxnt, mxntr, irrquant, totwater

      interceptrun = 1

      if(getvar('grid',  'hru_ppt',    MAXHRU,    'real',  hru_ppt)
     +   .ne.0) return

      if(getvar('potet', 'hru_potet',  MAXHRU,   'real',  hru_potet)
     +   .ne.0) return

      if(getvar('grid',    'tffrc',    MAXHRU,    'real',    tffrc)
     +  .ne.0) return

      if(getvar('cropcof', 'coefs',  MAXLANDS*MAXCOEFS, 'real', coefs)
     +  .ne.0) return

      do 1000 i=1, nhru

        hru_intercpt(i)  = 0.0
        hru_thrufall(i)  = 0.0
        hru_evapinter(i) = 0.0
        hru_chnginter(i) = 0.0
        hru_irrigation(i)= 0.0
        hru_adjustpet(i) = hru_potet(i)

        irrquant = 0.0

      landcover = cov_type(i)
      mxnt  = COEFS(landcover,3)

      IF(landcover.eq.10) go to 1000    ! WATER           - NO INTERCEPTION

      IF(landcover.EQ.13. OR. landcover.eq.16 )  then  ! BARE SOIL/IMPERVIOUS  - NO INTERCEPTION
         hru_thrufall(i)  = hru_ppt(i)
         go to 1000
      END IF
        
      IF(TFFRC(i).GT.-1) THEN                                     !...FIRST THEN

         hru_thrufall(i)  = TFFRC(i)   * hru_ppt(i)
         hru_evapinter(i) = hru_ppt(i) - hru_thrufall(i)
         hru_intercpt(i)  = hru_evapinter(i)
      hru_adjustpet(i) = AMAX1((hru_potet(i)-hru_evapinter(i)/1.26),0.0)

      ELSE

!.... ADD IRRIGATION IF METHOD <1 MEANING IRRIGATION ABOVE CANOPY BY SPRINKLERS

      IF(hru_appld(i).GT.0.00001.and.hru_irr_methd(i).LT.1) THEN !..irrgatn then
      hru_irrigation(i)=  hru_appld(i)* COEFS(landcover,5)
      irrquant = hru_irrigation(i)
      END IF

         IF(hru_ppt(i).GT.0.0 .OR. hru_canopystor(i).GT.0.0 .OR. 
     +                                      irrquant.gt.0.0) THEN  !..SECOND THEN

!..DETERMINE IF THERE IS PRECIP TO INTERCEPT

         IF(hru_ppt(i).gT.0.000001.OR.irrquant.gt.0.000001) THEN    !..THIRD THEN 

!..FIND MAXIMUM AMOUNT OF MOISTURE THAT CAN BE INTERCEPTED

           MXNTR = MXNT - hru_canopystor(i)
           IF(MXNTR.LT.0.0) MXNTR=0.0

!..IF PRECIP (PPT) TODAY FOR THIS BLOCK THEN FIND AMOUNT INTERCEPTED

           totwater =  hru_ppt(i) + irrquant
           hru_intercpt(i) = AMIN1(totwater,MXNTR )
           hru_thrufall(i) = totwater - hru_intercpt(i)


        ENDIF                                                    !..ENDIF W/ FOR THIRD THEN

!..FIND TOTAL AMOUNT OF MOISTURE NOW ON FOLIAR COVER

         PTN = hru_intercpt(i) + hru_canopystor(i)

!..FIND TOTAL EVAPORATION OF INTERCEPTED MOISTURE (MAX=ETP)

         hru_evapinter(i) = amin1(hru_potet(i),ptn)

!..REDUCE pet BY AMOUNT EVAPORATED

         hru_adjustpet(i) = hru_potet(i) - hru_evapinter(i)

!..FIND NEW AMOUNT OF REMAINING MOISTURE ON FOLIAR COVER

         REMNEW=PTN - hru_evapinter(i)

!..CALCULATE CHANGE IN INTERCEPTED MOISTURE STORAGE OF FOLIAR COVER

         hru_chnginter(i) = REMNEW - hru_canopystor(i)

!..RESET REMAINING INTERCEPTED MOSITURE VARIABLE

         hru_canopystor(i) = REMNEW

        ENDIF                                                      !..second then

      END IF                                                       !..first then

1000  continue


      interceptrun = 0

      RETURN
      END

