!***********************************************************************
!
!                     MASBAL_DPM.F  

!....MODULE TO ACCUMULATE DAILY hru/mru/cell BUDGET ITEMS AND COMPUTE
!....DAILY, MONTHLY, AND ANNUAL AVERAGES FOR THE BASIN AS A WHOLE.
!....IF STREAMFLOW DATA IS BEING USED then last part makes adjustments based
!....pn module runtru_dpm.f APPORTIONS STREAMFLOW AND
!....RECOMPUTES RECHARGE. runtru_dpm.f IS CALLED AFTER THE Process
!....LOOP AND THEREFORE MUST RECOMPUTE BASIN AVERAGES OF THE AFFECTED
!....BUDGET ITEMS. These adjustments are made to the numbers in this module
!....if there is no streamflow data input: nobs=0, and actual numbers are done

!     version: 1.0 (vaccaro/bauer)


      integer function masbal_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer masbaldecl,masbalinit,masbalrun,retval

      double precision  QBALDY(MAXBUD),QBALMO(MAXBUD),QBALYR(MAXBUD)


      integer nbuds, nobs, nhru, dsum

      real wght(MAXHRU)

      save nbuds, nobs, dsum, nhru, wght
      save QBALDY,QBALMO,QBALYR

      retval = 0

      if(arg.eq.'declare') then
        retval = masbaldecl(QBALDY, QBALMO, QBALYR)
      
      else if(arg.eq.'initialize') then
        retval = masbalinit(dsum, nobs, nbuds, nhru,
     +                             QBALDY,QBALMO,QBALYR,wght)

      else if(arg.eq.'run') then
        retval = masbalrun(QBALDY, QBALMO, QBALYR, wght,
     +                              nobs,nbuds,nhru,dsum) 

      end if

!******Debug level print
      call dpint4('End of masbal, retval = ', retval, 1, 2)

      masbal_dpm = retval

      return
      end

!***********************************************************************
!     masbaldecl: Declares variables and parameters 
!                       for daily-monthly-annual water-bugets


      integer function masbaldecl(QBALDY,QBALMO,QBALYR)


      include 'fmodules.inc'

      double precision  QBALDY(MAXBUD),QBALMO(MAXBUD),QBALYR(MAXBUD)

      masbaldecl = 1


      if(declvar('masbal', 'qbaldy', 'nbuds', MAXBUD, 'double',
     +   'Daily water balance for the modeled area',
     +   'inches',qbaldy).ne.0) return

      if(declvar('masbal', 'qbalmo', 'nbuds', MAXBUD, 'double',
     +   'Monthly water balance for the modeled area',
     +   'inches',qbalmo).ne.0) return

      if(declvar('masbal', 'qbalyr', 'nbuds', MAXBUD, 'double',
     +   'Annual water balance for the modeled area',
     +   'inches',qbalyr).ne.0) return

       if(declparam('masbal', 'dsum', 'one', 'integer',
     +   '0', '0', '1',
     +   'Check to determine if want daily water-budgets',
     +   'Check to determine if want daily water-budgets, dsum>1=yes',
     +   'none').ne.0) return

      masbaldecl = 0

      return
      end



!**********************************************************************
!     masbalinit - get input  parameters, calculate,  and then initialize 
!               
            

      integer function masbalinit(dsum, nobs, nbuds, nhru,
     +                                   QBALDY,QBALMO,QBALYR,wght)

      include 'fmodules.inc'
      
      integer nbuds, nhru, dsum, i, nobs

      real  wght(MAXHRU)
 
      character*120 buffer

      double precision  QBALDY(MAXBUD),QBALMO(MAXBUD),QBALYR(MAXBUD)

      masbalinit = 1

      nobs = getdim('nobs')
      if(nobs.eq.-1) return

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nbuds = getdim('nbuds')
      if(nbuds.eq.-1) return

!..GET parameter to determine if want daily summaries for area

      if(getparam('masbal', 'dsum',        1,  'integer',   dsum)
     + .ne.0) return

!..Area variable for weighting results

      if(getvar('basin',    'wght',     MAXHRU,    'real',  wght)
     +   .ne.0) return

           
      DO 100 i=1,nbuds
      QBALDY(I)   = 0.D0
      QBALMO(I)   = 0.D0
100   QBALYR(I)   = 0.D0

      WRITE (BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1001) DSUM
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1000)
      CALL OPSTR(BUFFER)

1000  FORMAT()
1001  FORMAT ('  PARAMETER DSUM  = ',I4,' : IF =1 PRINT REGIONAL AVERAGE
     . WATER BUDGET FOR EACH DAY, IF=0 MONTHLY SUMMARIES ONLY')

      masbalinit = 0

      return
      end

!***********************************************************************
! 
!     masbalrun - Accumulate  basin values FOR WATER BUDGET
!

!.. THIS part of the module puts the daily values of water budget 
!.. components into the masbalance for later printing out and calcs


      integer function masbalrun(QBALDY,QBALMO,QBALYR,wght,
     +                           nobs,nbuds,nhru,dsum) 

      include 'fmodules.inc'

      integer dsum, nhru, nbuds, nobs, n
      real tavf(MAXHRU), hru_petcrop(MAXHRU),hru_aetplnt(MAXHRU)
      real wght(MAXHRU), hru_potet(MAXHRU),  hru_rototal(MAXHRU)
      real hru_chngsm(MAXHRU),  hru_chnginter(MAXHRU)
      real hru_rechrge(MAXHRU), hru_ppt(MAXHRU), hru_sublmton(MAXHRU)
      real hru_pevsoil(MAXHRU), hru_actevsoil(MAXHRU)
      real hru_chngsno(MAXHRU), hru_evapinter(MAXHRU)
      real hru_obsdisch(MAXHRU), hru_lakestor(MAXHRU)
      real hru_irrigation(MAXHRU)

      double precision  QBALDY(MAXBUD),QBALMO(MAXBUD),QBALYR(MAXBUD)

      real  CHGSMROBSN, SURPLUS, DEFICIT 

      masbalrun = 1

!..Daily values from the process and other variable modules

      if(getvar('grid',    'tavf',     MAXHRU,    'real',  tavf)
     +   .ne.0) return

      if(getvar('runoff', 'hru_rototal',MAXHRU,  'real',  hru_rototal)
     +   .ne.0) return

      if(getvar('intrcp', 'hru_chnginter',MAXHRU, 'real', hru_chnginter)
     +   .ne.0) return

      if(getvar('grid',   'hru_ppt',   MAXHRU,    'real',  hru_ppt)
     +   .ne.0) return

      if(getvar('potet', 'hru_potet',  MAXHRU,   'real',  hru_potet)
     +   .ne.0) return

      if(getvar('runoff', 'hru_rechrge', MAXHRU,  'real',  hru_rechrge)
     +   .ne.0) return

      if(getvar('runtru', 'hru_obsdisch', MAXHRU, 'real',  hru_obsdisch)
     +   .ne.0) return

      if(getvar('runoff', 'hru_lakestor', MAXHRU, 'real',  hru_lakestor)
     +   .ne.0) return

      if(getvar('soilev', 'hru_pevsoil',  MAXHRU,  'real', hru_pevsoil)
     +   .ne.0) return

      if(getvar('soilev', 'hru_actevsoil', MAXHRU,'real',hru_actevsoil)
     +   .ne.0) return

      if(getvar('plantet', 'hru_petcrop',  MAXHRU,'real',  hru_petcrop)
     +   .ne.0) return

      if(getvar('plantet', 'hru_aetplnt',  MAXHRU,'real',  hru_aetplnt)
     +   .ne.0) return

      if(getvar('soilms', 'hru_chngsm',    MAXHRU, 'real', hru_chngsm)
     +  .ne.0) return

      if(getvar('snowpck', 'hru_chngsno',  MAXHRU, 'real', hru_chngsno)
     +   .ne.0) return

      if(getvar('snowpck', 'hru_sublmton', MAXHRU, 'real', hru_sublmton)
     +   .ne.0) return

      if(getvar('intrcp', 'hru_evapinter', MAXHRU, 'real',hru_evapinter)
     +   .ne.0) return

      if(getvar('intrcp','hru_irrigation',MAXHRU,'real', hru_irrigation)
     +   .ne.0) return

! .....       BUDGET ITEMS FOR BASIN AVERAGES:
! .....    1= hru_ppt(n), PRECIP AT CELLS/HRUS
! .....    2= hru_potet(n), POTENTIAL ET
! .....    3= CHANGE IN INTERCEPTED STORAGE
! .....    4= OBSERVED STREAM DISCHARGE MINUS ESTIMATED BASEFLOW
! .....    5= RECHARGE (hru_rechrge)
! .....    6= POTENTIAL SOIL EVAPORATION (hru_pevsoil)
! .....    7= ACTUAL SOIL EVAPORATION (hru_actevsoil)
! .....    8= SNOW SUBLIMATION-EVAPORATION
! .....    9= POTENTIAL CROP (PLANT) TRANSPIRATION = petplant*cropcoef
! .....   10= ACTUAL PLANT TRANSPIRATION
! .....   11= CHANGE IN SOIL MOISTURE INCLUDING SATURATION
! .....   12= EVAPORATED PORTION OF INTERCEPTION
! .....   13= CHANGE IN SNOWPACK
! .....   14= AVERAGE TEMPERATURE
! .....   15= SIMULATED RUNOFF
! .....   16= LAKE STORAGE '+' FOR DAYS WHEN OBS Q=0.0 & P-AET > 0 FOR A SURFACE WATER BODY
!             LAKE STORGAE '-' FOR DAYS WHEN OBS Q=0.0 & P-AET < 0 FOR A SURFACE WATER BODY
!             LAKE STORGAE '-' WHEN NO OBS RO: USING MODELED & P-AET < 0 FOR A SURFACE WATER BODY
! .....   17= SOIL MOISTURE DEFICIT FROM OBSERVED RUNOFF:
!               '-' NOT ENOUGH SATURATION TO SUPPLY OBSERVED STREAMFLOW
!               '+' EXCESS WATER REMAINS AFTER STREAM SUPPLIED ONLY FROM EXCESS
! .....   18=IRRIGATION WATER APPLIED (hru_irrigation)


       do 1000 n=1,nhru

!..ACCUMULATE AND SAVE DAILY BASIN AVERAGES


      IF(DSUM.LT.1)  GO TO 10
      QBALDY(1) = QBALDY(1)    + hru_ppt(n)        * wght(n)
      QBALDY(2) = QBALDY(2)    + hru_potet(n)      * wght(n)
      QBALDY(3) = QBALDY(3)    + hru_chnginter(n)  * wght(n)
      QBALDY(4) = QBALDY(4)    + hru_obsdisch(n)   * wght(n)
      QBALDY(5) = QBALDY(5)    + hru_rechrge(n)    * wght(n)
      QBALDY(6) = QBALDY(6)    + hru_pevsoil(n)    * wght(n)
      QBALDY(7) = QBALDY(7)    + hru_actevsoil(n)  * wght(n)
      QBALDY(8) = QBALDY(8)    + hru_sublmton(n)   * wght(n)
      QBALDY(9) = QBALDY(9)    + hru_petcrop(n)    * wght(n)
      QBALDY(10)= QBALDY(10)   + hru_aetplnt(n)    * wght(n)
      QBALDY(11)= QBALDY(11)   + hru_chngsm(n)     * wght(n)
      QBALDY(12)= QBALDY(12)   + hru_evapinter(n)  * wght(n)
      QBALDY(13)= QBALDY(13)   + hru_chngsno(n)    * wght(n)
      QBALDY(14)= QBALDY(14)   + tavf(n)           * wght(n)
      QBALDY(15)= QBALDY(15)   + hru_rototal(n)    * wght(n)
      QBALDY(16)= QBALDY(16)   + hru_lakestor(n)   * wght(n)
      QBALDY(18)= QBALDY(18)   + hru_irrigation(n) * wght(n)

!..ACCUMULATE AND SAVE MONTHLY BASIN AVERAGES

10    QBALMO(1) = QBALMO(1)  + hru_ppt(n)          * wght(n)
      QBALMO(2) = QBALMO(2)  + hru_potet(n)        * wght(n)
      QBALMO(3) = QBALMO(3)  + hru_chnginter(n)    * wght(n)
      QBALMO(4) = QBALMO(4)  + hru_obsdisch(n)     * wght(n)
      QBALMO(5) = QBALMO(5)  + hru_rechrge(n)      * wght(n)
      QBALMO(6) = QBALMO(6)  + hru_pevsoil(n)      * wght(n)
      QBALMO(7) = QBALMO(7)  + hru_actevsoil(n)    * wght(n)
      QBALMO(8) = QBALMO(8)  + hru_sublmton(n)     * wght(n)
      QBALMO(9) = QBALMO(9)  + hru_petcrop(n)      * wght(n)
      QBALMO(10)= QBALMO(10) + hru_aetplnt(n)      * wght(n)
      QBALMO(11)= QBALMO(11) + hru_chngsm(n)       * wght(n)
      QBALMO(12)= QBALMO(12) + hru_evapinter(n)    * wght(n)
      QBALMO(13)= QBALMO(13) + hru_chngsno(n)      * wght(n)
      QBALMO(14)= QBALMO(14) + tavf(n)             * wght(n)
      QBALMO(15)= QBALMO(15) + hru_rototal(n)      * wght(n)
      QBALMO(16)= QBALMO(16) + hru_lakestor(n)     * wght(n)
      QBALMO(18)= QBALMO(18) + hru_irrigation(n)   * wght(n)

!..ACCUMULATE AND SAVE ANNUAL BASIN AVERAGES

      QBALYR(1) = QBALYR(1)  + hru_ppt(n)          * wght(n)
      QBALYR(2) = QBALYR(2)  + hru_potet(n)        * wght(n)
      QBALYR(3) = QBALYR(3)  + hru_chnginter(n)    * wght(n)
      QBALYR(4) = QBALYR(4)  + hru_obsdisch(n)     * wght(n)
      QBALYR(5) = QBALYR(5)  + hru_rechrge(n)      * wght(n)
      QBALYR(6) = QBALYR(6)  + hru_pevsoil(n)      * wght(n)
      QBALYR(7) = QBALYR(7)  + hru_actevsoil(n)    * wght(n)
      QBALYR(8) = QBALYR(8)  + hru_sublmton(n)     * wght(n)
      QBALYR(9) = QBALYR(9)  + hru_petcrop(n)      * wght(n)
      QBALYR(10)= QBALYR(10) + hru_aetplnt(n)      * wght(n)
      QBALYR(11)= QBALYR(11) + hru_chngsm(n)       * wght(n)
      QBALYR(12)= QBALYR(12) + hru_evapinter(n)    * wght(n)
      QBALYR(13)= QBALYR(13) + hru_chngsno(n)      * wght(n)
      QBALYR(14)= QBALYR(14) + tavf(n)             * wght(n)
      QBALYR(15)= QBALYR(15) + hru_rototal(n)      * wght(n)
      QBALYR(16)= QBALYR(16) + hru_lakestor(n)     * wght(n)
      QBALYR(18)= QBALYR(18) + hru_irrigation(n)   * wght(n)
      
1000  continue

!..Check if no observed streamflow, if so return since no observed runoff
!  was allocated to blocks and no adjustments done based on allocation

      if(nobs.lt.1) then
       masbalrun = 0
       return
      end if

      if(getvar('runtru', 'chgsmrobsn',      1, 'real', chgsmrobsn)
     +  .ne.0) return

      if(getvar('runtru', 'surplus',         1, 'real',  surplus)
     +  .ne.0) return 

      if(getvar('runtru', 'deficit',         1, 'real',  deficit)
     +  .ne.0) return


! .....BUDGET ITEMS FOR BASIN AVERAGES AFFECTED BY OBSERVED STREAMFLOW ADJUSTS:
! .....   5=RECHARGE
! .....   11=CHANGE IN SOIL MOISTURE INCLUDING SATURATION
!......   17=SOIL MOISTURE DEFICIT FROM OBSERVED RUNOFF:
!               '-' NOT ENOUGH SATURATION TO SUPPLY OBSERVED STREAMFLOW
!               '+' EXCESS WATER REMAINS AFTER STREAM SUPPLIED ONLY FROM EXCESS

      QBALMO(11) = QBALMO(11) + CHGSMROBSN
      QBALMO(17) = QBALMO(17) + SURPLUS
      QBALMO(17) = QBALMO(17) + DEFICIT

      QBALYR(11) = QBALYR(11) + CHGSMROBSN
      QBALYR(17) = QBALYR(17) + SURPLUS
      QBALYR(17) = QBALYR(17) + DEFICIT

      if(DSUM.GT.0) then
 
      QBALDY(11) = QBALDY(11) + CHGSMROBSN
      QBALDY(17) = QBALDY(17) + SURPLUS
      QBALDY(17) = QBALDY(17) + DEFICIT

      endif

      masbalrun = 0


      RETURN
      END

