!***********************************************************************
!
!                     NETRAD_DPM.F  
!

!     Net Radiation declare and initialize and run module

!...COMPUTE NET RADIATION (SLRNET) FOR FIR FOREST FROM INCOMING
!...SHORTWAVE RADIATION, SLRRAD, (SOLAR + SKY REFLECTED, AS WOULD BE MEASURED
!...BY A PYRENOMETER), CAL/CM**2/DAY. FORMULAS TAKEN FROM GILES, BLACK,
!...AND SPITTLEHOUSE,1984; AND FROM SPITTLEHOUSE AND BLACK, 1981).
!...SLREXTHZ=EXTRATERRESTRIAL SOLAR RADIATION ON HORIZONTAL SURFACE.
!...SLRXFMX=MAXIMUM OBSERVED FRACTION: SLRRAD/SLREXTHZ (CLEAR SKY),
!.. VARIES SLIGHTLY WITH MONTH OF YEAR. ALSO USED FOR GRASS, WATER, SAGE,
!.. BARE SOILS, AND IMPREVIOUS SURFACES


!     version: 1.0 (vaccaro/bauer)


      integer function netrad_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer netraddecl, netradinit, netradrun, retval

      integer nhru, nmonths, cov_type(MAXHRU)

      real slrxfmx(MAXMO), hru_netrad(MAXHRU)    
 
      save nhru, nmonths,cov_type
      save slrxfmx, hru_netrad
      
      retval = 0

      if(arg.eq.'declare') then
        retval = netraddecl(hru_netrad)
      
      else if(arg.eq.'initialize') then
        retval = netradinit(nhru, nmonths, slrxfmx, cov_type)

       else if(arg.eq.'run') then
        retval = netradrun(nhru,nmonths,cov_type, slrxfmx, hru_netrad)

      end if

!******Debug level print
      call dpint4('End of net radiation, retval = ', retval, 1, 2)

      netrad_dpm = retval

      return
      end



!***********************************************************************
!     netraddecl: Declares parameters and variables for net radiation
!              
!***********************************************************************

!     netraddecl - declare variables and  parameters

      integer function netraddecl(hru_netrad)

      include 'fmodules.inc'

      real hru_netrad(MAXHRU)

      netraddecl = 1

      if(declvar('netrad', 'hru_netrad', 'nhru', MAXHRU, 'real',
     +   'Daily net radiation for each of hrus w/cover=3,10,13',
     +   'cal/cm2/dy',hru_netrad).ne.0) return

      if(declparam('netrad', 'slrxfmx', 'nmonths', 'real',
     +   '1.0', '0.20', '1.0',
     +   'MAX OF OBSERVED DAILY INCOMING SOLAR RADIATION, monthly',
     +   'MAX OF OBSERVED DAILY INCOMING SOLAR RADIATION, monthly'//
     +   'as FRACTION OF EXTRATERRESTRIAL RADIATION TO HORIZ. SURFACE',
     +   'fraction').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return


      netraddecl = 0

      return
      end

!**********************************************************************
!     netradinit - initialize parms and vars for module: net radiation

      integer function netradinit(nhru,nmonths,slrxfmx,cov_type)

      include 'fmodules.inc'

      integer nhru, nmonths, cov_type(MAXHRU)

      real slrxfmx(MAXMO)

      character*95 buffer

      netradinit = 1

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nmonths = getdim('nmonths')
      if(nmonths.eq.-1) return

!..MAXIMUM OF OBSERVED DAILY VALUES OF INCOMING SOLAR RADIATION FOR EACH MONTH
!    EXPRESSED AS FRACTION OF EXTRATERRESTRIAL RADIATION TO HORIZONTAL SURFACE

      if(getparam('netrad', 'slrxfmx',    MAXMO,  'real',  slrxfmx)
     +   .ne.0) return

!..get landuse/cover type for hru's

      if(getparam('basin',  'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return
 
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1001)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1002)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1003)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1004)  slrxfmx
      CALL OPSTR(BUFFER)

1000  FORMAT()
1001   FORMAT('  THE FOLLOWING ARE MAXIMUM OF OBSERVED DAILY VALUES OF I
     +NCOMING SOLAR RADIATION FOR EACH MONTH')
1002  FORMAT('  EXPRESSED AS FRACTION OF EXTRATERRESTRIAL RADIATION TO H
     +ORIZONTAL SURFACE')
1003  FORMAT('  JAN   FEB   MAR   APR   MAY   JUN   JUL   AUG   SEP   OC
     +T   NOV   DEC')
1004  FORMAT(12F6.2)

      netradinit = 0

      return
      end

!***********************************************************************
! 
!     netradrun - 
!

      integer function netradrun(nhru,nmonths,cov_type,
     +                                   slrxfmx,hru_netrad)

      include 'fmodules.inc'

      integer nhru, nmonths, cov_type(MAXHRU)

      real slrxfmx(MAXMO), slrexthz(MAXHRU), frcdylt(MAXHRU)
      real hru_solrad(MAXHRU), hru_netrad(MAXHRU)    
      real tmaxf(MAXHRU),      tminf(MAXHRU)

!..temps

      integer cov, imo, i, nowtime(6)
      real albedo, emveg, c, d, stefboltz, tavf, tavc, tavk
      real slrnetsw, slrnetlw, emair, slrrdmx, slrratio, stefan

      netradrun = 1

      call dattim('now',   nowtime)
      imo    = nowtime(2)

      if(getvar('grid',   'tmaxf',         MAXHRU, 'real', tmaxf)
     +   .ne.0) return

      if(getvar('grid',   'tminf',         MAXHRU, 'real', tminf)
     +   .ne.0) return

      if(getvar('grid',   'hru_solrad',    MAXHRU, 'real', hru_solrad)
     +   .ne.0) return

      if(getvar('extrad',  'slrexthz',     MAXHRU, 'real',  slrexthz)
     +   .ne.0) return

      if(getvar('extrad',  'frcdylt',      MAXHRU, 'real',  frcdylt)
     +   .ne.0) return

      ALBEDO=0.12             ! DIMENSIONLESS (+-0.02)
      EMVEG=0.96              !     "       , EMISSIVITY OF VEGETATION
      C=0.1                   !     "       , EMPIRICAL CONSTANT
      D=0.9                   !     "       ,      "    COEFFICIENT
      STEFBOLTZ=117.13E-9     ! CAL/CM**2/DAY, STEFAN-BOLTZMAN CONSTANT.

      do 1000 i=1,nhru

      cov = cov_type(i)
      hru_netrad(i) = 0.0

      if (cov.le.3 .or. cov.eq.10 .or. cov.eq.13 .or. cov.eq.16) then

!...AVERAGE TEMPERATURE FOR DAYLIGHT HOURS, CONVERT TO CELCIUS, AND
!...COMPUTE STEPHAN-BOLTZMAN BLACK-BODY RADIATION:

      TAVF=(Tminf(i)+2*Tmaxf(i))/3
      TAVC=5./9.  * (TAVF-32.)
      TAVK=TAVC+273
      STEFAN=STEFBOLTZ*TAVK**4

!...NET SHORTWAVE RADIATION:

      SLRNETSW=(1-ALBEDO) * hru_solrad(i)

!...EMISSIVITY OF AIR:

      EMAIR=1.0 - 0.261*EXP(-0.000777*TAVC**2)     ! DIMENSIONLESS

!...NET LONGWAVE RADIATION:

      SLRRDMX =SLREXTHZ(i)*SLRXFMX(imo)
      SLRRATIO=hru_solrad(i)/SLRRDMX
      SLRNETLW=FRCDYLT(i)*(C+D*SLRRATIO)*EMVEG*(EMAIR-1)*STEFAN

!...NET SHORTWAVE + NET LONGWAVE:

      hru_netrad(i) = SLRNETLW+SLRNETSW

      ENDIF

1000  continue

      netradrun = 0

      RETURN
      END

