! *************************************************************************

!                   main observed data routine

!     obs_dpm.f: fortran obs module--same as prms (in MMS) obs_ti_prms.f except
!                some observed values eliminated, such as: pan_evap
!        thrufall and baseflow added

!     version: 1.0 (vaccaro/bauer)

      integer function obs_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer retval, obsrun, obsdecl

      retval = 0

      if (arg.eq.'declare') then
         retval = obsdecl()
      else if (arg.eq.'run') then
         retval = obsrun()
      end if

!******Debug level print
      call dpint4('End of obs_dpm, retval = ', retval, 1, 2)

      obs_dpm = retval

      return
      end


! **********************************************************************

!     obsdecl - makes public variable declarations for the
!                     obs module

 
      integer function obsdecl()

      include 'fmodules.inc'

      real runoff(MAXOBS), bsflw(MAXBSFLW)
      real precip(MAXRAIN)
      real tmin(MAXTEMP), tmax(MAXTEMP)
      real solrad(MAXSOL)
      real thrufall(MAXTHRU)
      real snow(MAXSNOPIL)

      save runoff, precip, tmax, tmin
      save solrad, bsflw, thrufall, snow
     

      obsdecl = 1

      if(declvar('obs', 'runoff',  'nobs',   MAXOBS, 'real',
     +     'Observed runoff for each gage',
     +     'cfs',
     +   runoff).ne.0) return

      if(declvar('obs', 'bsflw',   'nbsflw', MAXBSFLW, 'real',
     +     'Estimated baseflow for each gage',
     +     'cfs',
     +   bsflw).ne.0) return

      if(declvar('obs', 'thrufall', 'nthru', MAXTHRU, 'real',
     +     'Fraction of total precip at gage that is thrufall',
     +     'fraction',
     +   thrufall).ne.0) return

      if(declvar('obs', 'precip',   'nrain', MAXRAIN, 'real',
     +     'Observed precip at each rain gage',
     +     'inches',
     +   precip).ne.0) return

      if(declvar('obs', 'tmin',     'ntemp',  MAXTEMP, 'real',
     +     'Observed minimum temperature',
     +     'units',
     +   tmin).ne.0) return

      if(declvar('obs', 'tmax',     'ntemp',  MAXTEMP, 'real',
     +     'Observed maximum temperature',
     +     'units',
     +   tmax).ne.0) return

      if(declvar('obs', 'solrad',   'nsol',   MAXSOL, 'real',
     +     'Observed solar radiation',
     +     'langleys',
     +   solrad).ne.0) return

      if(declvar('obs', 'snow',     'nsnow', MAXSNOPIL, 'real',
     +     'Observed snow pillow/course data',
     +     'inches',
     +   snow).ne.0) return

      obsdecl = 0

      return
      end


! ****************************************************************************

!     obsrun - runs obs module

 
      integer function obsrun()

      include 'fmodules.inc'

      integer nstep, datetime(6)
      integer julcalen, julsolar, julwater

      obsrun = 1

      if(readvar('obs','runoff').ne.0) return
      if(readvar('obs','precip').ne.0) return
      if(readvar('obs','tmin').  ne.0) return
      if(readvar('obs','tmax').  ne.0) return
      if(readvar('obs','snow').  ne.0) return
      if(readvar('obs','solrad').ne.0) return
      if(readvar('obs','bsflw'). ne.0) return
      if(readvar('obs','thrufall').ne.0) return

!     print out nstep, deltim, time and julian dates

      nstep = getstep()
      call dattim('now', datetime)
      julcalen = julian('now', 'calendar')
      julsolar = julian('now', 'solar')
      julwater = julian('now', 'water')

      call dpint4('Nstep        :', nstep, 1, 2)
      call dpint4('Date/Time    :', datetime, 6, 2)
      call dpint4('Jul Calen.   :', julcalen, 1, 2)
      call dpint4('Jul Solar    :', julsolar, 1, 2)
      call dpint4('Jul Water    :', julwater, 1, 2)

      obsrun = 0
 
      return
      end


