!***********************************************************************
!
!                     PLANTET_DPM.F  
!

!     version: 1.0 (vaccaro/bauer)


      integer function plantet_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer plantetdecl, plantetinit, plantetrun, retval

      integer nhru, nsoils, nlands, ncoef, nlayrsoil, iroot
      integer nlayer(MAXSOILS), cov_type(MAXHRU), hru_soil(MAXHRU)

      real  slmfac(MAXSOILS),  soil_type(MAXSOILS)
      real  avlcap(MAXSOILS),  spcyld(MAXSOILS)
      real  hru_petplnt(MAXHRU),hru_petcrop(MAXHRU),hru_aetplnt(MAXHRU)

      save  nhru, cov_type, hru_petplnt, hru_aetplnt, hru_petcrop
      save  hru_soil, avlcap, spcyld, slmfac, soil_type, iroot 
      save  nsoils, nlayer, nlands, ncoef, nlayrsoil 

      retval = 0

      if(arg.eq.'declare') then
        retval = plantetdecl(hru_petplnt, hru_petcrop,
     +                       hru_aetplnt)

      else if(arg.eq.'initialize') then
        retval = plantetinit(nhru,nsoils,nlands,ncoef,cov_type,
     +          hru_soil,slmfac,avlcap,soil_type,nlayer,iroot,
     +          nlayrsoil,spcyld)

      else if(arg.eq.'run') then
        retval = plantetrun(nhru,hru_petplnt,hru_aetplnt,nlayrsoil,
     +            hru_petcrop,cov_type,hru_soil,avlcap,slmfac,
     +   soil_type,nsoils,nlayer,nlands,iroot,ncoef,spcyld)
      
      end if

!******Debug level print
      call dpint4('End of plantet_dpm, retval = ', retval, 1, 2)

      plantet_dpm = retval

      return
      end

!***********************************************************************
!     plantetdecl: Declares 
!   


!     plantetdecl - set up parameters


      integer function plantetdecl(hru_petplnt, hru_petcrop,
     +                             hru_aetplnt)


      include 'fmodules.inc'

      real hru_petplnt(MAXHRU),hru_petcrop(MAXHRU),hru_aetplnt(MAXHRU)

      plantetdecl = 1


      if(declvar('plantet', 'hru_petplnt', 'nhru', MAXHRU, 'real',
     +   'Potential plant transpiration',
     +   'inches',hru_petplnt).ne.0) return

      if(declvar('plantet', 'hru_petcrop', 'nhru', MAXHRU, 'real',
     +   'Potential plant transpiration adjusted for crop growth',
     +   'inches',hru_petcrop).ne.0) return

      if(declvar('plantet', 'hru_aetplnt', 'nhru', MAXHRU, 'real',
     +   'Actual plant transpiration',
     +   'inches',hru_aetplnt).ne.0) return

!..soil parameters

      if(declparam('plantet', 'slmfac', 'nsoils', 'real',
     +   '0.0', '0.0', '0.9',
     +   'Soil limiting transpiration coefficient for a soil',
     +   'Soil limiting transpiration coefficient for a soil, when'//
     +   'multiplied by soil moisture is maximum daily transpiration'//
     +   'if =0.0 uses empirical relations in model, in inches/day',
     +   'in/day').ne.0) return

      if(declparam('soilms', 'avlcap', 'nsoils', 'real',
     +   '0.05', '0.', '.7',
     +   'Available water capacity for a soil association',
     +   'Available water capacity for a soil association'//
     +   'as decimal fraction for the layers (6 inches thick)',
     +   'none').ne.0) return

      if(declparam('soilms', 'spcyld', 'nsoils', 'real',
     +   '0.20', '0.02', '.45',
     +   'Specific yield of soils for a soil association',
     +   'Specific yield of soils for a soil association, equivalent'//
     +   ' to total effective porosity, as decimal fraction by volume',
     +   'none').ne.0) return
     
      if(declparam('soilms', 'soil_type', 'nsoils', 'real',
     +   '2.0', '1.0', '3.0',
     +   'Soil texture for a soil association',
     +   'Soil texture for a soil association: 1=sand,2=silt,3=clay'//
     +   'Decimal values for mixtures, eg, 1.5=silty sand',
     +   'none').ne.0) return

      if(declparam('soilms', 'nlayer', 'nsoils', 'integer',
     +   '4', '1', '14',
     +   'Number of 6" layers for a soil association',
     +   'Number of 6" layers for a soil association, will be limited'//
     +   'by the depth of the root zone during calculations',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_soil', 'nhru', 'integer',
     +   '1', '1', '200',
     +   'HRU soil type',
     +   'HRU soil type',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 land uses/covers',
     +   'none').ne.0) return

      if(declparam('cropcof', 'iroot', 'one', 'integer',
     +   '0', '0', '1',
     +  'Distribution of root mass in root zone: linear or exponential',
     + 'Distribution of root mass in root zone: linear or exponential'//
     +   'iroot=0=linear, iroot>0=exponential: expon gives more rech'//
     +   'because plant moisture extraction ~ to root mass distribtion',
     +   'none').ne.0) return

      plantetdecl = 0

      return
      end



!**********************************************************************
!     plantetinit - get input  parameters, calculate,  and then initialize 
!               

      integer function plantetinit(nhru,nsoils,nlands,ncoef,cov_type,
     +          hru_soil,slmfac,avlcap,soil_type,nlayer,iroot,
     +          nlayrsoil,spcyld)

      include 'fmodules.inc'
      
      integer nhru, nsoils, nlands, ncoef, iroot, nlayrsoil
      integer cov_type(MAXHRU), hru_soil(MAXHRU), nlayer(MAXSOILS)

      real  slmfac(MAXSOILS),  soil_type(MAXSOILS)
      real  avlcap(MAXSOILS),  spcyld(MAXSOILS)

      plantetinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nsoils = getdim('nsoils')
      if(nsoils.eq.-1) return

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

      nlayrsoil = getdim('nlayrsoil')
      if(nlayrsoil.eq.-1) return

!..land use/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.. Get HRU/MRU soil information for initializing

      if(getparam('basin', 'hru_soil',   MAXHRU,  'integer', hru_soil)
     +   .ne.0) return

      if(getparam('plantet', 'slmfac',   MAXSOILS, 'real',   slmfac)
     +   .ne.0) return

      if(getparam('soilms',   'avlcap',  MAXSOILS, 'real',   avlcap)
     +   .ne.0) return

      if(getparam('soilms', 'spcyld',    MAXSOILS, 'real',   spcyld)
     +   .ne.0) return

      if(getparam('soilms', 'soil_type', MAXSOILS, 'real', soil_type)
     +   .ne.0) return

      if(getparam('soilms', 'nlayer',    MAXSOILS, 'integer', nlayer)
     +   .ne.0) return

      if(getparam('cropcof', 'iroot',      1,      'integer',  iroot)
     +   .ne.0) return

      plantetinit = 0

      RETURN
      END

!***********************************************************************
! 
!                          plantetrun 
!

      integer function plantetrun(nhru,hru_petplnt,hru_aetplnt,
     +     nlayrsoil,hru_petcrop,cov_type,hru_soil,avlcap,slmfac,
     +   soil_type,nsoils,nlayer,nlands,iroot,ncoef,spcyld)

      include 'fmodules.inc'

      integer nhru, nsoils, nlands, ncoef, iroot, nlayrsoil
      integer nlayer(MAXSOILS), cov_type(MAXHRU), hru_soil(MAXHRU)

      real  slmfac(MAXSOILS),  soil_type(MAXSOILS)
      real  avlcap(MAXSOILS),  spcyld(MAXSOILS)
      real  sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real  unsatcur(MAXHRU), storcur(MAXHRU), excess(MAXHRU)
      real  hru_petplnt(MAXHRU),hru_petcrop(MAXHRU),hru_aetplnt(MAXHRU)
      real  coefs(MAXLANDS,MAXCOEFS), tavf(MAXHRU), hru_petloss(MAXHRU)
      real  hru_snow(MAXHRU),  hru_adjustpet(MAXHRU)


!..TEMP variables

      integer landcov, ns, i, nltot, nlroot, n, is, it, i1
      real rd, cp, rdmx, st, slf, slthk, wc, crpcur, sc
      real smtotroot, satmaxroot, unsatmaxroot, aetlmt, trnspr
      real anlr, r1, r2, wgt, ws, ep, ep1, ep2, maxpet

      plantetrun = 1

      if(getvar('soilms', 'sms',     MAXHRU*MAXLAYERS, 'real',    sms)
     +  .ne.0) return

      if(getvar('soilms', 'storpor', MAXHRU*MAXLAYERS,  'real', storpor)
     +  .ne.0) return

      if(getvar('soilms', 'unsatcur',    MAXHRU,      'real', unsatcur)
     +   .ne.0) return

      if(getvar('soilms', 'storcur',     MAXHRU,      'real', storcur)
     +   .ne.0) return

      if(getvar('soilms', 'excess',      MAXHRU,      'real',  excess)
     +   .ne.0) return

      if(getvar('cropcof', 'coefs', MAXLANDS*MAXCOEFS,  'real',  coefs)
     +  .ne.0) return 

      if(getvar('grid',    'tavf',       MAXHRU,        'real',  tavf)
     +   .ne.0) return

      if(getvar('snowpck', 'hru_snow',     MAXHRU,'real',   hru_snow)
     +   .ne.0) return

      if(getvar('intrcp', 'hru_adjustpet',MAXHRU, 'real', hru_adjustpet)
     +   .ne.0) return

      if(getvar('transfr', 'hru_petloss',  MAXHRU,'real',  hru_petloss)
     +   .ne.0) return

      DO 1000 i=1,nhru

!....TOTAL available pet was set= hru_adjustpet
!..  then hru_adjustpet modifed in: intercept, snowpck, soilev, transfer

       hru_aetplnt(i)  = 0.0
       hru_petcrop(i)  = 0.0
       hru_petplnt(i)  = hru_adjustpet(i)

!..get land use/cover

       landcov = cov_type(i)

!..for water body, bare soils, or impervious or below freezing or snow-covered then skip hru

      if(landcov.eq.10 .or. tavf(i).le.32.0 .or. landcov.eq.13
     +  .or.  hru_snow(i).gt.0.0000001 .or. landcov.eq.16) then
       hru_petplnt(i)   = 0.0
       go to 1000
      endif

    
!...IROOT= ROOT EXTRACTION PARAMETER
!.. SOIL IDENTIFICATION NUMBER FOR THIS BLOCK 

      NS=HRU_SOIL(I)

!.. SOIL TYPE (PARTICLE SIZE DISTRIBUTION) IDENTIFICATION NUMBER

      ST=soil_type(NS)

!.. SOIL LIMITED TRANSPIRATION RATE FACTOR, INCHES/DAY

      SLF=SLMFAC(NS)

!..     SET VARIABLES DETERMINED IN module CRPCOF (COEFS(landcov,1-6) 

      RD=     COEFS(landcov,1)   !..root depth
      CP=     COEFS(landcov,4)   !..crop coefficient
      RDMX=   COEFS(landcov,6)   !..max root depth

!.. NUMBER OF 6 IN LAYERS OF SOIL 

      NLTOT=NLAYER(NS)

!...SOIL ROOT DEPTH MUST BE AT LEAST 6 INCHES (ONE LAYER)

      IF(NLTOT.LT.1) NLTOT= 1
      IF(RDMX.LT.6.) RDMX = 6.

!...MAX ROOT ZONE LAYERS MUST BE LESS THAN OR EQUAL TO SOIL LAYERS
!...EVALUATE CURRENT NUMBER OF ROOT ZONE LAYERS.

      NLROOT=NLTOT
      SLTHK=NLTOT*6.0
      IF(RDMX.GT.SLTHK)  RDMX=SLTHK
      IF(RD.GT.RDMX)     RD=RDMX
      IF(SLTHK.GT.RDMX)  NLROOT=RDMX/6.+0.5

!.. find total available water-capacity for this soil per layer

      WC=AVLCAP(NS)*6.0

!.. find total saturated capacity for this soil for this layer

      SC=spcyld(ns)*6.0
      
!...MULTIPLY hru_petplnt(i) BY CROP COEFFICIENT TO ACCOUNT FOR THE CURRENT GROWTH
!...STAGE OF AGRICULTURAL CROP. FOR NON-AGRICULTURAL PLANTS THE CROP
!...COEFFICIENT IS EQUIVALENT TO THE ALFA-COEFFICIENT IN THE PRIESTLY-
!...TAYLOR METHOD.

      hru_petcrop(i) = hru_petplnt(i)*CP

      IF(hru_petcrop(i).LT.0.00000001)   hru_petcrop(i)=0.0

!...CRPCUR IS USED AS SURRAGATE FOR hru_petcrop(i) IN MODULE, hru_petcrop(i) RETAINS
!...ORIGINAL VALUE AND CRPCUR GETS REDUCED AS WATER IS EXTRACTED             -------

      CRPCUR=hru_petcrop(i)
      IF(hru_petcrop(i).LT. hru_petplnt(i)) then
         hru_petloss(i)=hru_petloss(i)+hru_petplnt(i)-hru_petcrop(i)
      end if

!...SUM TOTAL AVAILABLE WATER IN ROOT ZONE AND GET % OF MAXIMUM.

      SATMAXROOT  = sc  * NLROOT
      UNSATMAXROOT= wc  * NLROOT
      SMTOTROOT   = 0.0
      DO 40 N=1,NLROOT

40    SMTOTROOT = SMTOTROOT + storpor(i,n) + sms(i,n)

!..aet limited value based on soil limiting transpiration factor 

      AETLMT    =SLF*SMTOTROOT/(SATMAXROOT+UNSATMAXROOT)

!...DO TWO LOOPS ONE FOR SATURATED SOILS (IN WHICH CASE WILL TAKE FREE
!...WATER FIRST) AND THE SECOND LOOP FOR UNSATURATED SOILS
!...IF SOILS UNSATURATED GO TO UNSATURATED ALGORITHM (storpor(i,n)=0.0=STORCUR(i))

      IF(storcur(i).gt.0.00000001) then

!...SOILS SATURATED: FIRST TAKE ALL FREE WATER THAT CAN BE TAKEN FROM
!...SATURATED SOILS, IF SOME PET LEFT THEN GOTO unsat store
!...AND TAKE PET FROM UNSATURATED AVAILBLE WATER (IE,sms(i,n)).
!...WATER IS EXTRACTED BY PLANTS AT POTENTIAL RATE (SOIL WATER IS NON-LIMITING)
!...SO USE MAX OF EITHER AETLMT (MAY BE=0.0) OR CROPPET

!..  WATER FROM excess(i) (> FULL SATURATED STORE) 
!..  SOME WAS ALREADY EXTRACTED IN soilev_dpm

      IF(excess(i).GT.0.00000001) THEN
         maxpet = amax1(aetlmt,crpcur)
         TRNSPR = AMIN1(excess(i),maxpet)
         excess(i)=excess(i)-TRNSPR
         CRPCUR = CRPCUR - TRNSPR
         Aetlmt = aetlmt - TRNSPR
         hru_aetplnt(i) = TRNSPR
      END IF
 
      IF(crpcur.LT.0.00000001) crpcur =0.0
      if(aetlmt.lt.0.00000001) aetlmt =0.0

!..SATURATED SOIL EXTRACTION LOOP.......................200 or 250

      IF(slf.gt.0.0001) THEN          !...use aet limited value

       if(aetlmt.LT.0.00000001) go to 400
       do 200 N=1,NLROOT
        TRNSPR =AMIN1(storpor(i,n),aetlmt)
        STORCUR(i)   = STORCUR(i)   -TRNSPR
        storpor(i,n) = storpor(i,n) -TRNSPR
        AETLMT       = AETLMT       -TRNSPR
        hru_aetplnt(i) = hru_aetplnt(i) + TRNSPR

!...CHECK IF HAVE USED ALL aetlmt IF SO THEN LEAVE (GO TO 400)

200    if(aetlmt.LT.0.00000001) go to 400

      ELSE

       if(crpcur.LT.0.00000001) go to 400
       do 205 N=1,NLROOT
        TRNSPR =AMIN1(storpor(i,n),crpcur)
        STORCUR(i)   = STORCUR(i)   -TRNSPR
        storpor(i,n) = storpor(i,n) -TRNSPR
        crpcur       = crpcur       -TRNSPR
        hru_aetplnt(i) =hru_aetplnt(i) +TRNSPR

!...CHECK IF HAVE USED ALL hru_petcrop(i), IF SO THEN LEAVE (GO TO 400)

205    if(crpcur.LT.0.00000001) go to 400

      END IF

      end if                        !..end for excess/saturated store transpiration


!..UNSATURATED PLANT EXTRACTION, ONE OF TWO CHOICES:

!...FORMULATION OF GILES, BLACK, AND SPITTLEHOUSE, 1984, WHERE AET
!...IS LIMITED BY SOIL MOISTURE AVAILABILITY ACCORDING TO:
!...AET=(SOIL-LIMIT FACTOR)*(%AVAILABLE MOISTURE).
!...AET potential was decreased above if used some of water 
!...SOIL-LIMIT FACTOR (slmfac) IS SPECIFIED BY USER. IF slmfac SET TO 0.0 THEN
!...THIS METHOD IS NOT USED AND A METHOD BASED ON SOIL TEXTURE
!...IS USED INSTEAD.

      IF(SLF.GT.0.0) THEN

         if(aetlmt.lt.0.00000001) go to 400
         DO 300 N=1,NLROOT
         TRNSPR=AMIN1(sms(i,n),AETLMT)
         unsatcur(i)   = unsatcur(i)      - TRNSPR
         sms(i,n)      = sms(i,n)         - TRNSPR
         aetlmt        = aetlmt           - TRNSPR
         hru_aetplnt(i)= hru_aetplnt(i)   + TRNSPR
300      IF(aetlmt.LT.0.0000001) GO TO 400

       ELSE

!...UNSATURATED PLANT EXTRACTION BASED ON SOIL TEXTURE AND MOISTURE
!...AVAILABILITY (ORIGINAL FORMULATION):
!...FIRST THE FIND SOIL TYPE
!...FIND PORTION OF SOIL THAT IS SAND,LOAM,CLAY (R1,R2), WHERE:
!....                     R1 IS PORTION OF MAJOR SOIL PARTICLE SIZE
!....                     R2 IS PORTION OF MINOR SOIL PARTICLE SIZE

      if(crpcur.LT.0.00000001) go to 400

      IT=0
      IS=ST
      IF(IS.GT.1)  IT=1
      R1=2.0-ST+IT
      R2=1.0-R1
      I1=1+IT
      ANLR=NLROOT
      DO 75  N=1,NLROOT
      WGT=1.0
      IF(IROOT.GT.0)
     .   WGT=1.016*(EXP(-4.16*((N-1)/ANLR))-EXP(-4.16*(N/ANLR)))
      WS=sms(i,n)/WC
      IF(I1.GT.1)  GO TO 60
      EP1=WS*.52*R1
      IF(EP1.GT.0.13)EP1=R1
      EP2=WS*R2
      IF(EP2.GT.0.5) EP2=R2
      GO TO 70
60    EP1=WS*R1
      IF(EP1.GT.0.5) EP1=R1
      EP2=WS*R2*.44
      IF(WS.GT.0.32) EP2=WS*R2
      IF(EP2.GT.0.7) EP2=R2
70    EP=EP1+EP2
      TRNSPR=WGT*EP*CRPCUR
      IF(TRNSPR. GT .sms(i,n)) TRNSPR=sms(i,n)
      sms(i,n)       =sms(i,n)       -TRNSPR
      IF(IROOT.LT.1) CRPCUR=CRPCUR   -TRNSPR
      hru_aetplnt(i) = hru_aetplnt(i)+TRNSPR
      unsatcur(i)    = unsatcur(i)   -TRNSPR
75    if(crpcur.lt.0.0000001) crpcur=0.0

      END IF   !..end if for unsaturated-loop (either soil limited or soil texture)

!...FINISHED EXTRACTING WATER, EITHER CASE, SO GO TO 400 (SINK CALCULATION)

400   hru_petloss(i)=hru_petloss(i)+hru_petcrop(i)-hru_aetplnt(i)

!...hru_petloss(i) (THE AMOUNT OF UNUSED PET) IS NOT PUT IN MAS-BAL, IT IS IN CODE
!...FOR DEBUGGING PURPOSES

1000  continue


      if(putvar('intrcp', 'hru_adjustpet',MAXHRU, 'real',hru_adjustpet)
     +   .ne.0) return
      if(putvar('soilms', 'sms',     MAXHRU*MAXLAYERS, 'real',     sms)
     +  .ne.0) return
      if(putvar('soilms', 'storpor', MAXHRU*MAXLAYERS, 'real', storpor)
     +  .ne.0) return
      if(putvar('soilms', 'unsatcur',    MAXHRU,      'real', unsatcur)
     +  .ne.0) return
      if(putvar('soilms', 'storcur',     MAXHRU,      'real',  storcur)
     +  .ne.0) return
      if(putvar('soilms', 'excess',      MAXHRU,      'real',   excess)
     +  .ne.0) return
      if(putvar('transfr', 'hru_petloss',  MAXHRU,'real',  hru_petloss)
     +  .ne.0) return

      plantetrun = 0

      RETURN
      END


