!***********************************************************************
!
!                     PRINT_MASBAL_DPM.F  
!
!  STORES-OUTPUTS: Annual Monthly Daily Summaries
!                  -      -       -     -
!     Declares, initializes, and then accumlates each day/month water
!     budget items for the modeled area 
! 
!  Dailys optional because of potentially large amount of output
!
!.....MODULE TO  PRINT OUT DAILY, MONTHLY, AND ANNUAL BASIN-AVERAGE
!.....BUDGET COMPONENTS. THE PARTICULAR 12-MONTH PERIOD FOR THE ANNUAL BUDGET
!.....IS SPECIFIED BY USER. ALSO THE SIMULATION PERIOD AVERAGES ARE EVALUATED
!.....AND PRINTED OUT, ON AN ANNUALIZED BASIS, AT END OF SIMULATION.

!..       uses values accumulated in masbal_dpm.f 
  
!     version: 1.0 (vaccaro/bauer)


      integer function print_masbal_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer printmbdecl, printmbinit, printmbrun, retval

      integer mobdgt, mnthsall, nbdgdys, kntmos, dsum
      integer nym(MAXMO)
      integer nbuds,  nmonths, nobs

      double precision  QBLAVYR(MAXBUD),QBLAVMO(MAXBUD,MAXMO)

      save nbuds, nmonths, nobs, dsum
      save QBLAVYR,QBLAVMO
      save mobdgt, mnthsall, nym, nbdgdys, kntmos
  

      retval = 0

      if(arg.eq.'declare') then
        retval = printmbdecl(QBLAVYR,QBLAVMO,nym,mnthsall)
      
      else if(arg.eq.'initialize') then
        retval = printmbinit(QBLAVYR,QBLAVMO,
     +                       nym,mobdgt,mnthsall,dsum,
     +                       nbdgdys, kntmos, nbuds, nmonths,nobs) 


      else if(arg.eq.'run') then
        retval = printmbrun(QBLAVYR,QBLAVMO,nym,mobdgt,mnthsall,
     +             dsum, nbdgdys, kntmos, nbuds, nmonths,nobs) 

      end if

!******Debug level print
      call dpint4('End of print_masbal, retval = ', retval, 1, 2)

      print_masbal_dpm = retval

      return
      end

!***********************************************************************
!     print_masbaldecl: Declares variables and parameters 
!                      for daily-monthly-annual water-bugets
!              
 
!     printmbdecl - set up parameters


      integer function printmbdecl(QBLAVYR,QBLAVMO,nym,mnthsall)


      include 'fmodules.inc'

      double precision QBLAVYR(MAXBUD),QBLAVMO(MAXBUD,MAXMO)
      real nym(MAXMO),mnthsall

      printmbdecl = 1

!.. Variables for this module 

      if(declvar('printmb', 'QBLAVYR', 'nbuds', MAXBUD, 'double',
     +   'Average annual water balance for the modeled area'//
     +   'For all years',
     +   'inches',QBLAVYR).ne.0) return

      if(declvar('printmb', 'QBLAVMO', 'nbuds,nmonths', MAXBUD*MAXMO,
     +    'double',
     +   'Mean monthly water balance for modeled area'//
     +   'For all years and months that were simulated',
     +   'inches',QBLAVMO).ne.0) return

      if(declvar('printmb', 'mnthsall', 'one', 1, 'integer',
     +   'Total number of months simulated',
     +   'none',mnthsall).ne.0) return

      if(declvar('printmb', 'nym', 'nmonths', MAXMO, 'integer',
     +   'Number of years that each month is simulated',
     +   'none',nym).ne.0) return


!..Budget information: counters, times, checks

      if(declparam('printmb', 'mobdgt', 'one', 'integer',
     +   '9', '1', '12',
     +   'ENDing month for the annual water-budget summary',
     +   'ENDing month for the annual water-budget summary',
     +   'month').ne.0) return


      if(declparam('masbal', 'dsum', 'one', 'integer',
     +   '0', '0', '1',
     +   'Check to determine if want daily water-budgets',
     +   'Check to determine if want daily water-budgets, dsum>1=yes',
     +   'none').ne.0) return

      if(declparam('printmb', 'nbdgdys', 'one', 'integer',
     +   '1', '1', '5000',
     +   'Total number of days for this water-budget period',
     +   'Total number of days for this water-budget period'//
     +   'RESET TO 0 AFTER A BUDGET IS PRINTED TO START new COUNT'//
     +   'Used as divisor to calculate mean annual temperature',
     +   'none').ne.0) return

      if(declparam('printmb', 'kntmos', 'one', 'integer',
     +   '1', '1', '5000',
     +   'Total number of months for water-budget',
     +   'Total number of months for water-budget'//
     +   'Used as check for writing out budget summaries',
     +   'none').ne.0) return

      printmbdecl = 0

      return
      end



!**********************************************************************
!     printmbinit - get input  parameters, calculate,  and then initialize 
!               
               

      integer function printmbinit(QBLAVYR,QBLAVMO,
     +                           nym,mobdgt,mnthsall,dsum,
     +                      nbdgdys, kntmos, nbuds, nmonths, nobs) 

      include 'fmodules.inc'

      CHARACTER*50 BUFFER      

      integer nbuds, nmonths, nobs
      integer i,j, m

      integer starttime(6), endtime(6), iyrstrt, iyrend, mostrt, moend
      integer mobdgt, mnthsall, nym(MAXMO), nbdgdys,  kntmos
      integer dsum

      double precision QBLAVYR(MAXBUD), QBLAVMO(MAXBUD,MAXMO) 

      printmbinit = 1

      nmonths = getdim('nmonths')
      if(nmonths.eq.-1) return

      nbuds = getdim('nbuds')
      if(nbuds.eq.-1) return

      nobs = getdim('nobs')
      if(nobs.eq.-1) return


      call dattim('start', starttime)
      call dattim('end',   endtime)

      iyrstrt = starttime(1)
      iyrend  = endtime(1)
      mostrt  = starttime(2)
      moend   = endtime(2)

!..GET THE PARAMETERS

!..MONTHLY BUDGET END MONTH (any month, 9-water year) for annualized values

      if(getparam('printmb', 'mobdgt', 1, 'integer',  mobdgt)
     +  .ne.0) return

!..Get parameter to determine if want daily summaries for area

      if(getparam('masbal', 'dsum',   1, 'integer',  dsum)
     + .ne.0) return

!..Calculate (INITIALIZE) some parameters for water-budget output

!.....ESTABLISH TOTAL NUMBER OF MONTHS IN SIMULATION.

      MNTHSALL=(IYREND*12+MOEND)-(IYRSTRT*12+MOSTRT)+1

      WRITE (BUFFER,1000) IYRSTRT
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1001) IYREND
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1002) MOSTRT
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1003) MOEND
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1004) MNTHSALL
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1005) MOBDGT
      CALL OPSTR(BUFFER)
      WRITE (BUFFER,1006) 
      CALL OPSTR(BUFFER)
      

!.....DETERMINE FOR HOW MANY YEARS EACH MONTH IS SIMULATED

      DO 4 M=1,nmonths
      NYM(M)=IYREND-IYRSTRT+1
      IF(MOSTRT.GT.M) NYM(M)=NYM(M)-1
4     IF(MOEND. LT.M) NYM(M)=NYM(M)-1


!.....INITIALIZE TIME COUNTERS SOME OF WHICH ARE USED TO COMPARE AGAINST
!.....SPECIFIED TIMES FOR VARIOUS OUTPUTS.

!.....KNTMOS is the  TOTAL MONTH counter
!.....NBDGDYS IS NUMBER OF DAYS IN PERIOD FOR WHICH
!.....BASIN-WIDE BUDGET IS OUTPUT. NBDGDYS IS RESET TO 0 AFTER A BUDGET IS
!.....PRINTED TO START COUNT FOR NEXT PERIOD.

      KNTMOS=0
      NBDGDYS=0

!.....ZERO BUDGET ARRAYS BEFORE SIMULATION

      DO 95 I=1,nbuds
      DO 90 J=1,nmonths
90    QBLAVMO(I,J) = 0.0
95    QBLAVYR(I)   = 0.0

!..FORMATS

1000  FORMAT ('  BEGINNING YEAR OF SIMULATION              =',I5)
1001  FORMAT ('  ENDING YEAR OF SIMULATION                 =',I5)
1002  FORMAT ('  BEGINNING MONTH OF SIMULATION             =',I5)
1003  FORMAT ('  ENDING MONTH OF SIMULATION                =',I5)
1004  FORMAT ('  NUMBER OF MONTHS OF SIMULATION  (MNTHSALL)=',I5)
1005  FORMAT ('  END MONTH FOR ANNUAL OUTPUT     (MOBDGT)  =',I5)
1006  FORMAT ()
      printmbinit = 0

      return
      end

!***********************************************************************
! 
!     printmbrun - Accumulate and/or write out budget summaries for area
!

      integer function printmbrun(QBLAVYR,QBLAVMO,nym,mobdgt,mnthsall,
     +             dsum, nbdgdys, kntmos, nbuds, nmonths,nobs) 


      include 'fmodules.inc'

      integer dsum, mobdgt, mnthsall, nbdgdys, kntmos 
      integer nym(MAXMO), nbuds, nmonths, nobs

      double precision  QBALDY(MAXBUD),QBALMO(MAXBUD),QBALYR(MAXBUD)
      double precision  QBLAVYR(MAXBUD),QBLAVMO(MAXBUD,MAXMO),ERROR

      double precision runoff

!..temporary params, vars

      integer i, l, m, ltot, ntmpdys, nstep
      integer nowtime(6), starttime(6), endtime(6)
      integer iyr, imo, jday, idaymo, mostrt, dayend
      real sumtmp
      character*145 buffer
      character*140 bufferd

      integer ndays(12)
      DATA NDAYS/31,28,31,30,31,30,31,31,30,31,30,31/

      CHARACTER*4 AMON(12)
      character*6 ATOT
      DATA AMON/' JAN',' FEB',' MAR',' APR',' MAY',' JUN',
     .          ' JUL',' AUG',' SEP', ' OCT',' NOV',' DEC'/
      DATA ATOT/'TOTALS'/

      printmbrun = 1


      call dattim('start', starttime)
      call dattim('now',   nowtime)
      call dattim('end',   endtime)

      iyr    = nowtime(1)
      imo    = nowtime(2)
      idaymo = nowtime(3)
      mostrt = starttime(2)
      dayend = endtime(3)

      jday    = julian('now', 'calendar')
      nstep = getstep()
      if(nstep.eq.1.or.jday.eq.1) then
        if(mod(iyr,4).eq.0) then
          ndays(2) = 29
        else
          ndays(2) = 28
        end if
      end if 

      if(nstep.lt.2) then

       WRITE(BUFFER,1000)
       CALL OPSTR(BUFFER)
       WRITE(BUFFER,1001)
       CALL OPSTR(BUFFER)
       WRITE(BUFFER,1002)
       CALL OPSTR(BUFFER)
       WRITE(BUFFER,1000)
       CALL OPSTR(BUFFER)

      end if

       if(getvar('masbal', 'qbaldy',    MAXBUD,  'double',  qbaldy)
     + .ne.0) return

       if(getvar('masbal', 'qbalmo',    MAXBUD,  'double',  qbalmo)
     + .ne.0) return

       if(getvar('masbal', 'qbalyr',    MAXBUD,  'double',  qbalyr)
     + .ne.0) return

!..Acummulate daily budget counter

      nbdgdys = nbdgdys + 1 

!...WRITE OUT DAILY VALUES, IF SO SPECIFIED (DSUM > 0).

      IF(DSUM.GT.0) THEN
           IF(NOBS.GT.0) RUNOFF=QBALDY(4)
           IF(NOBS.LT.1) RUNOFF=QBALDY(15)
           ERROR=QBALDY(3)+QBALDY(5)+QBALDY(7)+QBALDY(8)+
     .       QBALDY(10)+QBALDY(11)+QBALDY(12)+QBALDY(13)+
     .       QBALDY(16)+QBALDY(17)-QBALDY(18)+RUNOFF-QBALDY(1)

           WRITE(BUFFERD,2000)IYR,IMO,IDAYMO,(QBALDY(I),I=1,nbuds),ERROR
           CALL OPSTR(BUFFERD)

           DO 10 I=1,nbuds
10         QBALDY(I)=0.0

         if(putvar('masbal', 'qbaldy',    MAXBUD,  'double',  qbaldy)
     +      .ne.0) return

       END IF

!...WRITE OUT MONTHLY VALUES if last day of month

      IF(idaymo .EQ. ndays(imo) ) THEN

!..END of a month, add to counter

         kntmos = kntmos +1

           IF(DSUM.GT.0) WRITE(BUFFER,1003)
           IF(DSUM.GT.0) CALL OPSTR(BUFFER)

!..AVERAGE TEMPERATURE:
           QBALMO(14)=QBALMO(14)/NDAYS(IMO)
           IF(NOBS.GT.0) RUNOFF=QBALMO(4)
           IF(NOBS.LT.1) RUNOFF=QBALMO(15)
           ERROR=QBALMO(3)+QBALMO(5)+QBALMO(7)+QBALMO(8)+
     .      QBALMO(10)+QBALMO(11)+QBALMO(12)+QBALMO(13)+
     .      QBALMO(16)+QBALMO(17)-QBALMO(18)+RUNOFF-QBALMO(1)

           WRITE(BUFFER,2001)AMON(IMO),IYR,(QBALMO(I),I=1,nbuds),ERROR
           CALL OPSTR(BUFFER)

           IF(DSUM.GT.0) WRITE(BUFFER,1000)
           IF(DSUM.GT.0) CALL OPSTR(BUFFER)
           IF(DSUM.GT.0) WRITE(BUFFER,1002)
           IF(DSUM.GT.0) CALL OPSTR(BUFFER)

           DO 20 I=1,nbuds
           QBLAVMO(I,IMO)=QBLAVMO(I,IMO)+QBALMO(I)
20         QBALMO(I)=0.0

          if(putvar('masbal', 'qbalmo',    MAXBUD,  'double',  qbalmo)
     +       .ne.0) return

       END IF

!...WRITE OUT ANNUAL VALUES AT END OF SPECIFIED BUDGET MONTH, AND/OR
!...AT END OF SIMULATION.

!.FIRST make sure last day of month

      IF(idaymo .EQ. ndays(imo) ) THEN
      IF(IMO.EQ.MOBDGT.OR.KNTMOS.EQ.MNTHSALL) THEN

           WRITE(BUFFER,1003)
           CALL OPSTR(BUFFER)

!..AVERAGE TEMPERATURE:
           QBALYR(14)=QBALYR(14)/NBDGDYS
           IF(NOBS.GT.0) RUNOFF=QBALYR(4)
           IF(NOBS.EQ.0) RUNOFF=QBALYR(15)
           ERROR=QBALYR(3)+QBALYR(5)+QBALYR(7)+QBALYR(8)+
     .      QBALYR(10)+QBALYR(11)+QBALYR(12)+QBALYR(13)+
     .      QBALYR(16)+QBALYR(17)-QBALYR(18)+RUNOFF-QBALYR(1)
           WRITE(BUFFER,2002) ATOT, (QBALYR(I),I=1,nbuds),ERROR
           CALL OPSTR(BUFFER)

           IF(KNTMOS.NE.MNTHSALL) WRITE(BUFFER,1000)
           IF(KNTMOS.NE.MNTHSALL) CALL OPSTR(BUFFER)
           IF(KNTMOS.NE.MNTHSALL) WRITE(BUFFER,1002)
           IF(KNTMOS.NE.MNTHSALL) CALL OPSTR(BUFFER)

!..Zero for next year's values

           DO 30 I=1,nbuds
30         QBALYR(I)=0.0
           NBDGDYS=0

          if(putvar('masbal', 'qbalyr',    MAXBUD,  'double',  qbalyr)
     +       .ne.0) return

         ENDIF
        END IF

!.....WRITE OUT MONTHLY and ANNUAL AVERAGES FOR SIMULATION PERIOD.

!.....      SIMULATION PERIOD BASIN BUDGET SUMMARY.

      IF( kntmos.eq.mnthsall .and. idaymo.eq.dayend ) THEN
           WRITE(BUFFER,1000)
           CALL OPSTR(BUFFER)
           WRITE(BUFFER,1004)
           CALL OPSTR(BUFFER)
           WRITE(BUFFER,1000)
           CALL OPSTR(BUFFER)

           DO 40 I=1,nbuds
           DO 40 M=1,nmonths
           IF(NYM(M).EQ.0) GO TO 40
           QBLAVMO(I,M)=QBLAVMO(I,M)/NYM(M)
40         CONTINUE
           DO 50 I=1,nbuds
           DO 50 M=1,nmonths
50         QBLAVYR(I)=QBLAVYR(I)+QBLAVMO(I,M)

!..........AVERAGE TEMPERATURE:
           SUMTMP=0.0
           NTMPDYS=0
           DO 55 M=1,nmonths
           IF(QBLAVMO(14,M).GT.0.0) NTMPDYS=NTMPDYS+NDAYS(M)
55         SUMTMP=SUMTMP+QBLAVMO(14,M)*NDAYS(M)
           QBLAVYR(14)=SUMTMP/NTMPDYS

           WRITE(BUFFER,1002)
           CALL OPSTR(BUFFER)
           LTOT=MIN0(12,MNTHSALL)
           DO 60 L=1,LTOT
           M=MOD((MOSTRT-1+L),12)
           IF(M.EQ.0) M=12
           WRITE(BUFFER,2003) AMON(M), (QBLAVMO(I,M),I=1,nbuds)
60         CALL OPSTR(BUFFER)

           WRITE(BUFFER,1003)
           CALL OPSTR(BUFFER)

           WRITE(BUFFER,2002) ATOT,(QBLAVYR(I),I=1,nbuds)
           CALL OPSTR(BUFFER)

           IF(MNTHSALL.LT.12) WRITE(BUFFER,1005)
           IF(MNTHSALL.LT.12) CALL OPSTR(BUFFER)
           IF(MNTHSALL.LT.12) WRITE(BUFFER,1006)
           IF(MNTHSALL.LT.12) CALL OPSTR(BUFFER)

       END IF

1000  FORMAT()
1001  FORMAT('                  AVERAGES FOR ENTIRE REGION:')
1002  FORMAT('   DATE    PRECP  POTET  CHGINT  RUNOFF RECHRG SOLPEV  ACT
     +SEV SNWEVP PPLTR  APLTR CHGSM  EVINT  CHGSNW AVTMP SYM-RO  LAKE DE
     +FCIT IRRGTN ERROR')
1003  FORMAT('  --------------------------------------------------------
     .----------------------------------------------------------------')
1004  FORMAT('  ANNUALIZED AVERAGES FOR ENTIRE REGION FOR ENTIRE SIMULAT
     .ION PERIOD:')
1005  FORMAT('   **** SIMULATION PERIOD WAS LESS THAN ONE YEAR; ****')
1006  FORMAT('   **** TOTAL IS NOT ANNUALIZED VALUE.            ****')


1100  FORMAT(//,2X,'ANNUALIZED AVERAGES FOR ENTIRE REGION FOR ENTIRE SIM
     .ULATION PERIOD:')

2000  FORMAT(1X,I4,'/',I2,'/',I2,1x,f5.2,12(2X,F5.2),2X,F5.1,4(2X,F4.2),
     +                                                            F7.3)
2001  FORMAT(A,3X,I4,            1x,f5.2,12(2X,F5.2),2X,F5.1,3(2X,F4.2),
     +                                                    1x,f5.2,F7.3)
2002  FORMAT(A,4X,1x,f5.2,9(2X,F5.2),2X,F6.2,1X,F5.2,2x,f5.2,3X,F5.1,
     !3(2X,F4.2),1x,F5.1,1X,F6.3)
2003  FORMAT(A,5X,10(2X,F5.2),2X,F6.2,2(2X,F5.2),2X,F5.1,3(2X,F4.2),
     !1x,F5.1,1X,F7.3)

      printmbrun = 0

      RETURN
      END

