!***********************************************************************
!
!                     SOILEVAP_DPM.F  
!

!...MODULE TO COMPUTE EVAPORATION FROM BARE SOIL.
!...ACTUAL SOIL EVAPORATION IS BASED ON A RELATIONSHIP THAT IS ASSUMED
!...TO HOLD FOR ALL SOILS AND IS BASED ON % VOLUME OF SOIL MOISTURE
!...IN UPPERMOST FOOT AND REMAINING PET (SOLPEV). SOLPEV IS
!...PROPORTIONAL TO THE AMOUNT OF GROUND NOT SHADED.
!...TOTAL EVAP FROM SOIL, ACTEV  = ACTEXCS+ACTEVSAT+ACTEVCAP
!                                = evap fromexcess,unsatstore,satstore


!     version: 1.0 (vaccaro/bauer)


      integer function soilevap_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer soilevapdecl, soilevapinit, soilevaprun, retval


      integer nhru, nsoils, nlands, ncoef, nlayrsoil
      integer nlayer(MAXSOILS), cov_type(MAXHRU), hru_soil(MAXHRU)

      real avlcap(MAXSOILS)
      real hru_pevsoil(MAXHRU),  hru_actevsoil(MAXHRU)

      save nhru, nsoils, nlands, ncoef, cov_type, nlayer, nlayrsoil
      save hru_pevsoil, hru_actevsoil, hru_soil, avlcap

      retval = 0

      if(arg.eq.'declare') then
        retval = soilevapdecl(hru_pevsoil,hru_actevsoil)
      
      else if(arg.eq.'initialize') then
        retval = soilevapinit(nhru,nsoils,nlands,cov_type,nlayer,
     +                            nlayrsoil,hru_soil,avlcap,ncoef)

      else if(arg.eq.'run') then
        retval = soilevaprun(nhru,nsoils,nlands,cov_type,nlayer,
     +  nlayrsoil,hru_soil,avlcap,hru_pevsoil,hru_actevsoil,ncoef)

      end if

!******Debug level print
      call dpint4('End of soilevap_dpm, retval = ', retval, 1, 2)

      soilevap_dpm = retval

      return
      end

!***********************************************************************
!     soilevapdecl: Declares 
!   


!     soilevapdecl - set up parameters

      integer function soilevapdecl(hru_pevsoil,hru_actevsoil)

      include 'fmodules.inc'

      real hru_pevsoil(MAXHRU),  hru_actevsoil(MAXHRU)

      soilevapdecl = 1


      if(declvar('soilev', 'hru_pevsoil', 'nhru', MAXHRU, 'real',
     +   'Potential evaporation demand for soil evaporation',
     +   'inches',hru_pevsoil).ne.0) return

      if(declvar('soilev', 'hru_actevsoil', 'nhru', MAXHRU, 'real',
     +   'Actual evaporation from upper 1 foot of the soil column',
     +   'inches',hru_actevsoil).ne.0) return

!..PARAMETERS

      if(declparam('soilms', 'avlcap', 'nsoils', 'real',
     +   '0.05', '0.', '.7',
     +   'Available water capacity for a soil association',
     +   'Available water capacity for a soil association'//
     +   'as decimal fraction for the layers (6 inches thick)',
     +   'none').ne.0) return

      if(declparam('soilms', 'nlayer', 'nsoils', 'integer',
     +   '4', '1', '14',
     +   'Number of 6" layers for a soil association',
     +   'Number of 6" layers for a soil association, will be limited'//
     +   'by the depth of the root zone during calculations',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_soil', 'nhru', 'integer',
     +   '1', '1', '200',
     +   'HRU soil type',
     +   'HRU soil type',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return


      soilevapdecl = 0

      return
      end



!**********************************************************************
!     soilevapinit - get input  parameters
!               

      integer function soilevapinit(nhru,nsoils,nlands,cov_type,
     +                    nlayer,nlayrsoil,hru_soil,avlcap,ncoef)

      include 'fmodules.inc'

      
      integer nhru, nsoils, nlands, ncoef, nlayrsoil
      integer nlayer(MAXSOILS), cov_type(MAXHRU), hru_soil(MAXHRU)

      real avlcap(MAXSOILS)
 
      soilevapinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nsoils = getdim('nsoils')
      if(nsoils.eq.-1) return

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

      nlayrsoil = getdim('nlayrsoil')
      if(nlayrsoil.eq.-1) return

!..landuse/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.. Get HRU/MRU soil information for initializing

      if(getparam('basin', 'hru_soil',   MAXHRU,  'integer', hru_soil)
     +  .ne.0) return

      if(getparam('soilms', 'nlayer',    MAXSOILS, 'integer', nlayer)
     +   .ne.0) return

      if(getparam('soilms', 'avlcap',    MAXSOILS, 'real',    avlcap)
     +   .ne.0) return


      soilevapinit = 0

      RETURN
      END

!***********************************************************************
! 
!                           soilevaprun 
!


      integer function soilevaprun(nhru,nsoils,nlands,cov_type,nlayer,
     +     nlayrsoil,hru_soil,avlcap,hru_pevsoil,hru_actevsoil,ncoef)


      include 'fmodules.inc'

      integer nhru, nlands, nsoils, ncoef, nlayrsoil
      integer cov_type(MAXHRU),  hru_soil(MAXHRU), nlayer(MAXSOILS)

      real unsatcur(MAXHRU),     storcur(MAXHRU), hru_snow(MAXHRU)
      real sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real excess(MAXHRU),       avlcap(MAXSOILS)     
      real coefs(MAXLANDS,MAXCOEFS),    hru_adjustpet(MAXHRU)
      real hru_pevsoil(MAXHRU),  hru_actevsoil(MAXHRU)  

!..temp values for this module

      integer i, ns, nltot, landcov
      real wc,fc,ACTEXCS,ACTEVSAT,ACTEVCAP,s1,s2,w1,w2,smf,ratio
      real sattot, soltot

      soilevaprun = 1


      if(getvar('soilms', 'sms',     MAXHRU*MAXLAYERS, 'real',    sms)
     +  .ne.0) return

      if(getvar('soilms', 'storpor',MAXHRU*MAXLAYERS,  'real', storpor)
     +  .ne.0) return

      if(getvar('soilms', 'unsatcur',    MAXHRU,      'real', unsatcur)
     +   .ne.0) return

      if(getvar('soilms', 'storcur',     MAXHRU,      'real', storcur)
     +   .ne.0) return

      if(getvar('soilms', 'excess',      MAXHRU,      'real',  excess)
     +   .ne.0) return

      if(getvar('intrcp', 'hru_adjustpet',MAXHRU, 'real',hru_adjustpet)
     +   .ne.0) return

      if(getvar('cropcof', 'coefs',  MAXLANDS*MAXCOEFS, 'real',  coefs)
     +  .ne.0) return

      if(getvar('snowpck', 'hru_snow',   MAXHRU,     'real',  hru_snow)
     +   .ne.0) return


!...ACTUAL SOIL EVAPORATION IS BASED ON A RELATIONSHIP THAT IS ASSUMED
!...TO HOLD FOR ALL SOILS AND IS BASED ON % VOLUME OF SOIL MOISTURE
!...IN UPPERMOST FOOT AND REMAINING PET (hru_pevsoil). hru_pevpsoil IS
!...PROPORTIONAL TO THE AMOUNT OF GROUND NOT SHADED.
!...TOTAL EVAP FROM SOIL, hru_actevsoil  = ACTEXCS+ACTEVSAT+ACTEVCAP.

!..evaoration of free water (ACTEXCS) is for all land covers, rest of soil 
!..evaporation is only for non-agriculutral crops


      do 1000 i=1,nhru

       hru_actevsoil(i) = 0.0
       hru_pevsoil(i)   = 0.0

!..get landuse

       landcov = cov_type(i)

!..if a water body use Priestly-Taylor pet as actual evaporation= potential
      if(landcov.eq.10) then
       hru_actevsoil(i) = 1.26 * hru_adjustpet(I)
       hru_pevsoil(i)   = hru_actevsoil(i)
       hru_adjustpet(i) = 0.0
       go to 1000
      endif
      
!..skip this HRU if snowpack

      if(hru_snow(i).gt.0.0000001) go to 1000

!..if impervious use Priestly-Taylor pet as actual evaporation = potential if excess

      if(landcov.eq.16) then
       hru_pevsoil(i) = 1.26 * hru_adjustpet(I)

      IF( EXCESS(i) .GT. 0.00000001 )   THEN

       IF(EXCESS(i).GT.HRU_PEVSOIL(I)) THEN
         HRU_ACTEVSOIL(i) = HRU_PEVSOIL(I)
         hru_adjustpet(i) = 0.0
         EXCESS(i) = EXCESS(i)- HRU_ACTEVSOIL(i)
         go to 1000
        ELSE
         HRU_ACTEVSOIL(i)=EXCESS(i)
         EXCESS(i)=0.0
         hru_adjustpet(i) =  hru_adjustpet(i) - hru_actevsoil(i)
         if( hru_adjustpet(i) .lt. 0.0) hru_adjustpet(i) = 0.0
       END IF

      END IF

       go to 1000
      endif
     

!.. get foliar cover for this day for this landuse for this hru/cell/mru

      fc = coefs(landcov,2)

      hru_pevsoil(i)= hru_adjustpet(i) * (1.0-FC)
     
!..no potential soil evaporation? if not go to next hru

      IF( hru_pevsoil(I) .LT. 0.00000001 ) go to 1000

      ACTEXCS =0.0
      ACTEVSAT=0.0
      ACTEVCAP=0.0

!.. EVAPORATE EXCESS WATER (AMOUNT ABOVE COMPLETE SATURATION) AT POTENTIAL RATE FOR ALL LAND COVERS

!.. IF SATURATED, ACTEXCS IS FIRST CALCULATED WHICH IS THE
!.. EVAPORATION OF WATER IN EXCESS OF SATURATION.

      IF( EXCESS(i) .GT. 0.00000001 ) THEN
       IF(EXCESS(i).GT.HRU_PEVSOIL(I)) THEN
         HRU_ACTEVSOIL(i) = HRU_PEVSOIL(I)
         EXCESS(i) = EXCESS(i)- HRU_ACTEVSOIL(i)
         go to 1000
        ELSE
         HRU_ACTEVSOIL(i)=EXCESS(i)
         EXCESS(i)=0.0
       END IF
      END IF

!.. ONLY DO SOIL EVAPORATION FROM SATURATED AND UNSATURATED STORES FOR:
!..            forest, grasslands, sage and bare soils 
!          (i.e., non-agricultural uses) AND foliar cover is less than 60%
 
      if( (landcov.le.3 .or. landcov.eq.13) .and. fc.lt.0.6) then

!.. SOIL IDENTIFICATION NUMBER FOR THIS BLOCK
      NS=HRU_SOIL(I)
!.. NUMBER OF 6 INCH LAYERS OF SOIL
      NLTOT=NLAYER(NS)
!...SOIL and ROOT DEPTH MUST BE AT LEAST 6 INCHES (ONE LAYER)
      IF(NLTOT.LT.1) NLTOT=1
!.. find total available water-capacity for this soil type
      WC=AVLCAP(NS)*6.0

!..no water above field capacity in the upper foot? if not go check unsat. store

      IF(storpor(i,1).GT.0.00000001.or.storpor(i,2).GT.0.00000001)
     +                        THEN    !....THEN DO THE SATURATED SOIL STORE 1ST

 
!..ACTEVSAT IS EVAPORATION FROM THE SATURATED STORE
      
      IF(NLTOT.LT.2) storpor(i,2)=0.0
      S1=storpor(i,1)
      S2=storpor(i,2)
      SATTOT=S1+S2

       ACTEVSAT=AMIN1((HRU_PEVSOIL(I)-ACTEXCS),SATTOT)

       storpor(i,1)=storpor(i,1)-ACTEVSAT
       IF(storpor(i,1).LT.0.0) THEN
            storpor(i,2)=storpor(i,2)+storpor(i,1)
            storpor(i,1)=0.0
       END IF

      STORCUR(i)=STORCUR(i)-ACTEVSAT

      endif                           !..end for check on doing saturated soil store

!..CHECK FOR POTENTIAL REMAINING TO EVAPORATE UNSATURATED MOISTURE.

      IF( (HRU_PEVSOIL(I)-(ACTEVSAT+ACTEXCS)).gt.0.00000001) then


!.. ACTEVCAP IS EVAPORATION FROM SOIL MOISTURE BELOW FIELD CAPACITY STORE

      W1=WC
      W2=WC
      S1=SMS(I,1)
      S2=SMS(I,2)
      IF(NLTOT.LT.2) THEN
         S2=0.0
         W2=0.0
      END IF
      SOLTOT=S1+S2
      SMF=(SOLTOT)/(W1+W2)
      RATIO=0.0
      IF(SMF.GT.0.25) RATIO=(SMF-0.25)*6.6
      IF(SMF.GT.0.40) RATIO=1.0
      ACTEVCAP=RATIO*(HRU_PEVSOIL(I)-ACTEVSAT-ACTEXCS)
      IF(ACTEVCAP.GT.SOLTOT) ACTEVCAP=SOLTOT
      IF(ACTEVCAP.LT.0.00000001) then 
          actevcap=0.0
          GO TO 100
        endif
      SMS(I,1)=SMS(I,1)-ACTEVCAP*S1/SOLTOT
      SMS(I,2)=SMS(I,2)-ACTEVCAP*S2/SOLTOT
      UNSATCUR(i)=UNSATCUR(i)-ACTEVCAP

      endif       !..for case where still potential evap available for unsat stor

!..ADD THE 3 SOIL EVAP. COMPONENTS TOGETHER

100    hru_actevsoil(i) = ACTEVSAT + ACTEXCS + ACTEVCAP
       hru_adjustpet(i) = hru_adjustpet(i) - hru_actevsoil(i)

      end if      !***** for cases of soil evap only for:
                  !  (landcov.le.3 .or. landcov.eq.13) .and. fc.lt.0.6


1000  continue


      if(putvar('intrcp', 'hru_adjustpet',MAXHRU, 'real', hru_adjustpet)
     +   .ne.0) return
      if(putvar('soilms', 'storpor', MAXHRU*MAXLAYERS, 'real', storpor)
     +   .ne.0) return
      if(putvar('soilms', 'storcur',   MAXHRU,        'real',  storcur)
     +   .ne.0) return
      if(putvar('soilms', 'sms',    MAXHRU*MAXLAYERS,  'real',     sms)
     +   .ne.0) return
      if(putvar('soilms', 'unsatcur',  MAXHRU,        'real', unsatcur)
     +   .ne.0) return
      if(putvar('soilms', 'excess',    MAXHRU,        'real',   excess)
     +   .ne.0) return

      soilevaprun = 0

      RETURN
      END

