!***********************************************************************
!
!                     SOILMS_DPM.F  

!....MODULE TO DISTRIBUTE SURPLUS MOISTURE AMONG SOIL LAYERS.
!....THIS ROUTINE ENTERED ONLY IF THERE IS SURPLUS MOISTURE
!....FROM PRECIP AND/OR SNOWMELT AFTER ABSTRACTION FOR INTERCEPTION.
!....SOIL IS ALLOWED TO SATURATE WITH NO PERCOLATION TO SUBSOIL YET.
!....(PERCOLATION FROM SOIL TO SUBSOIL IS CONTROLLED BY USER SPECIFIED
!....INFILTRATION RATE, VKSAT, AFTER SOILS SATURATE AND
!....IS SUSEQUENTLY COMPUTED IN module RUNOFF OR RUNTRU)


!     version: 1.0 (vaccaro/bauer)


      integer function soilms_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer soilmsdecl, soilmsinit, soilmsrun, retval

      integer nhru, nsoils, nlayrsoil, cov_type(MAXHRU)
      integer nlayer(MAXSOILS), hru_soil(MAXHRU)
      integer hru_irr_methd(MAXHRU)
      integer ncoef, nlands

      real  avlcap(MAXSOILS),    spcyld(MAXSOILS)
      real  sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real  unsatmax(MAXHRU), stormax(MAXHRU)
      real  unsatcur(MAXHRU), storcur(MAXHRU), excess(MAXHRU)
      real  sms_init(MAXHRU,MAXLAYERS), storpor_init(MAXHRU,MAXLAYERS)
      real  hru_chngsm(MAXHRU), wght(MAXHRU), strtsms, strtpor
      real  soil_type(MAXSOILS), solprm(MAXSOILS)
      real  hru_appld(MAXHRU)
      real smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax

      save  nhru, nsoils, nlayer, nlayrsoil, cov_type
      save  sms, storpor, excess, stormax, unsatmax, avlcap, spcyld
      save  soil_type, solprm, hru_soil, unsatcur, storcur
      save  sms_init, storpor_init, hru_chngsm, wght, strtsms, strtpor
      save  smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax
      save  hru_appld, hru_irr_methd, ncoef, nlands
      retval = 0

      if(arg.eq.'declare') then
        retval = soilmsdecl(sms,storpor,excess,unsatcur,storcur,   
     +                         hru_chngsm,sms_init,storpor_init, 
     +  smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax)
      
      else if(arg.eq.'initialize') then
        retval = soilmsinit(nhru,nsoils,cov_type,
     +    nlayer,avlcap,spcyld,solprm,soil_type,hru_soil,
     +  smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax,
     +  unsatmax,stormax,wght,strtsms,strtpor,sms,storpor,nlayrsoil,
     +   hru_irr_methd,hru_appld, ncoef, nlands)

      else if(arg.eq.'run') then
        retval = soilmsrun(nhru,nsoils,nlayer,nlayrsoil,cov_type,
     +   hru_soil,sms,unsatcur,storcur,storpor,unsatmax,stormax,
     +   excess,avlcap,hru_appld,hru_irr_methd,hru_chngsm,
     +   sms_init,storpor_init, ncoef, nlands)
      
      end if

!******Debug level print
      call dpint4('End of soilms_dpm, retval = ', retval, 1, 2)

      soilms_dpm = retval

      return
      end

!***********************************************************************
!     soilmsdecl: Declares 
!   


!     soilmsdecl - set up parameters


      integer function soilmsdecl(sms,storpor,excess,unsatcur,storcur,
     +                               hru_chngsm,sms_init,storpor_init,
     +    smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax)


      include 'fmodules.inc'

      real  sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real  sms_init(MAXHRU,MAXLAYERS), storpor_init(MAXHRU,MAXLAYERS)
      real  unsatcur(MAXHRU), storcur(MAXHRU), excess(MAXHRU)
      real  hru_chngsm(MAXHRU)
      real smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax

      soilmsdecl = 1

!..AREA WEIGHTED AVERAGE,MIN,MAX OF SOIL MOSITURE AND SOIL SATURATION
!..CALCULATED FROM INPUT SOIL INFORMATION

      if(declvar('soilms', 'smscapavg', 'one', 1, 'real',
     +   'Area-average of soil moisture capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', smscapavg).ne.0) return

      if(declvar('soilms', 'smscapmin', 'one', 1, 'real',
     +   'Minimum of soil moisture capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', smscapmin).ne.0) return

      if(declvar('soilms', 'smscapmax', 'one', 1, 'real',
     +   'Maximum of soil moisture capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', smscapmax).ne.0) return

      if(declvar('soilms', 'satcapavg', 'one', 1, 'real',
     +   'Area-average of soil saturation capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', satcapavg).ne.0) return

      if(declvar('soilms', 'satcapmin', 'one', 1, 'real',
     +   'Minimum of soil saturation capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', satcapmin).ne.0) return

      if(declvar('soilms', 'satcapmax', 'one', 1, 'real',
     +   'Maximum of soil saturation capacity for all CELLs/HRUs'//
     +   'based on each soil-type and allied info(layers,etc) input',
     +   'inches', satcapmax).ne.0) return

      if(declvar('soilms', 'sms', 'nhru,nlayrsoil', MAXHRU*MAXLAYERS,
     +    'real',
     +   'Soil moisture in unsaturated soil moisture store, by layer',
     +   'inches',sms).ne.0) return

      if(declvar('soilms', 'sms_init', 'nhru,nlayrsoil', 
     +   MAXHRU*MAXLAYERS, 'real',
     +   'Daily initial soil moisture in unsatured soil moisture store',
     +   'inches',sms_init).ne.0) return

      if(declvar('soilms','storpor_init','nhru,nlayrsoil',
     +    MAXHRU*MAXLAYERS,'real',
     +   'Daily initial soil moisture in satured soil moisture store',
     +   'inches',storpor_init).ne.0) return

      if(declvar('soilms', 'storpor', 'nhru,nlayrsoil', 
     +   MAXHRU*MAXLAYERS, 'real',
     +   'Soil moisture in satured soil moisture store, by layer'//
     +   ' sms(nhru,nsoils) must first be filled',
     +   'inches',storpor).ne.0) return

      if(declvar('soilms', 'excess', 'nhru', MAXHRU, 'real',
     +   'Amount of water in excess of saturated soil moisture store',
     +   'inches',excess).ne.0) return

      if(declvar('soilms', 'hru_chngsm', 'nhru', MAXHRU, 'real',
     +   'Total change in soil moisture (sat/unsat) for this day',
     +   'inches',hru_chngsm).ne.0) return

      if(declvar('soilms', 'unsatcur',   'nhru', MAXHRU, 'real',  
     +   'CURRENT available water capacity for a soil for a hru',
     +   'inches',unsatcur).ne.0) return

      if(declvar('soilms', 'storcur',   'nhru', MAXHRU, 'real',  
     +   'CURRENT saturated water capacity for a soil for a hru',
     +   'inches',storcur).ne.0) return

!..SOIL PARAMETERS

      if(declparam('soilms', 'unsatmax', 'nhru', 'real',
     +   '2.0', '0.', '24.',
     +   'Maximum available water capacity for a soil for a hru',
     +   'Maximum available water capacity for a soil for a hru',
     +   'inches').ne.0) return

      if(declparam('soilms', 'stormax', 'nhru', 'real',
     +   '2.0', '0.', '24.',
     +   'Maximum saturated water capacity for a soil for a hru',
     +   'Maximum saturated water capacity for a soil for a hru',
     +   'inches').ne.0) return

      if(declparam('soilms', 'avlcap', 'nsoils', 'real',
     +   '0.05', '0.', '.7',
     +   'Available water capacity for a soil association',
     +   'Available water capacity for a soil association'//
     +   'as decimal fraction for the layers (6 inches thick)',
     +   'none').ne.0) return

      if(declparam('soilms', 'spcyld', 'nsoils', 'real',
     +   '0.20', '0.02', '.45',
     +   'Specific yield of soils for a soil association',
     +   'Specific yield of soils for a soil association, equivalent'//
     +   ' to tot effective porosity, decimal fraction by volume ',
     +   'none').ne.0) return

      if(declparam('soilms', 'solprm', 'nsoils', 'real',
     +   '5.', '0.', '500.',
     +   'Lateral permeability for a soil association, in feet/day',
     +   'Lateral permeability for a soil association, in feet/day',
     +   'feet/day').ne.0) return

      if(declparam('soilms', 'soil_type', 'nsoils', 'real',
     +   '2.0', '1.0', '3.0',
     +   'Soil texture for a soil association',
     +   'Soil texture for a soil association: 1=sand,2=silt,3=clay'//
     +   'Decimal values for mixtures, eg, 1.5=silty sand',
     +   'none').ne.0) return

      if(declparam('soilms', 'nlayer', 'nsoils', 'integer',
     +   '4', '1', '14',
     +   'Number of 6" layers for a soil association',
     +   'Number of 6" layers for a soil association, will be limited'//
     +   'by the depth of the root zone during calculations',
     +   'none').ne.0) return

!.. INITIAL CONDITIONS:  STRTSMS, STRTPOR
          
      if(declparam('soilms', 'strtsms', 'one', 'real',
     +   '0.0', '0.0', '1.',
     +   'Initial soil moisture for each CELL/HRU as fraction TAWC',
     +   'Initial soil moisture, all layers for all CELLs/HRUs'//
     +   'value as fraction of total available water capacity',
     +   'none').ne.0) return

      if(declparam('soilms', 'strtpor', 'one', 'real',
     +   '0.0', '0.0', '1.',
     +  'Initial soil saturation, FRACTION OF TOTAL EFFECTIVE POROSITY',
     +   'Initial soil saturation, same fraction for each CELL/HRU',
     +   'none').ne.0) return

!..basin parameters

      if(declparam('basin', 'hru_soil', 'nhru', 'integer',
     +   '1', '1', '200',
     +   'HRU soil type',
     +   'HRU soil type',
     +   'none').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return

      if(declparam('basin', 'hru_appld', 'nhru', 'real',
     +   '0.', '0.', '72.',
     +   'Average application rate of irrigation water for hru',
     +   'Average application rate of irrigation water for hru',
     +   'inches').ne.0) return

      if(declparam('basin', 'hru_irr_methd', 'nhru', 'integer',
     +   '0', '0', '1',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'Irrigation method for hru: 0=abv canop 1=all other',
     +   'none').ne.0) return

      soilmsdecl = 0

      return
      end



!**********************************************************************
!     soilmsinit - get input  parameters, calculate,  and then initialize 
!               

      integer function soilmsinit(nhru,nsoils,cov_type,
     +    nlayer,avlcap,spcyld,solprm,soil_type,hru_soil,
     +  smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax,
     +  unsatmax,stormax,wght,strtsms,strtpor,sms,storpor,nlayrsoil,
     +   hru_irr_methd,hru_appld, ncoef, nlands)
      include 'fmodules.inc'

      integer nhru, nsoils, nlayrsoil, ncoef, nlands 
      integer nlayer(MAXSOILS), cov_type(MAXHRU), hru_soil(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real avlcap(MAXSOILS),  spcyld(MAXSOILS), solprm(MAXSOILS)
      real soil_type(MAXSOILS)
      real unsatmax(MAXHRU),  stormax(MAXHRU), wght(MAXHRU)
      real hru_appld(MAXHRU)
      real strtsms, strtpor

      real smscapavg,smscapmin,smscapmax,satcapavg,satcapmin,satcapmax
      real smscapblk,satcapblk,storcapavg

      integer i, j, n, ns, nltot
      real sur 

      character*115 buffer

      soilmsinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nsoils = getdim('nsoils')
      if(nsoils.eq.-1) return

      nlayrsoil = getdim('nlayrsoil')
      if(nlayrsoil.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

!..land use/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

!.. Get HRU/MRU soil information for initializing

      if(getparam('basin', 'hru_soil',   MAXHRU, 'integer', hru_soil)
     +  .ne.0) return

      if(getvar('basin', 'wght',       MAXHRU,   'real',     wght)
     +   .ne.0) return

!..Get HRU info for irrigation application rates and method

      if(getparam('basin', 'hru_appld',  MAXHRU, 'real',    hru_appld)
     +   .ne.0) return
 
      if(getparam('basin','hru_irr_methd',MAXHRU,'integer',
     +   hru_irr_methd)   .ne.0) return

!..SOIL PARAMETERS

      if(getparam('soilms', 'avlcap',    MAXSOILS, 'real', avlcap)
     +   .ne.0) return

      if(getparam('soilms', 'spcyld',    MAXSOILS, 'real', spcyld)
     +    .ne.0) return

      if(getparam('soilms', 'solprm',    MAXSOILS, 'real', solprm)
     +   .ne.0) return

      if(getparam('soilms', 'soil_type', MAXSOILS, 'real', soil_type)
     +   .ne.0) return

      if(getparam('soilms', 'nlayer',    MAXSOILS, 'integer', nlayer)
     +   .ne.0) return

!.. INITIAL CONDITIONS: STRTSMS, STRTPOR

      if(getparam('soilms', 'strtsms',  1, 'real',  strtsms)
     +  .ne.0) return

      if(getparam('soilms', 'strtpor',  1, 'real',  strtpor)
     +  .ne.0) return

!..find max storages in root zone, excluding water bodies =cov_type=10
!..                                excluding impervious   =cov_type=16

      do 500 i=1,nhru

      if(cov_type(i).eq.10.or.cov_type(i).eq.16)      go to 500

!..  SOIL IDENTIFICATION NUMBER FOR THIS BLOCK
      NS=HRU_SOIL(I)
!..  NUMBER OF 6 IN LAYERS OF SOIL
      NLTOT=NLAYER(NS)
!...SOIL and ROOT DEPTH MUST BE AT LEAST 6 INCHES (ONE LAYER)
      IF(NLTOT.LT.1) NLTOT=1

!..  TOTAL AVAILABLE WATER CAPACITY FOR THE SOIL COLUMN, REGARDLESS OF ROOT DEPTH
!..  use avlcap that is decimal percent of a 6 layer
!..  TOTAL SATURATED WATER CONTENT FOR THE SOIL COLUMN, REGARDLESS OF ROOT DEPTH
!..  =EFFECTIVE POROSITY (SPEC. YIELD), IN INCHES, FOR TOTAL SOIL THICKNESS

      UNSATMAX(i)= AVLCAP(NS) * NLTOT*6.0
      STORMAX(i) = SPCYLD(NS) * NLTOT*6.0

500   continue

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1001) nsoils
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1002)  
      CALL OPSTR(BUFFER)

      DO 1  I=1,nsoils
      WRITE (BUFFER,1003)I,NLAYER(I),soil_type(I),AVLCAP(I),SPCYLD(I),
     .                   SOLPRM(I)
1      CALL OPSTR(BUFFER)

      SMSCAPAVG=0.0
      SATCAPAVG=0.0
      SMSCAPMIN=9999
      SMSCAPMAX=0.0
      SATCAPMIN=9999
      SATCAPMAX=0.0

      DO 2  I=1,nhru

      if(cov_type(i).eq.10)      go to 2   !..do not count surface water bodies
      if(cov_type(i).eq.16)      go to 2   !..do not count impervious hrus

      J=hru_soil(I)
      NLTOT=NLAYER(J)
      SMSCAPBLK=NLTOT*AVLCAP(J)*6.0
      SATCAPBLK=NLTOT*SPCYLD(J)*6.0
      IF(SMSCAPBLK.LT.SMSCAPMIN) SMSCAPMIN=SMSCAPBLK
      IF(SMSCAPBLK.GT.SMSCAPMAX) SMSCAPMAX=SMSCAPBLK
      IF(SATCAPBLK.LT.SATCAPMIN) SATCAPMIN=SATCAPBLK
      IF(SATCAPBLK.GT.SATCAPMAX) SATCAPMAX=SATCAPBLK

      SMSCAPAVG=SMSCAPAVG+SMSCAPBLK*WGHT(i)
      SATCAPAVG=SATCAPAVG+SATCAPBLK*WGHT(i)
2     continue

      STORCAPAVG=SMSCAPAVG+SATCAPAVG

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1004)  SMSCAPAVG
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1005)  SATCAPAVG
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1006)  STORCAPAVG
      CALL OPSTR(BUFFER)




!.....ECHO-WRITEOUT THE INITIAL CONDITIONS.

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1007)  
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1008)  STRTSMS, STRTPOR
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1009)  
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)


!..check if bad numbers, if so write out and stop simulation
      IF(STRTSMS.LT.1.0.AND.STRTPOR.GT.0.0) THEN

          WRITE(BUFFER,1000)
          CALL OPSTR(BUFFER)
          WRITE(BUFFER,1010) 
          CALL OPSTR(BUFFER)
          WRITE(BUFFER,1011) 
          CALL OPSTR(BUFFER)
          WRITE(BUFFER,1012) STRTSMS, STRTPOR
          CALL OPSTR(BUFFER)
          WRITE(BUFFER,1013) 
          CALL OPSTR(BUFFER)
          WRITE(BUFFER,1000)
          CALL OPSTR(BUFFER)

          stop

       END IF

!..... SET INITIAL CONDITIONS FOR:  SMS,STORPOR

!..... INITIAL MOISTURE STORES FOR ALL CELLS:
!..... 1) SMS=SPECIFIED % OF FIELD CAPACITY
!..... 2) STORPOR=SPECIFIED % OF EFFECTIVE POROSITY. (NOTE: IF SMS NOT SET
!........ TO FIELD CAPACITY, STORPOR MUST BE SPECIFIED AS ZERO.)


      DO 20  I=1,NHRU

      if(cov_type(i).eq.10)      go to 20    !..do not initialize for water bodies
      if(cov_type(i).eq.16)      go to 20    !..do not initialize for impervious

      NS=hru_soil(I)
      NLTOT=NLAYER(NS)
      if(nltot.lt.1) nltot=1
        DO 10 N=1,NLTOT
        STORPOR(I,N)=0.0
10      SMS(I,N)=STRTSMS*AVLCAP(NS)*6.0
      SUR=NLTOT*STRTPOR*SPCYLD(NS)*6.0
        DO 15 N=NLTOT,1,-1
        STORPOR(I,N)=SPCYLD(NS)*6.0
        SUR=SUR-STORPOR(I,N)
         IF(SUR.LE.0.0) THEN
          STORPOR(I,N)=STORPOR(I,N)+SUR
          GO TO 20
          END IF
15     CONTINUE
20    CONTINUE


!..FORMATS

1000  FORMAT()
1001  FORMAT(' SOIL PROPERTIES FOR THE ',I2,'  (nsoils) SOILS ARE:')
1002  FORMAT(' NSOIL #LAYERS SOLTEX AVLCAP  SPCYLD SOLPRM(FT/DY) ')
1003  FORMAT(3X,I3,5X,I3,4X,F3.1,4X,F3.2,4X,F3.2,7X,F6.2,5X,F6.2)
1004  FORMAT('  AVERAGE SOIL MOISTURE IN BASIN AT FIELD CAPACITY       =
     .',F8.2, ' INCHES')
1005  FORMAT('  AVERAGE SATURATED MOISTURE IN BASIN AT FULL SATURATION =
     .',F8.2, ' INCHES')
1006  FORMAT('  AVERAGE TOTAL SOIL MOISTURE STORAGE CAPACITY IN BASIN  =
     .',F8.2, ' INCHES')
1007  FORMAT('  INITIAL CONDITIONS:')
1008  FORMAT('  FRACTION OF FIELDCAP=',F4.2,' FRACTION OF SPCFC YLD=',
     +F4.2)
1009  FORMAT('  THESE VALUES ARE REPLACED IF STORAGE ARRAYS ARE READ IN 
     .FROM VARS FILE SAVE FROM PREVIOUS SIMULATION')
1010  FORMAT('****SOIL NOT AT FIELD CAPACITY, EITHER SET SOIL MOISTURE**
     .**')
1011  FORMAT('****FACTOR TO ZERO, OR SET SATURATION FACTOR TO ZERO****')
1012  FORMAT('STRTSMS=',F3.1,'STRTPOR=',F3.1)
1013  FORMAT('**!!** MMS WILL END RUN, MAY BE ABRUPT W/ ERROR **!!!!**')

      soilmsinit = 0

      RETURN
      END

!***********************************************************************
! 
!     soilmsrun - adjust soil moisture stores based on surplus water
!


      integer function soilmsrun(nhru,nsoils,nlayer,nlayrsoil,cov_type,
     +   hru_soil,sms,unsatcur,storcur,storpor,unsatmax,stormax,excess,   
     +   avlcap,hru_appld,hru_irr_methd,hru_chngsm,sms_init,
     +                                      storpor_init,ncoef, nlands)


      include 'fmodules.inc'

      integer nhru, nsoils, nlayrsoil, ncoef, nlands
      integer cov_type(MAXHRU), nlayer(MAXSOILS),  hru_soil(MAXHRU)
      integer hru_irr_methd(MAXHRU)

      real unsatmax(MAXHRU),   stormax(MAXHRU), avlcap(MAXSOILS)
      real hru_snomelt(MAXHRU), hru_rain(MAXHRU), hru_appld(MAXHRU)
      real coefs(MAXLANDS,MAXCOEFS)

!..MODELED VARIABLES

      real  sms(MAXHRU,MAXLAYERS), storpor(MAXHRU,MAXLAYERS)
      real  sms_init(MAXHRU,MAXLAYERS), storpor_init(MAXHRU,MAXLAYERS)
      real  excess(MAXHRU), unsatcur(MAXHRU), storcur(MAXHRU)
      real  hru_chngsm(MAXHRU), hru_irrigation(MAXHRU)

!..temps

      integer i, n, ns, nltot
      real  wc, dry, sc, sur

      soilmsrun = 1

!..Process variables from process modules

      if(getvar('snowpck', 'hru_rain',  MAXHRU,  'real',  hru_rain)
     +   .ne.0) return

      if(getvar('snowpck', 'hru_snomelt',MAXHRU, 'real',  hru_snomelt)
     +   .ne.0) return

      if(getvar('intrcp','hru_irrigation',MAXHRU,'real', hru_irrigation)
     +   .ne.0) return

      if(getvar('cropcof', 'coefs', MAXLANDS*MAXCOEFS, 'real', coefs)
     +  .ne.0) return

!..ZERO SOME VALUES AND FIND INITIAL VALUES FOR STORAGE FOR DAY IN UNSAT AND SAT STORES

      do 500 i=1,nhru

       excess(i)     = 0.0
       hru_chngsm(i) = 0.0
       UNSATCUR(i)   = 0.0
       STORCUR(i)    = 0.0

      if(cov_type(i) .NE. 10 .or. cov_type(i) .NE. 16) THEN  !...DO ALL NON-WATER/IMPERVIOUS HRUS

!..  SOIL IDENTIFICATION NUMBER FOR THIS BLOCK
       NS=HRU_SOIL(I)
!..  NUMBER OF 6 IN LAYERS OF SOIL
       NLTOT=NLAYER(NS)
!...SOIL and ROOT DEPTH MUST BE AT LEAST 6 INCHES (ONE LAYER)
       IF(NLTOT.LT.1) NLTOT=1

       DO 400 N=1,NLTOT

!.   FIND TOTAL WATER CURRENTLY IN THE SATURATED STORE.

       STORCUR(i)        = STORCUR(i) + STORPOR(I,N)
       storpor_init(i,n) = STORPOR(I,N)

!.. FIND TOTAL SOIL MOISTURE CONTENT (INCHES) CURRENTLY IN EACH SOIL LAYER

       sms_init(i,n) = SMS(I,N)
400    UNSATCUR(i)   = UNSATCUR(i) + SMS(I,N)

      ENDIF

500   continue


      do 1000 i=1, nhru

!..find surplus water:
!..  snowmelt plus rainfall plus any irrigation water that is applied blw canopy
!..  if irr water applied abv canopy accounted for in modules: intercept snowpck

      sur = hru_snomelt(i) + hru_rain(i)

      if(hru_irr_methd(i).gt.0.and.hru_appld(i).gt.0.0) then
         hru_irrigation(i) =  hru_appld(i) * coefs( cov_type(i), 5 )
       sur = sur + hru_irrigation(i)
      end if

!..if no surplus water, go to next hru

      if(sur.lt.0.0000001) go to 1000

 
!..if water body, go to next hru (end of 1000 loop)

      if(cov_type(i).eq.10)      then
       go to 1000     
      end if

!..if impervious, , set excess, and go to next hru

      if(cov_type(i).eq.16)      then
       excess(i) = sur
       go to 1000     
      end if

      NS=HRU_SOIL(I)
      NLTOT=NLAYER(NS)
      IF(NLTOT.LT.1) NLTOT=1
      WC=AVLCAP(NS)*6.0

!...DISTRIBUTE SURPLUS TO UNSATURATED SOIL MOISTURE STORE BY FILLING
!...LAYERS FROM TOP DOWN. DIFFERENCE BETWEEN CURRENT SOIL MOISTURE, SMS,
!.. AND WATER HOLDING CAPACITY, WC, IS AMOUNT OF WATER THAT CAN BE TAKEN
!.. FROM SURPLUS AND ADDED TO LAYER.

      IF( (UNSATMAX(i)-UNSATCUR(i)) .gt.0.00000001) then
        DO 30 N=1,NLTOT
         DRY=WC-SMS(I,N)
         sur=sur-DRY
         SMS(i,N)=WC
         UNSATCUR(i)=UNSATCUR(i) + DRY

!...CHECK IF surplus IS USED UP; IF SO RE-ADJUST SMS/UNSATCUR for hru and go to next one

        IF(sur.LE.0.0) THEN
          SMS(i,N)   =SMS(i,N)    + sur
          UNSATCUR(i)=UNSATCUR(i) + sur
          go to 1000
         END IF

30      CONTINUE

      endif

!...UNSATURATED STORAGE IS FULL. DISTRIBUTE REMAINING SURPLUS (sur)
!...BY FULLY SATURATING EACH SOIL LAYER FROM BOTTOM UP.
!...IF ALL LAYERS BECOME FULL, REMAINING SURPLUS BECOMES EXCESS WHICH
!...BECOMES PART OF THE RUNOFF COMPONENT AND/OR SOIL EVAPORATION
!.. AND PLANT TRANSPIRATION

      IF( (STORMAX(i)-STORCUR(i)) .gt.0.00000001) then
       SC=STORMAX(i)/NLTOT
       DO 45 N=NLTOT,1,-1
        DRY=SC-storpor(i,N)
        sur=sur-DRY
        storpor(i,N)=SC
        STORCUR(i)=STORCUR(i) + DRY

!...CHECK IF SURPLUS IS USED UP, IF SO RE-ADJUST storpor(i,n) AND STORCUR(i); go to next hru

       IF(sur.LE.0.0) THEN
         storpor(i,N)= storpor(i,N) + sur
         STORCUR(i)  = STORCUR(i)   + sur
         go to 1000
        END IF

45     CONTINUE

      endif

!...SOIL IS TOTALLY SATURATED BUT THERE IS STILL
!...SOME surplus (sur). PUT SURPLUS INTO EXCESS

      STORCUR(i)= STORMAX(i)
      EXCESS(i) = sur

1000  continue


      if(putvar('intrcp','hru_irrigation',MAXHRU,'real',hru_irrigation)
     +   .ne.0) return

      soilmsrun = 0

      RETURN
      END


