!***********************************************************************
!
!                     TRANSFER_DPM.F  

!....THIS MODULE TAKES THE PORTION OF hru_pevsoil NOT USED TO
!....EVAPORATE BARE SOIL MOISTURE,SA,AND ADDS PART OF IT TO hru_petplnt
!....thruough the variable hru_adjustpet, which is the adjusts to daily PET
!....based on the use of energy to meet different evaporative demands
!....THE AMOUNT ADDED IS BASED ON THE AMOUNT OF FOLIAR COVER. THIS
!....RELATION IS FROM SAXTON AND OTHERS (1974,ASAE)


!     version: 1.0 (vaccaro/bauer)

      integer function transfer_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer transferdecl, transferinit, transferrun, retval

      integer nhru, nlands, ncoef, cov_type(MAXHRU)
      real hru_petloss(MAXHRU)

      save  nhru, nlands, ncoef, cov_type,  hru_petloss

      retval = 0

      if(arg.eq.'declare') then

       retval = transferdecl(hru_petloss)
      
      else if(arg.eq.'initialize') then
        retval = transferinit(nhru, nlands, ncoef, cov_type)

      else if(arg.eq.'run') then
        retval = transferrun(nhru,nlands, ncoef, cov_type, hru_petloss)

      end if

!******Debug level print
      call dpint4('End of transfer_dpm, retval = ', retval, 1, 2)

      transfer_dpm = retval

      return
      end

!***********************************************************************
!     transferdecl: Declares 
!   


!     transferdecl - set up parameters


      integer function transferdecl(hru_petloss)

      include 'fmodules.inc'

      real  hru_petloss(MAXHRU)

      transferdecl = 1

      if(declvar('transfr', 'hru_petloss', 'nhru', MAXHRU, 'real',
     +   'Amount of potential et loss and not transferred to plnt pet',
     +   'inches',hru_petloss).ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return


      transferdecl = 0

      return
      end



!**********************************************************************
!     transferinit - get input  parameters
!               

      integer function transferinit(nhru, nlands, ncoef, cov_type)

      include 'fmodules.inc'
      
      integer nhru, nlands, ncoef, cov_type(MAXHRU)

      transferinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nlands = getdim('nlands')
      if(nlands.eq.-1) return

      ncoef = getdim('ncoef')
      if(ncoef.eq.-1) return

!..landuse/cover type

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

      transferinit = 0

      RETURN
      END

!***********************************************************************
! 
!     transferrun - Transfer unused pet from soil evaporation to plant pet
!

      integer function transferrun(nhru,nlands,ncoef,
     +                           cov_type,hru_petloss)

      include 'fmodules.inc'

      integer nhru, nlands, ncoef, cov_type(MAXHRU)
      real hru_petloss(MAXHRU),  hru_adjustpet(MAXHRU)
      real hru_snow(MAXHRU),  coefs(MAXLANDS,MAXCOEFS)  
      real hru_actevsoil(MAXHRU), hru_pevsoil(MAXHRU)

!..temp vars for this module

      integer i, landcov
      real fc, sa, trns

      transferrun = 1

      if(getvar('intrcp', 'hru_adjustpet',MAXHRU, 'real',hru_adjustpet)
     +   .ne.0) return

      if(getvar('cropcof',  'coefs', MAXLANDS*MAXCOEFS, 'real',  coefs)
     +  .ne.0) return

      if(getvar('soilev', 'hru_pevsoil',   MAXHRU,'real', hru_pevsoil)
     +   .ne.0) return

      if(getvar('soilev', 'hru_actevsoil', MAXHRU,'real',hru_actevsoil)
     +   .ne.0) return

      if(getvar('snowpck', 'hru_snow',     MAXHRU,'real',   hru_snow)
     +   .ne.0) return

      do 1000 i=1,nhru

       hru_petloss(i) = 0.0

!..get landuse

       landcov = cov_type(i)

!..if a water body or impervious skip this hru

      if(landcov.eq.10 .or. landcov.eq.16) then
       go to 1000
      endif

!..if snow covered skip this hru
      
      if(hru_snow(i).gt.0.0000001) go to 1000

!.. get foliar cover for this day for this landuse for this hru/cell/mru

      fc = coefs(landcov,2)

!.. ONLY DO transferance FOR: forest, grasslands, sage and bare soils--ie, non-agricultural areas
!..                          AND foliar cover is less than 60%
 
      if( (landcov.le.3 .or. landcov.eq.13) .and. fc.lt.0.6) then

       SA   = hru_pevsoil(i)-hru_actevsoil(i)
       TRNS = 1.6666 * FC
       hru_adjustpet(i)= hru_adjustpet(i)*FC+TRNS*SA
       hru_petloss(i)  = (SA-TRNS*SA)


      else   !..do other land covers in case evaporated water in excess of saturation
             !..assume no pet loss for this change in petplnt

         hru_adjustpet(i) = hru_adjustpet(i) - hru_actevsoil(i)   

      endif

     
1000  continue


      if(putvar('intrcp', 'hru_adjustpet',MAXHRU, 'real', hru_adjustpet)
     +   .ne.0) return

      transferrun = 0


      RETURN
      END


