!***********************************************************************

!                    WEATHER_SITEINFO_DPM.F

!     WEATHER STATION INFORMATION parameter routine

!   Establish the weather station parameters for the model and writes to file to see
!     the input parameters


!     version: 1.0 (vaccaro/bauer)


      integer function weather_siteinfo_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg
      integer weatherdecl, weatherinit, retval

      integer nrain, ntemp, nthru, nsol, nmonths, nhru
      integer kzone, covthru(MAXTHRU)

      real   ratemn(MAXMO), ratemx(MAXMO)

      real hru_ylat(MAXHRU), hru_xlong(MAXHRU)
      real tsta_x(MAXTEMP),  tsta_y(MAXTEMP), tsta_elev(MAXTEMP)
      real Tnjulav(MAXTEMP), Txjulav(MAXTEMP) 
      real psta_x(MAXRAIN),  psta_y(MAXRAIN)
      real psta_mon_ppt(MAXRAIN,MAXMO)
      real solsta_x(MAXSOL), solsta_y(MAXSOL)
      real thrusta_x(MAXTHRU), thrusta_y(MAXTHRU)

      save  nrain, ntemp, nthru, nsol, nmonths,  kzone
      save  ratemn, ratemx, hru_ylat, hru_xlong, nhru
      save  tsta_x,  tsta_y, tsta_elev, Tnjulav, Txjulav
      save  psta_x,  psta_y, psta_mon_ppt, solsta_x, solsta_y
      save  thrusta_x, thrusta_y, covthru

      retval = 0

      if(arg.eq.'declare') then
        retval = weatherdecl()
      
      else if(arg.eq.'initialize') then
        retval = weatherinit(nrain, ntemp, nthru, nsol, nmonths,kzone,
     +                            ratemn, ratemx, hru_ylat, hru_xlong,
     +                   tsta_x,  tsta_y, tsta_elev, Tnjulav, Txjulav,  
     +                     psta_x,  psta_y, psta_mon_ppt,
     +                     solsta_x, solsta_y, thrusta_x, thrusta_y, 
     +                     covthru, nhru)

      end if

!******Debug level print
      call dpint4('End of weather, retval = ', retval, 1, 2)

      weather_siteinfo_dpm = retval

      return
      end


!***********************************************************************
!     weatherdecl: Declares pameters for weather stations 
!              
 
!     weatherdecl - set up parameters


      integer function weatherdecl()


      include 'fmodules.inc'

      weatherdecl = 1

      if(declparam('weather', 'kzone', 'one', 'integer',
     +   '4601', '0', '4904',
     +   'NOS number for state plane code, =0 IF ALREADY STATE PLANE',
     +   'National Ocean Survey ID number for the state coordinate '//
     +   'system/projection for each state or zone in a state',
     +   'none').ne.0) return

      if(declparam('weather', 'ratemn', 'nmonths', 'real',
     +   '2.0', '0.0', '4.',
     +   'Minimum monthly temperature lapse rate: for each month',
     +   'Minimum monthly temperature lapse rate: for each month',
     +   'degrees/1000 ft').ne.0) return

      if(declparam('weather', 'ratemx', 'nmonths', 'real',
     +   '2.0', '0.0', '5.',
     +   'Maximum monthly temperature lapse rate: for each month',
     +   'Maximum monthly temperature lapse rate: for each month',
     +   'degrees/1000 ft').ne.0) return

      if (declparam ('weather', 'tsta_x', 'ntemp', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each temper. station-state plane or decimal degrees',
     +   'X for each temper. station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tsta_y', 'ntemp', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each temper. station-state plane or decimal degrees',
     +   'Y for each temper. station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tsta_elev', 'ntemp', 'real',
     +   '0.', '-300.', '15000.',
     +   'Temperature station elevation',
     +   'Elevation of each temperature measurement station',
     +   'feet').ne.0) return

      if (declparam ('weather', 'tnjulav', 'ntemp', 'real',
     +   '40.', '33.', '80.',
     +   'AVERAGE July minimum temperature for each temp. station',
     +   'AVERAGE July minimum temperature for each temp. station',
     +   'degrees').ne.0) return

      if (declparam ('weather', 'txjulav', 'ntemp', 'real',
     +   '70.', '40.', '110.',
     +   'AVERAGE July maximum temperature for each temp. station',
     +   'AVERAGE July maximum temperature for each temp. station',
     +   'degrees').ne.0) return

      if (declparam ('weather', 'psta_x', 'nrain', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each precip station (state plane or decimal degrees)',
     +   'X for each precip station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'psta_y', 'nrain', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each precip station (state plane or decimal degrees)',
     +   'Y for each precip station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'psta_mon_ppt','nrain,nmonths', 'real',
     +   '0.', '0.', '60.',
     +   'Average monthly precip at each station',
     +   'Average monthly precip at each station',
     +   'inches').ne.0) return

      if (declparam ('weather', 'thrusta_x', 'nthru', 'real',
     +   '0.', '-10000000.', '10000000.',
     +  'X for each thrufall station (state plane or decimal degrees)',
     +  'X for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'thrusta_y', 'nthru', 'real',
     +   '0.', '-10000000.', '10000000.',
     +  'Y for each thrufall station (state plane or decimal degrees)',
     +  'Y for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if (declparam ('weather', 'covthru', 'nthru', 'integer',
     +   '1', '1', '31',
     +   'Land cover for each thrufall station',
     +   'Land cover for each thrufall station',
     +   'none').ne.0) return

      if (declparam ('weather', 'solsta_x', 'nsol', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'X for each solar rad station-state plane or decimal degrees',
     +   'X for each solar rad station-state plane or decimal degrees',
     +   'feet').ne.0) return

      if (declparam ('weather', 'solsta_y', 'nsol', 'real',
     +   '0.', '-10000000.', '10000000.',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'Y for each thrufall station (state plane or decimal degrees)',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_ylat', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU latitude of centroid, lat or state plane',
     +   'latitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      if(declparam('basin', 'hru_xlong', 'nhru', 'real',
     +   '0', '-1e+09', '1e+09',
     +   'MRU longitude of centroid, long or state plane',
     +   'longitude of each MRU '//
     +   'for the centroid, if degrees converted to state plane',
     +   'feet').ne.0) return

      weatherdecl = 0

      return
      end


!**********************************************************************
!     weatherinit - get input parameters and then initialize 
!               write-out basic input information 

      integer function weatherinit(nrain, ntemp, nthru, nsol, nmonths,
     +               kzone, ratemn, ratemx, hru_ylat, hru_xlong,
     +               tsta_x,  tsta_y, tsta_elev, Tnjulav, Txjulav,  
     +               psta_x,  psta_y, psta_mon_ppt, solsta_x,
     +               solsta_y, thrusta_x, thrusta_y, covthru, nhru)


      include 'fmodules.inc'

      DOUBLE PRECISION X,Y


      integer nrain, ntemp, nthru, nsol, nmonths, nhru
      integer kzone, i, n, covthru(MAXTHRU)

      real   ratemn(MAXMO), ratemx(MAXMO)

      real hru_ylat(MAXHRU), hru_xlong(MAXHRU)
      real tsta_x(MAXTEMP),  tsta_y(MAXTEMP), tsta_elev(MAXTEMP)
      real Tnjulav(MAXTEMP), Txjulav(MAXTEMP) 
      real psta_x(MAXRAIN),  psta_y(MAXRAIN)
      real psta_mon_ppt(MAXRAIN,MAXMO)
      real solsta_x(MAXSOL), solsta_y(MAXSOL)
      real thrusta_x(MAXTHRU), thrusta_y(MAXTHRU)

      character*110 buffer

      weatherinit = 1

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

      nrain = getdim('nrain')
      if(nrain.eq.-1) return

      ntemp = getdim('ntemp')
      if(ntemp.eq.-1) return

      nsol = getdim('nsol')
      if(nsol.eq.-1) return

      nthru = getdim('nthru')
      if(nthru.eq.-1) return

      nmonths = getdim('nmonths')
      if(nmonths.eq.-1) return

!..GET THE PARAMETERS

      if(getparam('weather', 'kzone',  1, 'integer',  kzone)
     +   .ne.0) return

!..MONTHLY MINIMUM AND MAXIMUM LAPSE RATES FOR STUDY AREA
!.....ZERO LAPSE RATES ARE CODED IF CONSIDERED UNIMPORTANT.

      if(getparam('weather', 'ratemn',  MAXMO, 'real', ratemn)
     +   .ne.0) return

      if(getparam('weather', 'ratemx',  MAXMO, 'real', ratemx)
     +   .ne.0) return

!..HRU X,Y'S

      if (getparam ('basin', 'hru_xlong', MAXHRU, 'real', hru_xlong)
     +   .ne.0) return

      if (getparam ('basin', 'hru_ylat',  MAXHRU, 'real', hru_ylat)
     +   .ne.0) return

!.. TEMPERATURE STATION INFO

!.....GET THE X,Y,ALTITUDE,AND AVG-JUL MIN-MAX OF TEMP STATIONS

      if (getparam ('weather', 'tsta_x',  MAXTEMP,   'real', tsta_x)
     +   .ne.0) return

      if (getparam ('weather', 'tsta_y',  MAXTEMP,   'real', tsta_y)
     +   .ne.0) return

      if (getparam ('weather', 'tsta_elev', MAXTEMP, 'real', tsta_elev)
     +   .ne.0) return

      if (getparam ('weather', 'tnjulav',  MAXTEMP,  'real', tnjulav)
     +   .ne.0) return

      if (getparam ('weather', 'txjulav',  MAXTEMP,  'real', txjulav) 
     +   .ne.0) return

!..PRECIP STATION INFO

!.....GET THE X,Y LOCATIONS(LON-LAT DECIMAL. DEG. OR X-Y FEET) AND MEAN monthly 
!.....PRECIP FOR PRECIP STATIONS.

      if (getparam ('weather', 'psta_x',  MAXRAIN,  'real', psta_x)
     +   .ne.0) return

      if (getparam ('weather', 'psta_y',  MAXRAIN,  'real', psta_y)
     +   .ne.0) return

      if (getparam ('weather', 'psta_mon_ppt', MAXRAIN*MAXMO, 'real',
     +    psta_mon_ppt) .ne.0) return

!..THRUFALL STATION INFO

!.....GET THE X,Y LOCATIONS(LON-LAT DECIMAL DEG. OR X-Y FEET) AND LANDUSE
!.....FOR THROUGHFALL STATIONS.

      if (getparam ('weather', 'thrusta_x', MAXTHRU, 'real', thrusta_x)
     +   .ne.0) return

      if (getparam ('weather', 'thrusta_y', MAXTHRU, 'real', thrusta_y)
     +   .ne.0) return

      if (getparam ('weather', 'covthru',  MAXTHRU, 'integer', covthru)
     +   .ne.0) return

!..SOLAR RADIATION STATION INFO

! ....GET THE X,Y OF SOLAR RADIATION DATA SITES 

      if (getparam ('weather', 'solsta_x', MAXSOL,   'real', solsta_x)
     +   .ne.0) return

      if (getparam ('weather', 'solsta_y', MAXSOL,   'real', solsta_y)
     +   .ne.0) return

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1001)  NRAIN
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1002)  NTHRU
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1003)  NTEMP
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1004)  NSOL
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1005) 
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1007)  RATEMN
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1006)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1007)  RATEMX
      CALL OPSTR(BUFFER)

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1008)  kzone 
      CALL OPSTR(BUFFER)

!..calculate hru's x,y if input in lat-long (decimal degree) format

      DO 4  I=1,nhru
      IF(KZONE.GT.0) then
        x=hru_xlong(i)
        y=hru_ylat(i)
       CALL PLANE(X,Y,KZONE)
       hru_xlong(i)= x
       hru_ylat(i) = y
      endif
4     continue

!..output station info and for weather sites
!.... CALCULATE the X,Y's's if input in decimal degrees (KZONE>0)

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1009)  
      CALL OPSTR(BUFFER)

      DO 5  I=1,NRAIN
      WRITE(BUFFER,1010)I,Psta_x(I),Psta_y(I),(PSTA_MON_PPT(I,n),n=1,12)
      CALL OPSTR(BUFFER)
      IF(KZONE.GT.0) then
        x=psta_x(i)
        y=psta_y(i)
       CALL PLANE(X,Y,KZONE)
       psta_x(i)=x
       psta_y(i)=y
      endif
5     continue

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1011)  
      CALL OPSTR(BUFFER)

      DO 6  I=1,NTEMP
      WRITE(BUFFER,1012) I,Tsta_x(I),Tsta_y(I),tsta_elev(I),
     +                   TNjulav(I),TXjulav(I)
      CALL OPSTR(BUFFER)
      IF(KZONE.GT.0) then
        x=tsta_x(i)
        y=tsta_y(i)
       CALL PLANE(X,Y,KZONE)
       tsta_x(i)=x
       tsta_y(i)=y
      endif
6     continue

      if(nsol.gt.0) then

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1013)  
      CALL OPSTR(BUFFER)

      DO 7  I=1,NSOL
      WRITE(BUFFER,1012) I,solsta_x(I),solsta_y(I)
      CALL OPSTR(BUFFER)
      IF(KZONE.GT.0) then
        x=solsta_x(i)
        y=solsta_y(i)
       CALL PLANE(X,Y,KZONE)
       solsta_x(i)=x
       solsta_y(i)=y
      endif
7     continue

      endif

      if(nthru.gt.0) then

      WRITE(BUFFER,1000)
      CALL OPSTR(BUFFER)
      WRITE(BUFFER,1014)  
      CALL OPSTR(BUFFER)

      DO 8  I=1,NTHRU
      WRITE(BUFFER,1015) I, thrusta_x(I),thrusta_y(I),covthru(I)
      CALL OPSTR(BUFFER)
      IF(KZONE.GT.0) then
        x=thrusta_x(i)
        y=thrusta_y(i)
       CALL PLANE(X,Y,KZONE)
       thrusta_x(i)=x
       thrusta_y(i)=y
      endif
8     continue

      endif


!.. OUTPUT FORMATS

1000  FORMAT()
1001  FORMAT(' THE # OF PRECP STATIONS          (NRAIN)    =',I5) 
1002  FORMAT(' THE # OF THROUGHFALL STATIONS    (NTHRU)    =',I5) 
1003  FORMAT(' THE # OF TEMP STATIONS           (NTEMP)    =',I5) 
1004  FORMAT(' THE # OF SOLAR RADIATION SITES   (NSOL)     =',I5) 
1005  FORMAT('  MONTHLY MINIMUM LAPSE RATES ARE: JAN  FEB  MAR  APR  MAY
     .  JUN  JUL  AUG  SEP  OCT  NOV  DEC')
1006  FORMAT('  MONTHLY MAXIMUM LAPSE RATES ARE: JAN  FEB  MAR  APR  MAY
     .  JUN  JUL  AUG  SEP  OCT  NOV  DEC')
1007  FORMAT(19X,'DEG-F/1000 FT: ',12(F4.1,1X))
1008  FORMAT('  ZONE FOR STATE PLANE COORDS,    (KZONE)   =',I5,'; 0 FOR
     . X-Y FT. INSTEAD OF LON-LAT')
1009  FORMAT('  PRCP STATION#, X, Y, LONG-TERM MON PRCP(0.0 FOR NO OROGR
     .APHIC ADJUSTMENTS)')
1010  FORMAT(2X, I4, 2F13.4, 12F6.2)
1011  FORMAT('  TEMP STATION#, X,  Y,     ALTITUDE,   JULY LONG-TERM AVG
     . MIN AND MAX TEMP')
1012  FORMAT(2X, I4, 2F13.4, F8.0, 2F6.1)
1013  FORMAT('  SOLAR RADIATION SITE#, X, Y')
1014  FORMAT('  THRFL STATION#, X, Y, LANDUSE (cov_type) #')
1015  FORMAT(2X, I4, 2F13.4, I5)

      weatherinit = 0

      return
      end




      SUBROUTINE PLANE (FLON,FLAT,KKZONE)                               00000010
C                                                                       00000020
C     GENERALIZED  PLANE COORDINATE CONVERSION PACKAGE 7-30-82 FIPS CODE00000030
C     MODIFIED 6-16-83                                                  00000040
C     REVISED FOR PRIME BY EHKLUITENBERG  6/85 --
C       INSERTED SAVE STATEMENT AT 000130.  CHANGED DFLOAT TO DBLE.
C       AT 000180, 00011200, 00011220.
C       REMOVED DUPLICATE DECLARATION OF DMSD AT 00001790.
C  REV 2/87 WK -- INSERTED WRITE(1... BEFORE EACH ERROR MSG TO PRINT AT TERMNL.
C  rev 1/05 jjv --writes are now MMS so go to buffer and then call opstr(buffer)
C  REV 2/92 JJV--FOR FORWARD TRANSFORMATION ONLY FOR CONT. STATES ONLY
C USGS'S NATIONAL MAPPING DIVISIONS PLANE.F77 PACKAGE, MODIFIED AS ABOVE
C
C
      IMPLICIT REAL*8 (A-H,O-Z)                                         00000050
      INTEGER JTAB(125)                                                 00000070
      INTEGER*4 NOS(139)     
      integer kkzone,IDIR,ISPHER,IZONE,I,ITEST,ICODE
      CHARACTER*50 BUFFER                                               00000080
      COMMON/BLOCK1/ T(11)                                              00000090
      COMMON/BLOCK2/ C1,C2,C3,C4,C5,C6,C7,C8,C9,C10                     00000100
      COMMON/BLOCK3/ D1,D2,D3,D4,D5,D6,D7,D8,D9,D10,D11                 00000110
      COMMON/BLOCK4/ RADSEC                                             00000120
C
C                                                                       00000140
      DATA NOS/101,102,5010,0,201,202,203,301,302,401,402,403,404,405,  00000150
     . 406,407,501,502,503,600,700,901,902,903,1001,1002,5101,5102,5103,00000160
     . 5104,5105,1101,1102,1103,1201,1202,1301,1302,1401,1402,1501,1502,00000170
     . 1601,1602,1701,1702,1703,1801,1802,1900,2001,2002,2101,2102,2103,00000180
     . 2111,2112,2113,2201,2202,2203,2301,2302,2401,2402,2403,2501,2502,00000190
     . 2503,2601,2602,2701,2702,2703,2800,2900,3001,3002,3003,3101,3102,00000200
     . 3103,3104,3200,3301,3302,3401,3402,3501,3502,3601,3602,3701,3702,00000210
     . 3800,3901,3902,4001,4002,4100,4201,4202,4203,4204,4205,4301,4302,00000220
     . 4303,4400,4501,4502,4601,4602,4701,4702,4801,4802,4803,4901,4902,00000230
     . 4903,4904,5201,5202,5300,5400,0,0,0,0,5001,5002,5003,5004,5005,  00000240
     . 5006,5007,5008,5009/                                             00000250
C                                                                       00000260
C                                                                       00000270
      DATA JTAB/                                                        00000280
     1 0,0,1,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,0,               00000290
     2 0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,0,0,1,1,             00000300
     3 1,0,0,0,1,1,1,1,1,1,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,0,             00000310
     4 0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,1,1,1,1,1,             00000320
     5 1,1,1,1,1,0,1,1,1,1,1,1,1,1,1,0,0,0,0,1,1,1/                     00000330
C             DESCRIPTION OF CALL LINE                                  00000340
C     X,Y -- STATE PLANE COORDINATES IN FEET                            00000350
C     FLAT,FLON -- LATITUDE AND LONGITUDE IN DECIDEGREES                00000360
C     CONV -- CONVERGENCE IN DECIDEGREES                                00000370
C     IZONE -- ZONE NUMBER                                              00000380
C     IDIR -- DIRECTION OF CONVERSION: 1 = INVERSE; 0 = FORWARD         00000390
C          FORWARD IS GEOGRAPHIC TO PLANE                               00000400
C          INVERSE IS PLANE COORDINATES TO GEOGRAPHIC                   00000410
C     ISPHER -- SPHEROID SELECTION: 1=CLARKE 1866; 2=CLARKE 1880;       00000420
C               3=BESSEL 1967; 4=NEW INTERNATIONAL 1967;                00000430
C               5=INTERNATIONAL 1909 (1924) (HAYFORD);                  00000440
C               6=WORLD GEODETIC SYSTEM 1972; 7=EVEREST;                00000450
C               8=WORLD GEODETIC SYSTEM 1966;                           00000460
C               9=GEODETIC REFERENCE SYSTEM 1980;                       00000470
C               10=AIRY; 11=MODIFIED EVEREST; 12=MODIFIED AIRY;         00000480
C               13=WALBECK; 14=SOUTH ASIA 1960 (FISCHER);               00000490
C               15=AUSTRALIAN NATIONAL-SOUTH AMERICAN 1969;             00000500
C               16=KRASSOVSKY; 17=HOUGH; 18=MERCURY 1960 (FISCHER);     00000510
C               19=MODIFIED MERCURY 1968 (FISCHER)                      00000520
C     NOTES:                                                            00000530
C            IF ISPHER.EQ.0: COMPUTE IN LAMBERT OR TRANSVERSE MERCATOR  00000540
C            IF ISPHER.NE.0: COMPUTE IN UNIVERSAL TRANSVERSE MERCATOR   00000550
C            IZONE IS UTM ZONE NUMBER OR STATE PLANE ZONE DEPENDING ON  00000560
C            SELECTION OF ISPHER.  IF UTM AND SOUTHERN HEMISPHERE, IZONE00000570
C            IS NEGATIVE.  IF UTM AND IDIR=0, IZONE MAY BE ZERO         00000580
C  ISPHER ALWAYS=0, ALWAYS DO STATE PLANE COORDINATES
C                                                                       00000590

C    PARAMETERS CONV, IDIR, AND ISPHER NOW SET IN PROGRAM FOR DOING ONLY FORWARD
      CONV=0.0001
      FLON=-FLON
      IDIR=0
      ISPHER=0
      IZONE=KKZONE                                                      00000600
      RADSEC = 206264.8062470963D0                                      00000650
      C1 = 101.2794065D0                                                00000660
      C2 = 60.0D0                                                       00000670
      SECS = 3600.0D0                                                   00000680
      C3 = 1052.893882D0                                                00000690
      C4 = 4.483344D0                                                   00000700
      C5 = 0.02352D0                                                    00000710
      C6 = 1.0D8                                                        00000720
      C7 = 9.873675553D-3                                               00000730
      C8 = 1047.54671D0                                                 00000740
      C9 = 6.19276D0                                                    00000750
      C10 = 0.050912D0                                                  00000760
C                                                                       00000770
      D1 = 3.9174D0                                                     00000780
      D2 = 30.92241724D0                                                00000790
      D3 = 4.0831D0                                                     00000800
      D4 = 3.28083333333D0                                              00000810
      D5 = 25.52381D0                                                   00000820
      D6 = 0.3048006099D0                                               00000830
      D7 = 25.52381D0                                                   00000840
      D8 = D3                                                           00000850
      D9 = 1.0D5                                                        00000860
      D10 = 1.0D-10                                                     00000870
      D11 = 1.0D4                                                       00000880
C                                                                       00000890
C     ALL SUBROUTINE INPUT AND OUTPUT OF ANGULAR DATA IS IN             00000900
C     SECONDS. SO CONVERT DECIDEGREES TO SECONDS.                       00000910
      ALAT = FLAT * SECS                                                00000930
      ALON = FLON * SECS                                                00000940
      ALON = - ALON                                                     00000950
   10 XX = X                                                            00000960
      YY = Y                                                            00000970
C                   **** ROUTINGS ****                                  00000980
C     CONVERSION         STATEMENT        ZONES         SPHERE          00000990
C       STATES             300            101-5300        0             00001030
C UTM,ALASKA, GUAM TAKEN OUT                                            00001040
   20 DO 40 I=1,139                                                     00001100
      ITEST = NOS(I)                                                    00001110
      IF (IZONE.NE.ITEST) GO TO 40                                      00001120
      IZONE = I                                                         00001130
      GO TO 50                                                          00001140
   40 CONTINUE                                                          00001150
      GO TO 900                                                         00001160
C                                                                       00001170
C   TEST FOR INVALID CODES                                              00001180
   50 IF (IZONE.GT.139) GO TO 900                                       00001190
      IF (IZONE.EQ.0) GO TO 900                                         00001200
      IF (IZONE.GT.126 .AND. IZONE.LT.131) GO TO 900                    00001210
      IF (IZONE.EQ.4) GO TO 900                                         00001220
C                                                                       00001230
C     TEST FOR ALASKA                                                   00001240
      IF (IZONE.GT.130) GO TO 900                                       00001250
C                                                                       00001260
C     TEST FOR GUAM                                                     00001270
      IF (IZONE.EQ.126) GO TO 900                                       00001280
C                                                                       00001290
C     ONLY POSSIBILITY LEFT IS A STATEPLANE ZONE                        00001300
C              STATE PLANE PROCESSING                                   00001410
C    FIRST GET THE ZONE PARAMETERS AND THE TYPE OF CONVERSION           00001420
300   CALL TAB(IZONE,T)                                                 00001440
      ICODE = JTAB(IZONE) + 1                                           00001450
      GO TO (310,320), ICODE                                            00001460
  310 T(7) = 0.0067686579D0                                             00001470
      CALL TRAMER(XX,YY,ALAT,ALON,IDIR,CONV)                            00001480
      GO TO 500                                                         00001490
  320 CALL TRALAM(XX,YY,ALAT,ALON,IDIR,CONV)                            00001500
      GO TO 500                                                         00001510
C                                                                       00001520
C     AFTER THE CONVERSION -- CHANGE BACK TO DECIDEGREES                00001570
  500 FLAT = YY
      FLON = XX                                                         00001580
      RETURN                                                            00001670
  900 WRITE(buffer,901) IZONE     
      CALL OPSTR(BUFFER)                                                00001680
  901 FORMAT(1X,I6,' ZONE NUMBER IS INVALID')                           00001690
      RETURN                                                            00001720
      END                                                               00001730


      DOUBLE PRECISION FUNCTION DMSD(ID,MIN,SEC)                        00001740
C     CONVERTS AN ANGLE IN DEGREES, MINUTES, SECONDS TO                 00001750
C     DECIDEGREES.                                                      00001760
C     ID IS THE DEGREES IN INTEGER*4 WITH PROPER SIGN                   00001770
C     MIN IS MINUTES IN INTEGER*4, SEC IS SECONDS IN REAL*8             00001780
      REAL*8      SEC,TEMP                                              00001790
      INTEGER*4 ID,MIN
      TEMP =  DBLE (IABS(ID))+ DBLE (MIN)/60.0D0+SEC/3600.0D0           00001800
      IF (ID.LT.0) TEMP = -TEMP                                         00001810
      DMSD = TEMP                                                       00001820
      RETURN                                                            00001830
      END                                                               00001840


      SUBROUTINE DDMS(DEGS,ID,IM,SECS)                                  00011150
C     CONVERT DECIDEGREES TO DEGREES, MINUTES, SECONDS                  00011160
      REAL*8 DEGS,SECS,TEMP                                             00011170
      INTEGER*4 ID,IM
      TEMP = DABS(DEGS)                                                 00011180
      ID = TEMP                                                         00011190
      TEMP = (TEMP- DBLE (ID))*60.0D0                                   00011200
      IM = TEMP                                                         00011210
      SECS = (TEMP- DBLE (IM))*60.0D0                                   00011220
      IF (SECS.LT.59.999D0) GO TO 20                                    00011230
      IM = IM + 1                                                       00011240
      SECS = 0.0D0                                                      00011250
   20 IF (IM.LT.60) GO TO 10                                            00011260
      IM = 0                                                            00011270
      ID = ID + 1                                                       00011280
   10 CONTINUE                                                          00011290
      IF (DEGS.LT.0.0D0) ID = -ID                                       00011300
      RETURN                                                            00011310
      END                                                               00011320
C
      SUBROUTINE TRALAM (X,Y,FLAT,FLONG,IFLAG,CONV)                     00001850
C THIS SUBROUTINE TRANSFORMS COORDINATES FROM STATE PLANE TO GEOGRAPHIC 00001860
C SYSTEM AND VICE VERSA. THE STATE PLANE COORDINATES ARE GIVEN IN A     00001870
C LAMBERT PROJECTION.                                                   00001880
C IFLAG = 0 , MEANS GEOGRAPHIC TO PLANE.                                00001890
C IFLAG = 1 , MEANS PLANE TO GEOGRAPHIC.                                00001900
      IMPLICIT REAL*8(A-H,O-Z)                                          00001910
      REAL*8 X,Y,FLAT,FLONG,CONV                                        00001920
      INTEGER I,IFLAG
      character*40 buffer
      COMMON /BLOCK1/ T(11)                                             00001930
      COMMON /BLOCK2/ C1,C2,C3,C4,C5,C6,C7,C8,C9,C10                    00001940
      COMMON /BLOCK3/ D1,D2,D3,D4,D5,D6,D7,D8,D9,D10,D11                00001950
      COMMON /BLOCK4/ RADSEC                                            00001960
      IF (IFLAG) 20,10,20                                               00001970
C                                                                       00001980
C TRANSFORM FROM GEOGRAPHIC TO PLANE COORDINATES.                       00001990
   10 PHI = FLAT / RADSEC                                               00002000
      SINPH = DSIN(PHI)                                                 00002010
      COSPH = DCOS(PHI)                                                 00002020
      TEMP = C4 - C5 * COSPH**2                                         00002030
      TEMP = C3 - TEMP * COSPH**2                                       00002040
      TEMP = SINPH * COSPH * TEMP                                       00002050
      S = C1 * ( C2 * T(7) + T(8) - FLAT + TEMP )                       00002060
      TEMP = S / C6                                                     00002070
      TEMP1 = T(9) - T(10) * TEMP + T(11) * TEMP**2                     00002080
      TEMP = 1.D0+ TEMP1 * TEMP**2                                      00002090
      R = T(3) + S * T(5) * TEMP                                        00002100
      THETA = T(6) * ( T(2) - FLONG )                                   00002110
      THETA = THETA / RADSEC                                            00002120
      SINTH = DSIN(THETA)                                               00002130
      SINHTH = DSIN(THETA/2.0 D0)                                       00002140
      X = R * SINTH + T(1)                                              00002150
      Y = T(4) - R + 2.D0* R * SINHTH**2                                00002160
      GO TO 70                                                          00002170
C                                                                       00002180
C TRANSFORM FROM PLANE TO GEOGRAPHIC COORDINATES.                       00002190
   20 TEMP = ( X - T(1) ) / ( T(4) - Y )                                00002200
      THETA = DATAN(TEMP)                                               00002210
      COSTH = DCOS(THETA)                                               00002220
      SINHTH = DSIN(THETA/2.0 D0)                                       00002230
      FLONG = T(2) - THETA * RADSEC / T(6)                              00002240
      R = ( T(4) - Y ) / COSTH                                          00002250
      YPRIME = Y - 2.D0* R * SINHTH**2                                  00002260
      SAPP = ( T(4) - T(3) - YPRIME ) / T(5)                            00002270
      SAPPP = SAPP                                                      00002280
      DO 50 I=1,10                                                      00002290
      TEMP = SAPP / C6                                                  00002300
      TEMP = T(9) * TEMP**2 - T(10) * TEMP**3 + T(11) * TEMP**4         00002310
      S = SAPPP / ( 1.D0+ TEMP )                                        00002320
      DIFF = S - SAPP                                                   00002330
      DIFF = DABS(DIFF)                                                 00002340
      IF ( DIFF - 0.1 ) 30,30,40                                        00002350
   30 DIFF = SAPPP * TEMP * ( 1.D0- TEMP )                              00002360
      S = SAPPP - DIFF                                                  00002370
      DIFF = S - SAPP                                                   00002380
      IF (DABS(DIFF) - 0.01D0) 60,60,40                                 00002390
   40 SAPP = S                                                          00002400
   50 CONTINUE                                                          00002410
      WRITE(buffer,1000)                                                 00002420
      call opstr(buffer)
 1000 FORMAT(' ******************* ERROR LAMBERT ***************')      00002430
      IF (IFLAG) 120,110,120                                            00002440
  110 X = 0.0D0                                                         00002450
      Y = 0.0D0                                                         00002460
      GO TO 130                                                         00002470
  120 FLAT = 0.0D0                                                      00002480
  130 CONTINUE                                                          00002490
   60 WSEC = C2 * T(7) + T(8) - C7 * S                                  00002500
      W = WSEC / RADSEC                                                 00002510
      SINW = DSIN(W)                                                    00002520
      COSW = DCOS(W)                                                    00002530
      TEMP = C9 + C10 * COSW**2                                         00002540
      TEMP = C8 + TEMP * COSW**2                                        00002550
      FLAT = WSEC + SINW * COSW * TEMP                                  00002560
   70 CONV = T(6)*(T(2)-FLONG)                                          00002570
      RETURN                                                            00002580
      END                                                               00002590
      SUBROUTINE TRAMER (X,Y,FLAT,FLONG,IFLAG,CONV)                     00002600
C THIS SUBROUTINE TRANSFORMS COORDINATES FROM STATE PLANE TO GEOGRAPHIC 00002610
C SYSTEM AND VICE VERSA. THE STATE PLANE COORDINATES ARE GIVEN IN A     00002620
C TRANSVERSE MERCATOR PROJECTION.                                       00002630
C                                                                       00002640
C IFLAG = 0 , MEANS GEOGRAPHIC TO PLANE.                                00002650
C IFLAG = 1 , MEANS PLANE TO GEOGRAPHIC.                                00002660
      IMPLICIT REAL*8(A-H,O-Z)                                          00002670
      REAL*8 X,Y,FLAT,FLONG,CONV                                        00002680
      INTEGER I,IFLAG
      character*40 buffer
      COMMON /BLOCK1/ T(11)                                             00002690
      COMMON /BLOCK2/ C1,C2,C3,C4,C5,C6,C7,C8,C9,C10                    00002700
      COMMON /BLOCK3/ D1,D2,D3,D4,D5,D6,D7,D8,D9,D10,D11                00002710
      COMMON /BLOCK4/ RADSEC                                            00002720
      ESQ = T(7)                                                        00002730
C                                                                       00002740
C TRANSFORM FROM GEOGRAPHIC TO PLANE COORDINATES.                       00002750
C                                                                       00002760
      IF (IFLAG)  50,10,50                                              00002770
   10 DL = T(2) - FLONG                                                 00002780
      TEMP = DL/D11                                                     00002790
      DL1 = DL - D1 * TEMP**3                                           00002800
      FLATR = FLAT / RADSEC                                             00002810
      SINPH = DSIN(FLATR)                                               00002820
      COSPH = DCOS(FLATR)                                               00002830
      CON1 = 1.D0- ESQ * SINPH**2                                       00002840
      CON1 = DSQRT(CON1)                                                00002850
      S1 = D2 * COSPH * DL1 / CON1                                      00002860
      TEMP = S1 / D9                                                    00002870
      SM = S1 + D3 * TEMP**3                                            00002880
      SG = D4 * T(5) * SM                                               00002890
      TEMP = SG / D9                                                    00002900
      XP = SG + T(6) * TEMP**3                                          00002910
      X = T(1) + XP                                                     00002920
      DLPI = 0.0 D0                                                     00002930
      DO 30 I=1,10                                                      00002940
      PHI = FLATR + DLPI / RADSEC                                       00002950
      SINPH = DSIN(PHI)                                                 00002960
      COSPH = DCOS(PHI)                                                 00002970
      TANPH = SINPH/COSPH                                               00002980
      CON1 = 1.D0 - ESQ * SINPH**2                                      00002990
      B = D5 * D10 * TANPH * CON1**2                                    00003000
      DLPIN = B * SM**2                                                 00003010
      DIFF = DLPI - DLPIN                                               00003020
      DIFF = DABS(DIFF)                                                 00003030
      EPSLN = DIFF - 0.0001                                             00003040
      IF (EPSLN)  40,40,20                                              00003050
   20 DLPI = DLPIN                                                      00003060
   30 CONTINUE                                                          00003070
      WRITE(buffer,1000)                                                     00003080
      call opstr(buffer)
 1000 FORMAT(' ******************* ERROR MERCATOR **************')      00003090
      IF (IFLAG) 120,110,120                                            00003100
  110 X = 0.0D0                                                         00003110
      Y = 0.0D0                                                         00003120
      GO TO 130                                                         00003130
  120 FLAT = 0.0D0                                                      00003140
      FLONG = 0.0D0                                                     00003150
  130 CONTINUE                                                          00003160
   40 FLATR = FLATR + DLPIN / RADSEC                                    00003170
      SINPH = DSIN(FLATR)                                               00003180
      COSPH = DCOS(FLATR)                                               00003190
      TEMP = C4 - C5 * COSPH**2                                         00003200
      TEMP = C3 - TEMP * COSPH**2                                       00003210
      TEMP = FLAT + DLPIN - C2 * T(3) - T(4) - SINPH * COSPH * TEMP     00003220
      Y = C1 * T(5) * TEMP                                              00003230
      GO TO 60                                                          00003240
C                                                                       00003250
C TRANSFORM FROM PLANE TO GEOGRAPHIC COORDINATES.                       00003260
C                                                                       00003270
   50 XP = X - T(1)                                                     00003280
      TEMP = XP / D9                                                    00003290
      SG1 = XP - T(6) * TEMP**3                                         00003300
      TEMP = SG1 / D9                                                   00003310
      SG = XP - T(6) * TEMP**3                                          00003320
      SM = D6 * SG / T(5)                                               00003330
      WSEC = C2 * T(3) + T(4) + C7 * Y / T(5)                           00003340
      W = WSEC / RADSEC                                                 00003350
      SINW = DSIN(W)                                                    00003360
      COSW = DCOS(W)                                                    00003370
      TEMP = C9 + C10 * COSW**2                                         00003380
      TEMP = C8 + TEMP * COSW**2                                        00003390
      PHI = WSEC + SINW * COSW * TEMP                                   00003400
      FLAT = PHI / RADSEC                                               00003410
      SINPH = DSIN(FLAT)                                                00003420
      COSPH = DCOS(FLAT)                                                00003430
      CON1 = 1.D0 - ESQ * SINPH**2                                      00003440
      TANPH = SINPH / COSPH                                             00003450
      DLAT = D5 * D10 * (SM**2) * TANPH * CON1**2                       00003460
      FLAT = PHI - DLAT                                                 00003470
      PHI = FLAT / RADSEC                                               00003480
      SINPH = DSIN(PHI)                                                 00003490
      COSPH = DCOS(PHI)                                                 00003500
      TEMP = SM / D9                                                    00003510
      SA = SM - D8 * TEMP**3                                            00003520
      TEMP = SA / D9                                                    00003530
      S1 = SM - D8 * TEMP**3                                            00003540
      CON1 = 1.D0 - ESQ * SINPH**2                                      00003550
      CON1 = DSQRT(CON1)                                                00003560
      DLAM1 = S1 * CON1 / D2 / COSPH                                    00003570
      TEMP = DLAM1 / D11                                                00003580
      DLAMA = DLAM1 + D1 * TEMP**3                                      00003590
      TEMP = DLAMA / D11                                                00003600
      DLAM = DLAM1 + D1 * TEMP**3                                       00003610
      FLONG = T(2) - DLAM                                               00003620
   60 CONV = (T(2)-FLONG)*(DSIN(PHI)+1.9587D-12*(T(2)-FLONG)**2         00003630
     . *DSIN(PHI)*DCOS(PHI)**2)                                         00003640
      RETURN                                                            00003650
      END                                                               00003660
C
      SUBROUTINE DMSTOD(FIN,FOUT)                                       00006920
C     TAKES SDDDMMSS.SSS AND CONVERTS TO DECIDEGREES                    00006930
      IMPLICIT REAL*8 (A-H,O-Z)                                         00006940
      REAL*8 FIN,FOUT                                                   00006950
      SEC = DMOD(FIN,100.0D0)                                           00006960
      AMIN = DMOD((FIN-SEC),10000.0D0)/100.0D0                          00006970
      DEG = (FIN - SEC - AMIN*100.0D0)/10000.0D0                        00006980
      FOUT = DEG + AMIN/60.0D0 + SEC/3600.0D0                           00006990
      RETURN                                                            00007000
      END                                                               00007010
      SUBROUTINE TAB(J,T)                                               00007020
C                                                                       00007030
C     THIS SUBROUTINE INSERTS THE PERTINENT ZONE PARAMETERS FOR ZONE J  00007040
C     INTO ARRAY T(11).  THE INDIVIDUAL ZONES ARE IN ARRAYS ZON1        00007050
C     THROUGH ZON125 WHICH ARE IN TURN EQUIVALENCED TO ARRAY            00007060
C     ZONE(11,125) SUCH THAT ZON1(1) IS ZONE(1,1), ZON2(1) IS ZONE(1,2) 00007070
C     ETC.   ZONE(J,11) IS THEN INSERTED INTO T(11).                    00007080
C          JACK WAANANEN  RT-P                OCTOBER 18, 1979          00007090
C                                                                       00007100
C
C   FURTHER MODIFIED BY J. VACCARO 6/1992 TO ELIMINATE EQUIVALENCING OF SINGLE
C   TO DOUBLE SUBSCRIPTED ARRAYS (WILL NOT WORK ON ALL MACHINES SINCE NOT
C   F77 STANDARD). DOUBLE DIMENSION WAS USED TO FIND PROPER ZON#() ARRAY FOR
C   SETTING INTO ARRAY T IN CALL SEQUENCE.  J (IZONE) IN CALL IS NOW USED
C   AS INDICE TO FIND LOCATION ON ZONE ARRAY FOR 11 PARAMETERS PUT INTO T(11)

      INTEGER I,J,K,INDICE
C
      REAL*8 T(11),ZONE(1375),ZON1(11),ZON2(11),ZON3(11),ZON4(11),      00007110
     . ZON5(11),ZON6(11),ZON7(11),ZON8(11),ZON9(11),ZON10(11),ZON11(11),00007120
     . ZON12(11),ZON13(11),ZON14(11),ZON15(11),ZON16(11),ZON17(11),     00007130
     . ZON18(11),ZON19(11),ZON20(11),ZON21(11),ZON22(11),ZON23(11),     00007140
     . ZON24(11),ZON25(11),ZON26(11),ZON27(11),ZON28(11),ZON29(11),     00007150
     . ZON30(11),ZON31(11),ZON32(11),ZON33(11),ZON34(11),ZON35(11),     00007160
     . ZON36(11),ZON37(11),ZON38(11),ZON39(11),ZON40(11),ZON41(11),     00007170
     . ZON42(11),ZON43(11),ZON44(11),ZON45(11),ZON46(11),ZON47(11),     00007180
     . ZON48(11),ZON49(11),ZON50(11),ZON51(11),ZON52(11),ZON53(11),     00007190
     . ZON54(11),ZON55(11),ZON56(11),ZON57(11),ZON58(11),ZON59(11),     00007200
     . ZON60(11),ZON61(11),ZON62(11),ZON63(11),ZON64(11),ZON65(11),     00007210
     . ZON66(11),ZON67(11),ZON68(11),ZON69(11),ZON70(11),ZON71(11),     00007220
     . ZON72(11),ZON73(11),ZON74(11),ZON75(11),ZON76(11),ZON77(11),     00007230
     . ZON78(11),ZON79(11),ZON80(11),ZON81(11),ZON82(11),ZON83(11),     00007240
     . ZON84(11),ZON85(11),ZON86(11),ZON87(11),ZON88(11),ZON89(11),     00007250
     . ZON90(11),ZON91(11),ZON92(11),ZON93(11),ZON94(11),ZON95(11),     00007260
     . ZON96(11),ZON97(11),ZON98(11),ZON99(11)                          00007270
C                                                                       00007280
      REAL*8 ZON100(11),ZON101(11),ZON102(11),ZON103(11),ZON104(11),    00007290
     .ZON105(11),ZON106(11),ZON107(11),ZON108(11),ZON109(11),ZON110(11),00007300
     .ZON111(11),ZON112(11),ZON113(11),ZON114(11),ZON115(11),ZON116(11),00007310
     .ZON117(11),ZON118(11),ZON119(11),ZON120(11),ZON121(11),ZON122(11),00007320
     .ZON123(11),ZON124(11),ZON125(11)                                  00007330
C                                                                       00007340
      EQUIVALENCE (ZON1(1),ZONE(1)),(ZON2(1),ZONE(12)),                 00007350
     . (ZON3(1),ZONE(23)),(ZON4(1),ZONE(34)),(ZON5(1),ZONE(45)),        00007360
     . (ZON6(1),ZONE(56)),(ZON7(1),ZONE(67)),(ZON8(1),ZONE(78)),        00007370
     . (ZON9(1),ZONE(89)),(ZON10(1),ZONE(100)),(ZON11(1),ZONE(111)),    00007380
     .(ZON12(1),ZONE(122)),(ZON13(1),ZONE(133)),(ZON14(1),ZONE(144)),   00007390
     .(ZON15(1),ZONE(155)),(ZON16(1),ZONE(166)),(ZON17(1),ZONE(177)),   00007400
     .(ZON18(1),ZONE(188)),(ZON19(1),ZONE(199)),(ZON20(1),ZONE(210)),   00007410
     .(ZON21(1),ZONE(221)),(ZON22(1),ZONE(232)),(ZON23(1),ZONE(243)),   00007420
     .(ZON24(1),ZONE(254)),(ZON25(1),ZONE(265)),(ZON26(1),ZONE(276)),   00007430
     .(ZON27(1),ZONE(287)),(ZON28(1),ZONE(298)),(ZON29(1),ZONE(309)),   00007440
     .(ZON30(1),ZONE(320)),(ZON31(1),ZONE(331)),(ZON32(1),ZONE(342)),   00007450
     .(ZON33(1),ZONE(353)),(ZON34(1),ZONE(364)),(ZON35(1),ZONE(375)),   00007460
     .(ZON36(1),ZONE(386)),(ZON37(1),ZONE(397)),(ZON38(1),ZONE(408)),   00007470
     .(ZON39(1),ZONE(419)),(ZON40(1),ZONE(430)),(ZON41(1),ZONE(441)),   00007480
     .(ZON42(1),ZONE(452)),(ZON43(1),ZONE(463)),(ZON44(1),ZONE(474)),   00007490
     .(ZON45(1),ZONE(485)),(ZON46(1),ZONE(496)),(ZON47(1),ZONE(507))    00007500
C                                                                       00007510
      EQUIVALENCE (ZON48(1),ZONE(518)),(ZON49(1),ZONE(529)),            00007520
     .(ZON50(1),ZONE(540)),(ZON51(1),ZONE(551)),(ZON52(1),ZONE(562)),   00007530
     .(ZON53(1),ZONE(573)),(ZON54(1),ZONE(584)),(ZON55(1),ZONE(595)),   00007540
     .(ZON56(1),ZONE(606)),(ZON57(1),ZONE(617)),(ZON58(1),ZONE(628)),   00007550
     .(ZON59(1),ZONE(639)),(ZON60(1),ZONE(650)),(ZON61(1),ZONE(661)),   00007560
     .(ZON62(1),ZONE(672)),(ZON63(1),ZONE(683)),(ZON64(1),ZONE(694)),   00007570
     .(ZON65(1),ZONE(705)),(ZON66(1),ZONE(716)),(ZON67(1),ZONE(727)),   00007580
     .(ZON68(1),ZONE(738)),(ZON69(1),ZONE(749)),(ZON70(1),ZONE(760)),   00007590
     .(ZON71(1),ZONE(771)),(ZON72(1),ZONE(782)),(ZON73(1),ZONE(793)),   00007600
     .(ZON74(1),ZONE(804)),(ZON75(1),ZONE(815)),(ZON76(1),ZONE(826)),   00007610
     .(ZON77(1),ZONE(837)),(ZON78(1),ZONE(848)),(ZON79(1),ZONE(859)),   00007620
     .(ZON80(1),ZONE(870)),(ZON81(1),ZONE(881)),(ZON82(1),ZONE(892)),   00007630
     .(ZON83(1),ZONE(903)),(ZON84(1),ZONE(914)),(ZON85(1),ZONE(925)),   00007640
     .(ZON86(1),ZONE(936)),(ZON87(1),ZONE(947)),(ZON88(1),ZONE(958)),   00007650
     .(ZON89(1),ZONE(969)),(ZON90(1),ZONE(980)),(ZON91(1),ZONE(991))    00007660
C                                                                       00007670
      EQUIVALENCE (ZON92(1),ZONE(1002)),(ZON93(1),ZONE(1013)),          00007680
     .(ZON94(1),ZONE(1024)),(ZON95(1),ZONE(1035)),                      00007690
     .(ZON96(1),ZONE(1046)),(ZON97(1),ZONE(1057)),                      00007700
     .(ZON98(1),ZONE(1068)),(ZON99(1),ZONE(1079)),                      00007710
     .(ZON100(1),ZONE(1090)),(ZON101(1),ZONE(1101)),                    00007720
     .(ZON102(1),ZONE(1112)),(ZON103(1),ZONE(1123)),                    00007730
     .(ZON104(1),ZONE(1134)),(ZON105(1),ZONE(1145)),                    00007740
     .(ZON106(1),ZONE(1156)),(ZON107(1),ZONE(1167)),                    00007750
     .(ZON108(1),ZONE(1178)),(ZON109(1),ZONE(1189)),                    00007760
     .(ZON110(1),ZONE(1200)),(ZON111(1),ZONE(1211)),                    00007770
     .(ZON112(1),ZONE(1222)),(ZON113(1),ZONE(1233)),                    00007780
     .(ZON114(1),ZONE(1244)),(ZON115(1),ZONE(1255)),                    00007790
     .(ZON116(1),ZONE(1266)),(ZON117(1),ZONE(1277)),                    00007800
     .(ZON118(1),ZONE(1288)),(ZON119(1),ZONE(1299)),                    00007810
     .(ZON120(1),ZONE(1310)),(ZON121(1),ZONE(1321)),                    00007820
     .(ZON122(1),ZONE(1332)),(ZON123(1),ZONE(1343)),                    00007830
     .(ZON124(1),ZONE(1354)),(ZON125(1),ZONE(1365))                     00007840
C                                                                       00007850
      DATA ZON1/0.5000000000D+06,0.3090000000D+06,0.1822000000D+04,     00007860
     X0.2100903000D+02,0.9999600000D+00,0.3817065000D+00,5*0.0D0/       00007870
      DATA ZON2/0.5000000000D+06,0.3150000000D+06,0.1792000000D+04,     00007880
     X0.2553386000D+02,0.9999333333D+00,0.3817477000D+00,5*0.0D0/       00007890
      DATA ZON3/0.3000000000D+07,0.6336000000D+06,0.1589395036D+08,     00007900
     X0.1656462877D+08,0.9998480641D+00,0.7969223940D+00,0.3161D+04,    00007910
     X0.4787068D+02,0.3799190D+01,0.5915500D+01,0.4400000D+02/          00007920
      DATA ZON5/0.5000000000D+06,0.3966000000D+06,0.1852000000D+04,     00007930
     X0.1662358000D+02,0.9999000000D+00,0.3816485000D+00,5*0.0D0/       00007940
      DATA ZON6/0.5000000000D+06,0.4029000000D+06,0.1852000000D+04,     00007950
     X0.1662358000D+02,0.9999000000D+00,0.3816485000D+00,5*0.0D0/       00007960
      DATA ZON7/0.5000000000D+06,0.4095000000D+06,0.1852000000D+04,     00007970
     X0.1662358000D+02,0.9999333333D+00,0.3815948000D+00,5*0.0D0/       00007980
      DATA ZON8/0.2000000000D+07,0.3312000000D+06,0.2927759361D+08,     00007990
     X0.2973288287D+08,0.9999359370D+00,0.5818991407D+00,0.2126D+04,    00008000
     X0.4635656D+02,0.3814520D+01,0.3264320D+01,0.0          /          00008010
      DATA ZON9/0.2000000000D+07,0.3312000000D+06,0.3101403923D+08,     00008020
     X0.3151172420D+08,0.9999184698D+00,0.5596906871D+00,0.2033D+04,    00008030
     X0.5694711D+02,0.3815500D+01,0.3082560D+01,0.0          /          00008040
      DATA ZON10/0.2000000000D+07,0.4392000000D+06,0.2424535805D+08,    00008050
     X0.2479243623D+08,0.9998946358D+00,0.6538843192D+00,0.2441D+04,    00008060
     X0.2675847D+02,0.3809920D+01,0.3935750D+01,0.0          /          00008070
      DATA ZON11/0.2000000000D+07,0.4392000000D+06,0.2579585031D+08,    00008080
     X0.2631225765D+08,0.9999146793D+00,0.6304679732D+00,0.2336D+04,    00008090
     X0.3081964D+02,0.3811470D+01,0.3701140D+01,0.0          /          00008100
      DATA ZON12/0.2000000000D+07,0.4338000000D+06,0.2705747585D+08,    00008110
     X0.2751299204D+08,0.9999291792D+00,0.6122320427D+00,0.2256D+04,    00008120
     X0.3552018D+02,0.3812650D+01,0.3529980D+01,0.0          /          00008130
      DATA ZON13/0.2000000000D+07,0.4284000000D+06,0.2818240533D+08,    00008140
     X0.2865293196D+08,0.9999407628D+00,0.5965871443D+00,0.2189D+04,    00008150
     X0.1035494D+02,0.3813620D+01,0.3390200D+01,0.0          /          00008160
      DATA ZON14/0.2000000000D+07,0.4248000000D+06,0.3019414554D+08,    00008170
     X0.3064942427D+08,0.9999221277D+00,0.5700119219D+00,0.2076D+04,    00008180
     X0.5210305D+02,0.3815230D+01,0.3165930D+01,0.0          /          00008190
      DATA ZON15/0.2000000000D+07,0.4185000000D+06,0.3184657092D+08,    00008200
     X0.3227126772D+08,0.9999541438D+00,0.5495175982D+00,0.1992D+04,    00008210
     X0.1633500D+00,0.3816420D+01,0.3002920D+01,0.0          /          00008220
      DATA ZON16/0.4186692580D+07,0.4260000000D+06,0.3089138210D+08,    00008230
     X0.3505539631D+08,0.9999885350D+00,0.5612432071D+00,0.2040D+04,    00008240
     X0.2288096D+02,0.3815720D+01,0.3095200D+01,0.0          /          00008250
      DATA ZON17/0.2000000000D+07,0.3798000000D+06,0.2475189768D+08,    00008260
     X0.2508606820D+08,0.9999568475D+00,0.6461334829D+00,0.2406D+04,    00008270
     X0.2462308D+02,0.3810440D+01,0.3856100D+01,0.0          /          00008280
      DATA ZON18/0.2000000000D+07,0.3798000000D+06,0.2578137691D+08,    00008290
     X0.2624305274D+08,0.9999359117D+00,0.6306895773D+00,0.2337D+04,    00008300
     X0.2965162D+02,0.3811460D+01,0.3703260D+01,0.0          /          00008310
      DATA ZON19/0.2000000000D+07,0.3798000000D+06,0.2697713389D+08,    00008320
     X0.2740223182D+08,0.9999453995D+00,0.6133780528D+00,0.2261D+04,    00008330
     X0.3426662D+02,0.3812570D+01,0.3540460D+01,0.0          /          00008340
      DATA ZON20/0.6000000000D+06,0.2619000000D+06,0.2365923356D+08,    00008350
     X0.2391438902D+08,0.9999831405D+00,0.6630594147D+00,0.2483D+04,    00008360
     X0.1967980D+02,0.3809290D+01,0.4032780D+01,0.0          /          00008370
      DATA ZON21/0.5000000000D+06,0.2715000000D+06,0.2271000000D+04,    00008380
     X0.3053702000D+02,0.9999950281D+00,0.3811454000D+00,5*0.0D0/       00008390
      DATA ZON22/0.5000000000D+06,0.2916000000D+06,0.1453000000D+04,    00008400
     X0.2609287000D+02,0.9999411765D+00,0.3821090000D+00,5*0.0D0/       00008410
      DATA ZON23/0.5000000000D+06,0.2952000000D+06,0.1453000000D+04,    00008420
     X0.2609287000D+02,0.9999411765D+00,0.3821090000D+00,5*0.0D0/       00008430
      DATA ZON24/0.2000000000D+07,0.3042000000D+06,0.3603044305D+08,    00008440
     X0.3645492453D+08,0.9999484343D+00,0.5025259000D+00,0.1802D+04,    00008450
     X0.2611701D+02,0.3818980D+01,0.2656430D+01,0.0          /          00008460
      DATA ZON25/0.5000000000D+06,0.2958000000D+06,0.1792000000D+04,    00008470
     X0.2553386000D+02,0.9999000000D+00,0.3817593000D+00,5*0.0D0/       00008480
      DATA ZON26/0.5000000000D+06,0.3030000000D+06,0.1792000000D+04,    00008490
     X0.2553386000D+02,0.9999000000D+00,0.3817593000D+00,5*0.0D0/       00008500
      DATA ZON27/0.5000000000D+06,0.5598000000D+06,0.1124000000D+04,    00008510
     X0.3952714000D+02,0.9999666667D+00,0.3826496000D+00,5*0.0D0/       00008520
      DATA ZON28/0.5000000000D+06,0.5640000000D+06,0.1214000000D+04,    00008530
     X0.1821554000D+02,0.9999666667D+00,0.3825762000D+00,5*0.0D0/       00008540
      DATA ZON29/0.5000000000D+06,0.5688000000D+06,0.1264000000D+04,    00008550
     X0.6774970000D+01,0.9999900000D+00,0.3825176000D+00,5*0.0D0/       00008560
      DATA ZON30/0.5000000000D+06,0.5742000000D+06,0.1303000000D+04,    00008570
     X0.5783623000D+02,0.9999900000D+00,0.3824812000D+00,5*0.0D0/       00008580
      DATA ZON31/0.5000000000D+06,0.5766000000D+06,0.1294000000D+04,    00008590
     X0.5280000000D-01,0.9999999999D+00,0.3824867000D+00,5*0.0D0/       00008600
      DATA ZON32/0.5000000000D+06,0.4038000000D+06,0.2491000000D+04,    00008610
     X0.1835156000D+02,0.9999473684D+00,0.3807624000D+00,5*0.0D0/       00008620
      DATA ZON33/0.5000000000D+06,0.4104000000D+06,0.2491000000D+04,    00008630
     X0.1835156000D+02,0.9999473684D+00,0.3807624000D+00,5*0.0D0/       00008640
      DATA ZON34/0.5000000000D+06,0.4167000000D+06,0.2491000000D+04,    00008650
     X0.1835156000D+02,0.9999333333D+00,0.3806227000D+00,5*0.0D0/       00008660
      DATA ZON35/0.5000000000D+06,0.3180000000D+06,0.2191000000D+04,    00008670
     X0.3704639000D+02,0.9999750000D+00,0.3811074000D+00,5*0.0D0/       00008680
      DATA ZON36/0.5000000000D+06,0.3246000000D+06,0.2191000000D+04,    00008690
     X0.3704639000D+02,0.9999411765D+00,0.3811332000D+00,5*0.0D0/       00008700
      DATA ZON37/0.5000000000D+06,0.3084000000D+06,0.2241000000D+04,    00008710
     X0.3284965000D+02,0.9999666667D+00,0.3811064000D+00,5*0.0D0/       00008720
      DATA ZON38/0.5000000000D+06,0.3135000000D+06,0.2241000000D+04,    00008730
     X0.3284965000D+02,0.9999666667D+00,0.3811064000D+00,5*0.0D0/       00008740
      DATA ZON39/0.2000000000D+07,0.3366000000D+06,0.2273695034D+08,    00008750
     X0.2316246159D+08,0.9999453686D+00,0.6777445518D+00,0.2551D+04,    00008760
     X0.2002265D+02,0.3808270D+01,0.4194790D+01,0.0          /          00008770
      DATA ZON40/0.2000000000D+07,0.3366000000D+06,0.2393658511D+08,    00008780
     X0.2437409667D+08,0.9999483705D+00,0.6587010213D+00,0.2463D+04,    00008790
     X0.2259905D+02,0.3809590D+01,0.3986300D+01,0.0          /          00008800
      DATA ZON41/0.2000000000D+07,0.3528000000D+06,0.2564495912D+08,    00008810
     X0.2597906857D+08,0.9999568556D+00,0.6327148646D+00,0.2346D+04,    00008820
     X0.2797215D+02,0.3811330D+01,0.3723760D+01,0.0          /          00008830
      DATA ZON42/0.2000000000D+07,0.3546000000D+06,0.2689602448D+08,    00008840
     X0.2735152150D+08,0.9999359200D+00,0.6145281068D+00,0.2266D+04,    00008850
     X0.3441020D+02,0.3812500D+01,0.3551020D+01,0.0          /          00008860
      DATA ZON43/0.2000000000D+07,0.3033000000D+06,0.2637182068D+08,    00008870
     X0.2672405182D+08,0.9999620817D+00,0.6220672671D+00,0.2299D+04,    00008880
     X0.3063364D+02,0.3812020D+01,0.3621130D+01,0.0          /          00008890
      DATA ZON44/0.2000000000D+07,0.3087000000D+06,0.2746786075D+08,    00008900
     X0.2783223564D+08,0.9999453808D+00,0.6064623718D+00,0.2231D+04,    00008910
     X0.3657874D+02,0.3813010D+01,0.3477710D+01,0.0          /          00008920
      DATA ZON45/0.2000000000D+07,0.3330000000D+06,0.3362456836D+08,    00008930
     X0.3407962933D+08,0.9999147417D+00,0.5287006734D+00,0.1907D+04,    00008940
     X0.1268515D+02,0.3817580D+01,0.2845110D+01,0.0          /          00008950
      DATA ZON46/0.2000000000D+07,0.3288000000D+06,0.3627138935D+08,    00008960
     X0.3675655345D+08,0.9999257458D+00,0.5000126971D+00,0.1792D+04,    00008970
     X0.2855026D+02,0.3819110D+01,0.2638850D+01,0.0          /          00008980
      DATA ZON47/0.2000000000D+07,0.3288000000D+06,0.4109174954D+08,    00008990
     X0.4157676239D+08,0.9998947956D+00,0.4540068519D+00,0.1612D+04,    00009000
     X0.5930342D+02,0.3821380D+01,0.2274360D+01,0.2500000D+02/          00009010
      DATA ZON48/0.5000000000D+06,0.2466000000D+06,0.2621000000D+04,    00009020
     X0.1515187000D+02,0.9999000000D+00,0.3806180000D+00,5*0.0D0/       00009030
      DATA ZON49/0.5000000000D+06,0.2526000000D+06,0.2561000000D+04,    00009040
     X0.1625668000D+02,0.9999666667D+00,0.3806575000D+00,5*0.0D0/       00009050
      DATA ZON50/0.8000000000D+06,0.2772000000D+06,0.2598947499D+08,    00009060
     X0.2636911276D+08,0.9999498485D+00,0.6276341196D+00,0.2323D+04,    00009070
     X0.5969369D+02,0.3811660D+01,0.3673920D+01,0.0          /          00009080
      DATA ZON51/0.6000000000D+06,0.2574000000D+06,0.2311197514D+08,    00009090
     X0.2354947732D+08,0.9999645506D+00,0.6717286561D+00,0.2523D+04,    00009100
     X0.1953138D+02,0.3808700D+01,0.4127380D+01,0.0          /          00009110
      DATA ZON52/0.2000000000D+06,0.2538000000D+06,0.2378467844D+08,    00009120
     X0.2392439802D+08,0.9999984844D+00,0.6610953994D+00,0.2474D+04,    00009130
     X0.1947463D+02,0.3809430D+01,0.4011740D+01,0.0          /          00009140
      DATA ZON53/0.5000000000D+06,0.3012000000D+06,0.2481000000D+04,    00009150
     X0.1872150000D+02,0.9999428571D+00,0.3807283000D+00,5*0.0D0/       00009160
      DATA ZON54/0.5000000000D+06,0.3087000000D+06,0.2481000000D+04,    00009170
     X0.1872150000D+02,0.9999090909D+00,0.3807541000D+00,5*0.0D0/       00009180
      DATA ZON55/0.5000000000D+06,0.3195000000D+06,0.2481000000D+04,    00009190
     X0.1872150000D+02,0.9999090909D+00,0.3805361000D+00,5*0.0D0/       00009200
      DATA ZON56/0.2000000000D+07,0.3132000000D+06,0.2004171618D+08,    00009210
     X0.2058942009D+08,0.9999410344D+00,0.7227899381D+00,0.2768D+04,    00009220
     X0.2225085D+02,0.3805010D+01,0.4684300D+01,0.3600000D+02/          00009230
      DATA ZON57/0.2000000000D+07,0.3036000000D+06,0.2100171522D+08,    00009240
     X0.2159476840D+08,0.9999509058D+00,0.7064074100D+00,0.2687D+04,    00009250
     X0.5076661D+02,0.3806220D+01,0.4468750D+01,0.3500000D+02/          00009260
      DATA ZON58/0.2000000000D+07,0.3036000000D+06,0.2256484851D+08,    00009270
     X0.2306959722D+08,0.9999450783D+00,0.6805292633D+00,0.2564D+04,    00009280
     X0.2223938D+02,0.3808080D+01,0.4157060D+01,0.3300000D+02/          00009290
      DATA ZON59/0.2000000000D+07,0.3351600000D+06,0.1898431962D+08,    00009300
     X0.1947139875D+08,0.9999028166D+00,0.7412196637D+00,0.2861D+04,    00009310
     X0.2463011D+02,0.3803620D+01,0.5016090D+01,0.0          /          00009320
      DATA ZON60/0.2000000000D+07,0.3393000000D+06,0.2000667972D+08,    00009330
     X0.2049345715D+08,0.9999220223D+00,0.7233880702D+00,0.2771D+04,    00009340
     X0.2089747D+02,0.3804970D+01,0.4761970D+01,0.0          /          00009350
      DATA ZON61/0.2000000000D+07,0.3384000000D+06,0.2132700606D+08,    00009360
     X0.2187434914D+08,0.9999220448D+00,0.7009277824D+00,0.2661D+04,    00009370
     X0.2012517D+02,0.3806620D+01,0.4469590D+01,0.0          /          00009380
      DATA ZON62/0.5000000000D+06,0.3198000000D+06,0.1772000000D+04,    00009390
     X0.2862716000D+02,0.9999600000D+00,0.3817257000D+00,5*0.0D0/       00009400
      DATA ZON63/0.5000000000D+06,0.3252000000D+06,0.1822000000D+04,    00009410
     X0.2100903000D+02,0.9999411765D+00,0.3816986000D+00,5*0.0D0/       00009420
      DATA ZON64/0.5000000000D+06,0.3258000000D+06,0.2141000000D+04,    00009430
     X0.4166790000D+02,0.9999333333D+00,0.3812643000D+00,5*0.0D0/       00009440
      DATA ZON65/0.5000000000D+06,0.3330000000D+06,0.2141000000D+04,    00009450
     X0.4166790000D+02,0.9999333333D+00,0.3812422000D+00,5*0.0D0/       00009460
      DATA ZON66/0.5000000000D+06,0.3402000000D+06,0.2161000000D+04,    00009470
     X0.3976857000D+02,0.9999411765D+00,0.3812362000D+00,5*0.0D0/       00009480
      DATA ZON67/0.2000000000D+07,0.3942000000D+06,0.1868949840D+08,    00009490
     X0.1915787426D+08,0.9999714855D+00,0.7464518080D+00,0.2888D+04,    00009500
     X0.2021285D+02,0.3803220D+01,0.5094900D+01,0.0          /          00009510
      DATA ZON68/0.2000000000D+07,0.3942000000D+06,0.1943293976D+08,    00009520
     X0.1991980636D+08,0.9999220151D+00,0.7333538278D+00,0.2821D+04,    00009530
     X0.2196779D+02,0.3804220D+01,0.4901350D+01,0.0          /          00009540
      DATA ZON69/0.2000000000D+07,0.3942000000D+06,0.2050065051D+08,    00009550
     X0.2109682093D+08,0.9999107701D+00,0.7149012442D+00,0.2729D+04,    00009560
     X0.2115820D+02,0.3805600D+01,0.4648140D+01,0.0          /          00009570
      DATA ZON70/0.2000000000D+07,0.3600000000D+06,0.2300434629D+08,    00009580
     X0.2336897746D+08,0.9999645501D+00,0.6734507906D+00,0.2531D+04,    00009590
     X0.1930504D+02,0.3808580D+01,0.4146530D+01,0.0          /          00009600
      DATA ZON71/0.2000000000D+07,0.3582000000D+06,0.2410456106D+08,    00009610
     X0.2459078186D+08,0.9999220725D+00,0.6560764003D+00,0.2451D+04,    00009620
     X0.2468139D+02,0.3809770D+01,0.3958650D+01,0.0          /          00009630
      DATA ZON72/0.5000000000D+06,0.4161000000D+06,0.2076000000D+04,    00009640
     X0.4830429000D+02,0.9999000000D+00,0.3812311000D+00,5*0.0D0/       00009650
      DATA ZON73/0.5000000000D+06,0.4200000000D+06,0.2076000000D+04,    00009660
     X0.4830429000D+02,0.9999000000D+00,0.3812311000D+00,5*0.0D0/       00009670
      DATA ZON74/0.5000000000D+06,0.4269000000D+06,0.2076000000D+04,    00009680
     X0.4830429000D+02,0.9999000000D+00,0.3812311000D+00,5*0.0D0/       00009690
      DATA ZON75/0.5000000000D+06,0.2580000000D+06,0.2541000000D+04,    00009700
     X0.1676677000D+02,0.9999666667D+00,0.3807327000D+00,5*0.0D0/       00009710
      DATA ZON76/0.2000000000D+07,0.2688000000D+06,0.2321000000D+04,    00009720
     X0.2702745000D+02,0.9999750295D+00,0.3810845000D+00,5*0.0D0/       00009730
      DATA ZON77/0.5000000000D+06,0.3756000000D+06,0.1852000000D+04,    00009740
     X0.1662358000D+02,0.9999090909D+00,0.3816135000D+00,5*0.0D0/       00009750
      DATA ZON78/0.5000000000D+06,0.3825000000D+06,0.1852000000D+04,    00009760
     X0.1662358000D+02,0.9999000000D+00,0.3816204000D+00,5*0.0D0/       00009770
      DATA ZON79/0.5000000000D+06,0.3882000000D+06,0.1852000000D+04,    00009780
     X0.1662358000D+02,0.9999166667D+00,0.3816288000D+00,5*0.0D0/       00009790
      DATA ZON80/0.5000000000D+06,0.2676000000D+06,0.2391000000D+04,    00009800
     X0.2284247000D+02,0.9999666667D+00,0.3808377000D+00,5*0.0D0/       00009810
      DATA ZON81/0.5000000000D+06,0.2757000000D+06,0.2391000000D+04,    00009820
     X0.2284247000D+02,0.9999375000D+00,0.3808450000D+00,5*0.0D0/       00009830
      DATA ZON82/0.5000000000D+06,0.2829000000D+06,0.2391000000D+04,    00009840
     X0.2284247000D+02,0.9999375000D+00,0.3808750000D+00,5*0.0D0/       00009850
      DATA ZON83/0.2000000000D+07,0.2664000000D+06,0.2423500080D+08,    00009860
     X0.2446254530D+08,0.9999949000D+00,0.6540820950D+00,0.2442D+04,    00009870
     X0.2064240D+02,0.3809900D+01,0.3937800D+01,0.0          /          00009880
      DATA ZON84/0.2000000000D+07,0.2844000000D+06,0.2963705947D+08,    00009890
     X0.3018361125D+08,0.9998725510D+00,0.5771707700D+00,0.2106D+04,    00009900
     X0.5160353D+02,0.3814800D+01,0.3224830D+01,0.0          /          00009910
      DATA ZON85/0.2000000000D+07,0.3618000000D+06,0.1881984905D+08,    00009920
     X0.1921551601D+08,0.9999358426D+00,0.7441333961D+00,0.2876D+04,    00009930
     X0.2257950D+02,0.3803390D+01,0.5059720D+01,0.0          /          00009940
      DATA ZON86/0.2000000000D+07,0.3618000000D+06,0.1966102779D+08,    00009950
     X0.2008697718D+08,0.9999358523D+00,0.7293826040D+00,0.2801D+04,    00009960
     X0.2045445D+02,0.3804520D+01,0.4845040D+01,0.0          /          00009970
      DATA ZON87/0.2000000000D+07,0.2970000000D+06,0.2404873851D+08,    00009980
     X0.2455915847D+08,0.9999391411D+00,0.6569503193D+00,0.2455D+04,    00009990
     X0.2348125D+02,0.3809710D+01,0.3967830D+01,0.0          /          00010000
      DATA ZON88/0.2000000000D+07,0.2970000000D+06,0.2552287581D+08,    00010010
     X0.2602707112D+08,0.9999359346D+00,0.6345195439D+00,0.2354D+04,    00010020
     X0.2863705D+02,0.3811210D+01,0.3740480D+01,0.0          /          00010030
      DATA ZON89/0.2000000000D+07,0.3528000000D+06,0.2865787166D+08,    00010040
     X0.2908283170D+08,0.9999454101D+00,0.5901470744D+00,0.2161D+04,    00010050
     X0.4256887D+02,0.3814020D+01,0.3334400D+01,0.0          /          00010060
      DATA ZON90/0.2000000000D+07,0.3528000000D+06,0.3038283106D+08,    00010070
     X0.3083803296D+08,0.9999359432D+00,0.5676166827D+00,0.2066D+04,    00010080
     X0.5248935D+02,0.3815370D+01,0.3146450D+01,0.0          /          00010090
      DATA ZON91/0.2000000000D+07,0.4338000000D+06,0.2083625094D+08,    00010100
     X0.2138385248D+08,0.9998945810D+00,0.7091860222D+00,0.2701D+04,    00010110
     X0.2208858D+02,0.3806020D+01,0.4573820D+01,0.0          /          00010120
      DATA ZON92/0.2000000000D+07,0.4338000000D+06,0.2234130943D+08,    00010130
     X0.2288866715D+08,0.9998946058D+00,0.6841473833D+00,0.2581D+04,    00010140
     X0.2274104D+02,0.3807820D+01,0.4268230D+01,0.0          /          00010150
      DATA ZON93/0.2000000000D+07,0.2799000000D+06,0.2375535127D+08,    00010160
     X0.2421105037D+08,0.9999568410D+00,0.6615397363D+00,0.2476D+04,    00010170
     X0.2157953D+02,0.3809400D+01,0.4017530D+01,0.0          /          00010180
      DATA ZON94/0.2000000000D+07,0.2799000000D+06,0.2457780067D+08,    00010190
     X0.2498482643D+08,0.9999595012D+00,0.6487931668D+00,0.2418D+04,    00010200
     X0.2387979D+02,0.3810260D+01,0.3883190D+01,0.0          /          00010210
      DATA ZON95/0.5000000000D+06,0.2574000000D+06,0.2456000000D+04,    00010220
     X0.1972344000D+02,0.9999937500D+00,0.3809220000D+00,5*0.0D0/       00010230
      DATA ZON96/0.2000000000D+07,0.2916000000D+06,0.3063012553D+08,    00010240
     X0.3112772475D+08,0.9999454207D+00,0.5644973800D+00,0.2053D+04,    00010250
     X0.5344099D+02,0.3815550D+01,0.3121270D+01,0.0          /          00010260
      DATA ZON97/0.2000000000D+07,0.2916000000D+06,0.3225212630D+08,    00010270
     X0.3267688765D+08,0.9999326284D+00,0.5446515700D+00,0.1972D+04,    00010280
     X0.3578390D+01,0.3816690D+01,0.2943810D+01,0.0          /          00010290
      DATA ZON98/0.2000000000D+07,0.3600000000D+06,0.2092270409D+08,    00010300
     X0.2136669703D+08,0.9999391116D+00,0.7077381841D+00,0.2694D+04,    00010310
     X0.1893392D+02,0.3809120D+01,0.4555290D+01,0.0          /          00010320
      DATA ZON99/0.2000000000D+07,0.3612000000D+06,0.2199357561D+08,    00010330
     X0.2246193705D+08,0.9999068931D+00,0.6898519579D+00,0.2608D+04,    00010340
     X0.2154370D+02,0.3807420D+01,0.4335190D+01,0.0          /          00010350
      DATA ZON100/0.2000000000D+07,0.3096000000D+06,0.2901023109D+08,   00010360
     X0.2953514991D+08,0.9999484030D+00,0.5854397296D+00,0.2141D+04,    00010370
     X0.4428313D+02,0.3814310D+01,0.3294220D+01,0.0          /          00010380
      DATA ZON101/0.2000000000D+07,0.3654000000D+06,0.2945690729D+08,   00010390
     X0.2997295994D+08,0.9999108771D+00,0.5795358654D+00,0.2116D+04,    00010400
     X0.4858548D+02,0.3814660D+01,0.3244520D+01,0.0          /          00010410
      DATA ZON102/0.2000000000D+07,0.3510000000D+06,0.3218780958D+08,   00010420
     X0.3269165454D+08,0.9998726224D+00,0.5453944146D+00,0.1975D+04,    00010430
     X0.5950740D+01,0.3816650D+01,0.2971070D+01,0.0          /          00010440
      DATA ZON103/0.2000000000D+07,0.3612000000D+06,0.3485170346D+08,   00010450
     X0.3533712123D+08,0.9998817443D+00,0.5150588857D+00,0.1852D+04,    00010460
     X0.2162181D+02,0.3818320D+01,0.2745500D+01,0.0          /          00010470
      DATA ZON104/0.2000000000D+07,0.3564000000D+06,0.3726150920D+08,   00010480
     X0.3780744038D+08,0.9998632433D+00,0.4899126408D+00,0.1752D+04,    00010490
     X0.3719059D+02,0.3819620D+01,0.2568990D+01,0.0          /          00010500
      DATA ZON105/0.2000000000D+07,0.3546000000D+06,0.4109174954D+08,   00010510
     X0.4157676239D+08,0.9998947956D+00,0.4540068519D+00,0.1612D+04,    00010520
     X0.5930342D+02,0.3821380D+01,0.2330940D+01,0.0          /          00010530
      DATA ZON106/0.2000000000D+07,0.4014000000D+06,0.2389487245D+08,   00010540
     X0.2422911029D+08,0.9999568422D+00,0.6593554910D+00,0.2466D+04,    00010550
     X0.2196231D+02,0.3809550D+01,0.3993230D+01,0.0          /          00010560
      DATA ZON107/0.2000000000D+07,0.4014000000D+06,0.2511717675D+08,   00010570
     X0.2566411442D+08,0.9998988207D+00,0.6405785926D+00,0.2381D+04,    00010580
     X0.2930066D+02,0.3810810D+01,0.3800240D+01,0.0          /          00010590
      DATA ZON108/0.2000000000D+07,0.4014000000D+06,0.2702595535D+08,   00010600
     X0.2743281288D+08,0.9999512939D+00,0.6126873424D+00,0.2258D+04,    00010610
     X0.3416878D+02,0.3812620D+01,0.3534140D+01,0.0          /          00010620
      DATA ZON109/0.5000000000D+06,0.2610000000D+06,0.2541000000D+04,   00010630
     X0.1676677000D+02,0.9999642857D+00,0.3807420000D+00,5*0.0D0/       00010640
      DATA ZON110/0.2000000000D+07,0.2826000000D+06,0.2623020009D+08,   00010650
     X0.2657644445D+08,0.9999483859D+00,0.6241178597D+00,0.2308D+04,    00010660
     X0.3078682D+02,0.3811890D+01,0.3640470D+01,0.0          /          00010670
      DATA ZON111/0.2000000000D+07,0.2826000000D+06,0.2743480006D+08,   00010680
     X0.2781131271D+08,0.9999454027D+00,0.6069248249D+00,0.2233D+04,    00010690
     X0.3641072D+02,0.3812980D+01,0.3481870D+01,0.0          /          00010700
      DATA ZON112/0.2000000000D+07,0.4350000000D+06,0.1879808167D+08,   00010710
     X0.1920586343D+08,0.9999422551D+00,0.7445203390D+00,0.2878D+04,    00010720
     X0.2215711D+02,0.3803360D+01,0.5065560D+01,0.0          /          00010730
      DATA ZON113/0.2000000000D+07,0.4338000000D+06,0.1983265352D+08,   00010740
     X0.2028911960D+08,0.9999145875D+00,0.7263957947D+00,0.2786D+04,    00010750
     X0.2172121D+02,0.3804740D+01,0.4803360D+01,0.0          /          00010760
      DATA ZON114/0.2000000000D+07,0.2862000000D+06,0.2530502912D+08,   00010770
     X0.2571512655D+08,0.9999407460D+00,0.6377729696D+00,0.2368D+04,    00010780
     X0.5752979D+02,0.3810990D+01,0.3772440D+01,0.0          /          00010790
      DATA ZON115/0.2000000000D+07,0.2916000000D+06,0.2663932345D+08,   00010800
     X27070620.78D0,.9999256928D0,.6181953936D0,2282.0D0,               00010810
     X0.3382207D+02,0.3812270D+01,0.3584910D+01,0.0          /          00010820
      DATA ZON116/0.2000000000D+07,0.3240000000D+06,0.2012413305D+08,   00010830
     X0.2048917967D+08,0.9999453461D+00,0.7213707913D+00,0.2761D+04,    00010840
     X0.1904034D+02,0.3805110D+01,0.4734510D+01,0.0          /          00010850
      DATA ZON117/0.2000000000D+07,0.3240000000D+06,0.2105074699D+08,   00010860
     X0.2143091391D+08,0.9999407059D+00,0.7055766312D+00,0.2683D+04,    00010870
     X0.4881363D+02,0.3806280D+01,0.4527820D+01,0.0          /          00010880
      DATA ZON118/0.2000000000D+07,0.3240000000D+06,0.2216143225D+08,   00010890
     X0.2267213466D+08,0.9999325474D+00,0.6871032423D+00,0.2595D+04,    00010900
     X0.2001691D+02,0.3807610D+01,0.4302740D+01,0.0          /          00010910
      DATA ZON119/0.5000000000D+06,0.3786000000D+06,0.2431000000D+04,   00010920
     X0.2083533000D+02,0.9999411765D+00,0.3808422000D+00,5*0.0D0/       00010930
      DATA ZON120/0.5000000000D+06,0.3864000000D+06,0.2431000000D+04,   00010940
     X0.2083533000D+02,0.9999411765D+00,0.3808422000D+00,5*0.0D0/       00010950
      DATA ZON121/0.5000000000D+06,0.3915000000D+06,0.2431000000D+04,   00010960
     X0.2083533000D+02,0.9999411765D+00,0.3808422000D+00,5*0.0D0/       00010970
      DATA ZON122/0.5000000000D+06,0.3963000000D+06,0.2431000000D+04,   00010980
     X0.2083533000D+02,0.9999411765D+00,0.3808422000D+00,5*0.0D0/       00010990
      DATA ZON123/0.500000000D+06,0.239160000D+06,0.6354222166D+08,     00011000
     X0.6368747944D+08,0.9999939449D+00,0.3128882281D+00,0.1088D+04,    00011010
     X0.484493300D+02,0.382699000D+01,0.151030000D+01,0.0D0/            00011020
      DATA ZON124/0.500000000D+06,0.239160000D+06,0.6354222166D+08,     00011030
     X0.6378747944D+08,0.9999939449D+00,0.3128882281D+00,0.1088D+04,    00011040
     X0.484493300D+02,0.382699000D+01,0.151030000D+01,0.0D0/            00011050
      DATA ZON125/0.500000000D+06,0.612000000D+06,-.8231223465D+08,     00011060
     X-.820000000D+08,0.100000000D+01,-.2464352205D+00,-.851000000D+03, 00011070
     X-.495329100D+02,0.382892000D+01,-.116664000D+01,0.0D0/            00011080
C                                                                       00011090
      INDICE=(J-1)*11
      DO 100 I=1,11
      K=I+INDICE
  100 T(I) = ZONE(K)
C
      RETURN                                                            00011130
      END                                                               00011140

