!***********************************************************************
!
!                     SNOWPCK_DPM.F  

!...MODULE TO COMPUTE SNOW ACCUMULATION, SNOWMELT, AND SUBLIMATION to obtain snowpack
!


!     version: 1.0 (vaccaro/bauer)


      integer function snowpck_dpm(arg)

      include 'fmodules.inc'

      character*(*) arg

      integer snowpckdecl, snowpckinit, snowpckrun, retval

      integer nhru, cov_type(MAXHRU)

      real sblrate, snmcoef, uadj, strtsno
      real hru_snow(MAXHRU), hru_rain(MAXHRU), hru_elev(MAXHRU)
      real hru_chngsno(MAXHRU),hru_snomelt(MAXHRU),hru_sublmton(MAXHRU)

      save nhru, cov_type, sblrate, snmcoef, hru_snow, hru_rain
      save hru_chngsno,hru_snomelt, hru_sublmton
      save uadj, hru_elev, strtsno

      retval = 0

      if(arg.eq.'declare') then
        retval = snowpckdecl(hru_rain, hru_snow,   hru_chngsno,
     +                                hru_snomelt, hru_sublmton)
      
      else if(arg.eq.'initialize') then
        retval = snowpckinit(nhru,cov_type,sblrate,snmcoef,uadj,
     +                                 hru_elev,strtsno,hru_snow)

      else if(arg.eq.'run') then
        retval = snowpckrun(nhru,cov_type,hru_snow,hru_rain,hru_chngsno,
     +          hru_snomelt,hru_sublmton,uadj,hru_elev,sblrate,snmcoef)

      end if

!******Debug level print
      call dpint4('End of snowpck_dpm, retval = ', retval, 1, 2)

      snowpck_dpm = retval

      return
      end

!***********************************************************************
!     snowpckdecl: Declares variables and parameters for this module
!              

      integer function snowpckdecl(hru_rain, hru_snow, hru_chngsno,
     +                             hru_snomelt, hru_sublmton)


      include 'fmodules.inc'
      
      real hru_snow(MAXHRU), hru_rain(MAXHRU)
      real hru_chngsno(MAXHRU),hru_snomelt(MAXHRU),hru_sublmton(MAXHRU)

      snowpckdecl = 1

!..variables for this module

      if(declvar('snowpck', 'hru_snow',  'nhru', MAXHRU, 'real',
     +   'Amount of snow-water-equivalent for a hru/mru/cell',
     +   'inches',hru_snow).ne.0) return

      if(declvar('snowpck', 'hru_rain',   'nhru', MAXHRU, 'real',
     +   'Amount of rain for a hru/mru/cell for a day',
     +   'inches',hru_rain).ne.0) return

      if(declvar('snowpck', 'hru_chngsno', 'nhru', MAXHRU, 'real',
     +   'Change in snowpack for this day for hru/cell',
     +   'inches',hru_chngsno).ne.0) return

      if(declvar('snowpck', 'hru_snomelt', 'nhru', MAXHRU, 'real',
     +   'Snowmelt for this day for hru/cell',
     +   'inches',hru_snomelt).ne.0) return

      if(declvar('snowpck', 'hru_sublmton', 'nhru', MAXHRU, 'real',
     +   'Amount of sublimation loss from snowpack day for hru/cell',
     +   'inches',hru_sublmton).ne.0) return

!..SNOW PARAMETERS

      if(declparam('snowpck', 'strtsno', 'one', 'real',
     +   '0.0', '0.0', '400.',
     +   'Initial snow water equivalent for all CELLs/HRUs',
     +   'Initial snow water equivalent for all CELLs/HRUs',
     +   'inches').ne.0) return

      if(declparam('snowpck', 'sblrate', 'one', 'real',
     +   '0.01', '0.001', '0.02',
     +   'Daily snow sublimation rate, generally 0.001-0.02',
     +   'Daily snow sublimation rate, generally 0.001-0.02',
     +   'inches').ne.0) return

      if(declparam('snowpck', 'snmcoef', 'one', 'real',
     +   '0.04', '0.001', '0.1',
     +   'Snowmelt coefficient for temperature index method',
     +   'Snowmelt coefficient used in snowmelt calculations for the'//
     +   'temperature index method, inches water/degrees Celcius/day',
     +   'in/C/day').ne.0) return

      if(declparam('snowpck', 'uadj', 'one', 'real',
     +   '0.15', '0.001', '0.20',
     +   'Average wind function during rain-on-snow event',
     +   'Average wind function during rain-on-snow event'//
     +   ' a model calibration factor for snowpack'//
     +   ' = 0.002 * wind movement in kilometers at height 1m ',
     +   'mm/mb/6hr').ne.0) return

!..declare module parameters

      if(declparam('basin', 'hru_elev', 'nhru', 'real',
     +   '0.', '-300.', '15000',
     +   'Mean elevation for each HRU',
     +   'Mean elevation for each HRU',
     +   'feet').ne.0) return

      if(declparam('basin', 'cov_type', 'nhru', 'integer',
     +   '1', '1', '31',
     +   'HRU cover type: land use/cover type, from 1-31',
     +   'HRU cover type, represents from 1-31 landuses/covers',
     +   'none').ne.0) return

      snowpckdecl = 0

      return
      end



!**********************************************************************
!     snowpckinit - get input  parameters
!               

      integer function snowpckinit(nhru,cov_type,sblrate,snmcoef,uadj,
     +                                      hru_elev,strtsno,hru_snow)

      include 'fmodules.inc'
      
      integer nhru, cov_type(MAXHRU), i

      real strtsno, sblrate, snmcoef, uadj
      real hru_elev(MAXHRU),hru_snow(MAXHRU)

      character*90 buffer

      snowpckinit = 1

!..GET dimensions 

      nhru = getdim('nhru')
      if(nhru.eq.-1) return

!..initial conditions for snowpack array (inches of water)

      if(getparam('snowpck', 'strtsno',  1, 'real',  strtsno)
     +  .ne.0) return

!..SNOW PARAMETERS

      if(getparam('snowpck', 'sblrate',     1,   'real',   sblrate)
     +    .ne.0) return 

      if(getparam('snowpck', 'snmcoef',     1,   'real',   snmcoef)
     +   .ne.0) return

      if(getparam('snowpck', 'uadj',        1,   'real',   uadj)
     +   .ne.0) return

!..landuse/cover type and elevation

      if(getparam('basin', 'cov_type',   MAXHRU, 'integer', cov_type)
     +   .ne.0) return

      if(getparam('basin', 'hru_elev',   MAXHRU, 'real',   hru_elev)
     +   .ne.0) return

!..initialize snowpack for start of simulation

       do 100 i=1,nhru
100   hru_snow(i)=strtsno

        WRITE(BUFFER,1000)
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1001) strtsno
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1000)
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1002)  SBLRATE
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1000)
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1003)  SNMCOEF
        CALL OPSTR(BUFFER)

!.....CONVERT IN/C/DAY TO IN/C/.25-DAY FOR SNMCOEF, FOR SUROUTINE SNWPCK

      SNMCOEF=0.25*SNMCOEF

        WRITE(BUFFER,1000)
        CALL OPSTR(BUFFER)
        WRITE(BUFFER,1004)  uadj
        CALL OPSTR(BUFFER)

1000  FORMAT()
1001  FORMAT(' INITIAL SNOW (H2O-INCHES)=',F6.2)
1002  FORMAT(' THE WINTER SEASON SUBLIMATION RATE = ',F6.4,' IN/DAY')
1003  FORMAT(' THE DAILY SNOWMELT COEFFICIENT  = ',  F6.4,' IN/C/DAY')
1004  FORMAT(' Rain-on-Snow Wind function (uadj) = ',F6.4,'mm/mb/6hr')
 
      snowpckinit = 0

      RETURN
      END

!***********************************************************************
! 
!     snowpckrun - snow accumulation and abalation
!
!...MODULE TO COMPUTE SNOWMELT AND SUBLIMATION to obtain snowpack


      integer function snowpckrun(nhru,cov_type,hru_snow,hru_rain, 
     +                      hru_chngsno, hru_snomelt,hru_sublmton,
     +                              uadj,hru_elev,sblrate,snmcoef)


      include 'fmodules.inc'

      integer nhru
      integer cov_type(MAXHRU)

      real sblrate, snmcoef, uadj
      real hru_snow(MAXHRU), hru_rain(MAXHRU),  hru_adjustpet(MAXHRU)
      real tmaxf(MAXHRU), tminf(MAXHRU), tavf(MAXHRU), tmxyst(MAXHRU)
      real hru_chngsno(MAXHRU),hru_snomelt(MAXHRU),hru_sublmton(MAXHRU)
      real hru_thrufall(MAXHRU), hru_ppt(MAXHRU), hru_elev(MAXHRU)

!..temp variables

      integer jday, i, i6hr, iy
      real t(4), kmcof, tmnpst, subtmp, snmlt, snoyst, pa, elev
      real tair, tak, rain, esat, rainmelt, qn, qe, qh

      snowpckrun = 1

      jday   = julian('now', 'calendar')

      if(getvar('intrcp', 'hru_adjustpet',MAXHRU,'real', hru_adjustpet)
     +   .ne.0) return

      if(getvar('intrcp', 'hru_thrufall', MAXHRU, 'real', hru_thrufall)
     +   .ne.0) return

      if(getvar('grid',     'hru_ppt',     MAXHRU,  'real', hru_ppt)
     +   .ne.0) return

      if(getvar('grid',     'tavf',         MAXHRU, 'real', tavf)
     +   .ne.0) return

      if(getvar('grid',     'tminf',        MAXHRU, 'real', tminf)
     +   .ne.0) return

      if(getvar('grid',     'tmaxf',        MAXHRU, 'real', tmaxf)
     +   .ne.0) return

      if(getvar('grid',     'tmxyst',       MAXHRU, 'real', tmxyst)
     +   .ne.0) return


      do 1000 i=1,nhru

      hru_rain(i)     = 0.0
      hru_chngsno(i)  = 0.0
      hru_snomelt(i)  = 0.0
      hru_sublmton(i) = 0.0
      snoyst = hru_snow(i)

!..if water for this hru/mru/cell skip to next hru

      if(cov_type(i).eq.10) go to 1000
    
!..add thrufall to either rain or snow

      if(hru_thrufall(i).gt.0.00001) then

       if(tavf(i).lt.32.0) then
        hru_snow(i)=hru_snow(i) + hru_thrufall(i)
       else
         hru_rain(i) = hru_thrufall(i)
       endif
      
      end if

!..if no snow for this hru/mru/cell skip to next hru

      if(hru_snow(i).lt.0.00001) go to 1000

!...FIRST DISAGGREGATE TEMPS TO 6-HR VALUES (ANDERSON,1973)

      TMNPST=tminf(i)+tmxyst(i)-tmaxf(i)
      T(1)=0.95* tminf(i)+0.05* tmxyst(i)
      T(2)=0.40* tminf(i)+0.60* tmaxf(i)
      T(3)=0.925*tmaxf(i)+0.025*tminf(i)+0.05*TMNPST
      T(4)=0.33* tmaxf(i)+0.67* TMNPST

!...FIND COEFFICIENT,BASED ON VARIATION WITH JULIAN DAY
!...(MALE AND GRANGER,1978,PROCEEDINGS MODELING SNOW COVER RUNOFF,CRREL)

      IY=JDAY
      IF(JDAY.GT.185) IY=(367-JDAY)
      KMCOF=SNMCOEF
      IF(IY.LT.75) GO TO 105
      KMCOF=.0014*(IY-75)+SNMCOEF

!...ACCUMULATE hru_snomelt  AND SUBLIMATION (hru_sublmton(i)) OVER THE FOUR 6-HR
!...PERIODS BUT SUBLIMATE ONLY FROM 6AM-6PM.  DECREASE snowpack (hru_snow(i)) FOR EACH
!...OF THE PERIODS.

105   DO 110 I6HR=1,4
      SUBTMP=0.0
      IF(I6HR.GT.1.AND.I6HR.LT.4) SUBTMP=SBLRATE*0.5
      IF(SUBTMP.GT.hru_snow(i))   SUBTMP=hru_snow(i)
      hru_snow(i)     = hru_snow(i)    -SUBTMP
      hru_sublmton(i) = hru_sublmton(i)+SUBTMP

!..check if any snow left to melt after sublimation,         if not leave 6hr loop

      IF(hru_snow(i).LT.0.00000001)        GO TO 120
      SNMLT= KMCOF*.555555556*(T(i6hr)-34.0)
      IF(SNMLT.LT.0.0) SNMLT=0.0
      IF(SNMLT.GT.hru_snow(i)) SNMLT=hru_snow(i)
      hru_snomelt(i)=hru_snomelt(i)+ SNMLT
      hru_snow(i)   =hru_snow(i)   - SNMLT

!..check if any snow left to melt w/ rainfall after snowmelt, if not leave 6hr loop

      IF(hru_snow(i).LT.0.00000001)        GO TO 120


!...COMPUTE hru_snomelt FROM rain-on-snow IF rain > 0.01 inches and temp > 32
!..from Anderson march 31, 1978 snow acc. and abal model, N.W.S., Part II, Chapter 2,
!  esentially same as Anderson (1973) w/ minor changes

      IF( (hru_rain(i)*0.25) .gt. 0.01 .and. t(i6hr).gt.32.0) then

       Tair = (T(i6hr)-32.)*0.555556                    !..temp in Celsius for 6 hr period
       rain = (hru_rain(i) * 0.25) * 25.4               !..rain for 6 hr period
       elev = (hru_elev(i) * 0.3048)/ 100.              !..convert elev to hundreds of meters
       PA   =  1012.4 - 11.34*elev + 0.00745*elev**2.4  !..calculate pressure atmospheric

        ESAT = 2.749e8 * (EXP(-4278.6/(Tair+242.792)))

!..assume 90 percent relative humidity during rain-on-snow

       ESAT = ESAT * 0.9
       TAK  = (Tair+273.) 
       TAK  = TAK**4
       QN   = 3.67e-9 * tak - 20.4                 !.. net radiation transfer
       QE   = 8.5 * (ESAT-6.11) * uadj             !.. latent heat transfer
       QH   =  0.004845 * pa * uadj * tair         !.. sensible heat transfer
       rainmelt =  0.0125  * rain * Tair 

       SNMLT = qn + qe + qh + rainmelt

       SNMLT = SNMLT / 25.4
       IF(SNMLT.LT.0.0) SNMLT=0.0
       IF(SNMLT.GT.hru_snow(i)) SNMLT=hru_snow(i)
       hru_snomelt(i)=hru_snomelt(i)+SNMLT
       hru_snow(i)=hru_snow(i)-SNMLT

! old anderson eqn        SNMLT=(tavf(i)-32.)*0.55555556*(0.029+hru_rain(i)*0.0028)

      endif

110   continue

120   hru_chngsno(i)=hru_snow(i)    - snoyst

!...REDUCE PET BY ENERGY USED TO EVAPORATE hru_snow, THIS WILL ONLY MATTER WHEN
!...TOTAL LOSS OF hru_snow FOR THIS DAY RESULTS IN NO snowpack SO OTHER
!...modules do calculations when entered (eg, plant et)

      hru_adjustpet(i) = hru_adjustpet(i) - hru_sublmton(i)
      IF(hru_adjustpet(i). LT. 0.0) hru_adjustpet(i)=0.0

1000  continue

      if(putvar('intrcp', 'hru_adjustpet',MAXHRU,'real', hru_adjustpet)
     +   .ne.0) return

      snowpckrun = 0

      RETURN
      END


